/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_mIs1bR8N);
  numBytes += sLine_init(&sLine_1aqcl6Rj);
  numBytes += sLine_init(&sLine_r4iL8Oa0);
  numBytes += sLine_init(&sLine_U2WfoVfU);
  numBytes += sLine_init(&sLine_B7rvE1jF);
  numBytes += sBiquad_init(&sBiquad_s_YpSkWJ3K);
  numBytes += sLine_init(&sLine_FlmIGQ1n);
  numBytes += sLine_init(&sLine_hCaAZUX0);
  numBytes += sLine_init(&sLine_xw6YiCE5);
  numBytes += sLine_init(&sLine_acifBcx4);
  numBytes += sLine_init(&sLine_uJg4kzbC);
  numBytes += sBiquad_init(&sBiquad_s_vcwj8wKq);
  numBytes += sLine_init(&sLine_Z8hZYdls);
  numBytes += sLine_init(&sLine_Ad44Ybgc);
  numBytes += sLine_init(&sLine_iQo1KLlG);
  numBytes += sLine_init(&sLine_ioW7baIw);
  numBytes += sLine_init(&sLine_IeftKuW4);
  numBytes += sLine_init(&sLine_1YsUL5wp);
  numBytes += sBiquad_init(&sBiquad_s_AFw1S6Ej);
  numBytes += sLine_init(&sLine_PEmmWLuV);
  numBytes += sLine_init(&sLine_3LpPWyug);
  numBytes += sLine_init(&sLine_qpdrRC15);
  numBytes += sLine_init(&sLine_kEuNRKdZ);
  numBytes += sLine_init(&sLine_fq9kDkW9);
  numBytes += sLine_init(&sLine_77yCnGr2);
  numBytes += sBiquad_init(&sBiquad_s_pcyL0VlG);
  numBytes += sLine_init(&sLine_4rRFUI0Q);
  numBytes += sLine_init(&sLine_V7sZJ2v9);
  numBytes += sLine_init(&sLine_fDU0mjDL);
  numBytes += sLine_init(&sLine_FQEogp4h);
  numBytes += sLine_init(&sLine_L0EyKR68);
  numBytes += sBiquad_init(&sBiquad_s_HkozabEG);
  numBytes += sLine_init(&sLine_2KaTQhi1);
  numBytes += sLine_init(&sLine_CqZMAYCX);
  numBytes += sLine_init(&sLine_pR6RTMuY);
  numBytes += sLine_init(&sLine_mxgQW420);
  numBytes += sLine_init(&sLine_O0JThNCj);
  numBytes += sLine_init(&sLine_ii0fLJNg);
  numBytes += sBiquad_init(&sBiquad_s_YERjQNzR);
  numBytes += sLine_init(&sLine_s8OH6a0H);
  numBytes += sLine_init(&sLine_7HEyDSYL);
  numBytes += sLine_init(&sLine_kMPMBM6C);
  numBytes += sLine_init(&sLine_LqOW5cbx);
  numBytes += sLine_init(&sLine_DJhFh3d0);
  numBytes += sLine_init(&sLine_QkvYRPOo);
  numBytes += sLine_init(&sLine_Sit8fAf1);
  numBytes += sLine_init(&sLine_JuLAwOOH);
  numBytes += sLine_init(&sLine_P0OaMtXP);
  numBytes += sLine_init(&sLine_vg2Zp1yK);
  numBytes += sLine_init(&sLine_b62RQYxO);
  numBytes += sLine_init(&sLine_3Nrcd90m);
  numBytes += sLine_init(&sLine_F9CZ4nPG);
  numBytes += sLine_init(&sLine_q5aXWgio);
  numBytes += sLine_init(&sLine_qOcd6Ljv);
  numBytes += sEnv_init(&sEnv_BCUizeyW, 512, 256);
  numBytes += sEnv_init(&sEnv_KM6l8BCd, 512, 256);
  numBytes += sLine_init(&sLine_0CWc1D0p);
  numBytes += sLine_init(&sLine_LrBXUQk6);
  numBytes += sLine_init(&sLine_HlyeOxQy);
  numBytes += sLine_init(&sLine_mbYyBrS7);
  numBytes += sLine_init(&sLine_uW0vG9pL);
  numBytes += sLine_init(&sLine_gGQzqAlO);
  numBytes += sLine_init(&sLine_o0q5LLrD);
  numBytes += sLine_init(&sLine_gKRjP5rj);
  numBytes += sLine_init(&sLine_qAa16wI6);
  numBytes += sLine_init(&sLine_F1NRnlab);
  numBytes += sLine_init(&sLine_AtddN7ak);
  numBytes += sLine_init(&sLine_adKn952P);
  numBytes += sLine_init(&sLine_QE4US8el);
  numBytes += sLine_init(&sLine_XfjpVt35);
  numBytes += sLine_init(&sLine_TH16F7y8);
  numBytes += sLine_init(&sLine_s9zea3B0);
  numBytes += sLine_init(&sLine_gUkDy3T9);
  numBytes += sLine_init(&sLine_mmONQ0k0);
  numBytes += sEnv_init(&sEnv_ZbWcTrEe, 512, 256);
  numBytes += sEnv_init(&sEnv_jRZfyZe7, 512, 256);
  numBytes += sLine_init(&sLine_j9iVez3r);
  numBytes += sLine_init(&sLine_dngmJLbk);
  numBytes += sLine_init(&sLine_MxR9ZKIf);
  numBytes += sLine_init(&sLine_F86lFQ5w);
  numBytes += sLine_init(&sLine_B1R7OPFy);
  numBytes += sLine_init(&sLine_xSrlWqJI);
  numBytes += sLine_init(&sLine_9Dk1OErN);
  numBytes += sLine_init(&sLine_ElI9PlYs);
  numBytes += sLine_init(&sLine_7kcbiean);
  numBytes += sLine_init(&sLine_1y9MnWiR);
  numBytes += sLine_init(&sLine_vq9Uo03o);
  numBytes += sLine_init(&sLine_YoVWbcln);
  numBytes += sLine_init(&sLine_fAmvIqX1);
  numBytes += sLine_init(&sLine_XV3hsCd4);
  numBytes += sLine_init(&sLine_Gby8D26P);
  numBytes += sLine_init(&sLine_DS98NZZM);
  numBytes += sLine_init(&sLine_rulvoW8b);
  numBytes += sLine_init(&sLine_US0RuV7m);
  numBytes += sLine_init(&sLine_LNUiYcAv);
  numBytes += sLine_init(&sLine_KTQi2dUc);
  numBytes += sEnv_init(&sEnv_unUtm1qA, 512, 256);
  numBytes += sEnv_init(&sEnv_dsffpoPy, 512, 256);
  numBytes += sLine_init(&sLine_neW54wkG);
  numBytes += sLine_init(&sLine_8rJgERe9);
  numBytes += sLine_init(&sLine_TvIfc1jM);
  numBytes += sLine_init(&sLine_h3YyEIwv);
  numBytes += sLine_init(&sLine_zifyF84m);
  numBytes += sLine_init(&sLine_rFnOWmyY);
  numBytes += sLine_init(&sLine_KNpeySki);
  numBytes += sLine_init(&sLine_Vbiacoxw);
  numBytes += sLine_init(&sLine_rV4RUViF);
  numBytes += sLine_init(&sLine_d7JFQIFx);
  numBytes += sLine_init(&sLine_ZHFNeKcX);
  numBytes += sLine_init(&sLine_oEzxKcks);
  numBytes += sLine_init(&sLine_YHYI01h1);
  numBytes += sLine_init(&sLine_KjHubgBS);
  numBytes += sLine_init(&sLine_tosSCqTX);
  numBytes += sLine_init(&sLine_tQwhKKEA);
  numBytes += sLine_init(&sLine_hCRNK5YP);
  numBytes += sLine_init(&sLine_fxAcAYg5);
  numBytes += sEnv_init(&sEnv_kUbljVQe, 512, 256);
  numBytes += sEnv_init(&sEnv_Wk53PUtk, 512, 256);
  numBytes += sLine_init(&sLine_rDddlpag);
  numBytes += sLine_init(&sLine_DQgYIF0Y);
  numBytes += sLine_init(&sLine_bPloqjb8);
  numBytes += sLine_init(&sLine_tM0NIeRp);
  numBytes += sLine_init(&sLine_X3pJt634);
  numBytes += sLine_init(&sLine_coiPZw5I);
  numBytes += sLine_init(&sLine_HaC6D8AP);
  numBytes += sLine_init(&sLine_olzyQLYv);
  numBytes += sLine_init(&sLine_LUR29rXc);
  numBytes += sLine_init(&sLine_qXjn4T0b);
  numBytes += sLine_init(&sLine_vlyJjXFD);
  numBytes += sLine_init(&sLine_S6IyEB8g);
  numBytes += sLine_init(&sLine_3tmWlXfz);
  numBytes += sLine_init(&sLine_KYkcATVf);
  numBytes += sLine_init(&sLine_uloH3YLr);
  numBytes += sLine_init(&sLine_csCVGhTD);
  numBytes += sLine_init(&sLine_wuvpmkn3);
  numBytes += sLine_init(&sLine_T79EBREr);
  numBytes += sLine_init(&sLine_n6GdnktL);
  numBytes += sLine_init(&sLine_kfodzCu2);
  numBytes += sEnv_init(&sEnv_a1NYBl4D, 512, 256);
  numBytes += sEnv_init(&sEnv_ZTQubMs0, 512, 256);
  numBytes += sLine_init(&sLine_Vu8sEma4);
  numBytes += sLine_init(&sLine_mz6QipU0);
  numBytes += sLine_init(&sLine_9J6zZmHf);
  numBytes += sLine_init(&sLine_6vX9VjVc);
  numBytes += sLine_init(&sLine_IVoesz6O);
  numBytes += sLine_init(&sLine_r3JdKsTu);
  numBytes += sLine_init(&sLine_juhFIt18);
  numBytes += sLine_init(&sLine_iIDBQ4r0);
  numBytes += sLine_init(&sLine_HRRiEk8F);
  numBytes += sLine_init(&sLine_1yyM5g9J);
  numBytes += sLine_init(&sLine_GHnAIG3z);
  numBytes += sLine_init(&sLine_QEFSzlxX);
  numBytes += sLine_init(&sLine_bO9lR8Ek);
  numBytes += sLine_init(&sLine_QaueMrzd);
  numBytes += sLine_init(&sLine_dCidLkjd);
  numBytes += sLine_init(&sLine_CsGan9fy);
  numBytes += sLine_init(&sLine_vniP6wyM);
  numBytes += sLine_init(&sLine_6elAW81c);
  numBytes += sEnv_init(&sEnv_QFxVoMhr, 512, 256);
  numBytes += sEnv_init(&sEnv_4VlCUEcL, 512, 256);
  numBytes += sLine_init(&sLine_cB5PE5uM);
  numBytes += sLine_init(&sLine_rrrcbDoi);
  numBytes += sLine_init(&sLine_GvzxD2jc);
  numBytes += sLine_init(&sLine_5bC37u66);
  numBytes += sLine_init(&sLine_7wMP3wCF);
  numBytes += sLine_init(&sLine_kTfrq7xh);
  numBytes += cVar_init_f(&cVar_wKbD1Z71, 0.0f);
  numBytes += cVar_init_f(&cVar_TWFYKzea, 0.0f);
  numBytes += cVar_init_f(&cVar_2iMaYoBZ, 0.0f);
  numBytes += cVar_init_f(&cVar_rEgLR6MH, 0.0f);
  numBytes += cVar_init_f(&cVar_Mwv2yz7x, 0.0f);
  numBytes += cVar_init_f(&cVar_KpKkfzlI, 1.0f);
  numBytes += cVar_init_f(&cVar_1PbEQr7j, 0.0f);
  numBytes += cVar_init_f(&cVar_LedYrwCK, 0.0f);
  numBytes += cVar_init_f(&cVar_0GjL3vM4, 0.0f);
  numBytes += cVar_init_f(&cVar_J1Cskvl0, 0.0f);
  numBytes += cSlice_init(&cSlice_hB8bXNLb, 1, -1);
  numBytes += cVar_init_f(&cVar_of5s3swg, 1337.0f);
  numBytes += cVar_init_f(&cVar_igDE3udd, 0.0f);
  numBytes += cIf_init(&cIf_2DzhsS2t, false);
  numBytes += cIf_init(&cIf_tap6Dlbh, false);
  numBytes += cBinop_init(&cBinop_u44qF4FG, 0.0f); // __pow
  numBytes += cIf_init(&cIf_fWRHajFT, false);
  numBytes += cBinop_init(&cBinop_gpykRmBn, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_WMNcEhEG, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_c4bLdeEJ, 0.0f);
  numBytes += cIf_init(&cIf_t0JWTusd, false);
  numBytes += cIf_init(&cIf_BJFaGDBi, false);
  numBytes += cBinop_init(&cBinop_ElziK6c6, 0.0f); // __pow
  numBytes += cIf_init(&cIf_FRB3xPKG, false);
  numBytes += cBinop_init(&cBinop_Ue7jrKtg, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_lKFeQ2tn, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_JrkBlI8a, 0.0f);
  numBytes += cIf_init(&cIf_ylhlStLU, false);
  numBytes += cIf_init(&cIf_CAxeqa6Z, false);
  numBytes += cBinop_init(&cBinop_THKNKWhM, 0.0f); // __pow
  numBytes += cIf_init(&cIf_AofnNpPq, false);
  numBytes += cBinop_init(&cBinop_Fn0qvvRt, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_UIXMSc1C, -15.0f); // __eq
  numBytes += cIf_init(&cIf_61YCAbcn, false);
  numBytes += cSlice_init(&cSlice_rjzmKeH3, 1, -1);
  numBytes += cVar_init_f(&cVar_BEjQ8BTy, 0.0f);
  numBytes += cSlice_init(&cSlice_9wmEFDEo, 1, -1);
  numBytes += cVar_init_f(&cVar_gu1mKmbG, 0.0f);
  numBytes += cSlice_init(&cSlice_mmteMlCh, 1, -1);
  numBytes += cVar_init_f(&cVar_1Zgt3ank, 0.0f);
  numBytes += cSlice_init(&cSlice_WjpGWqs3, 1, -1);
  numBytes += cVar_init_f(&cVar_9nVITjRA, 0.313f);
  numBytes += cBinop_init(&cBinop_EK6TtkYa, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_jWWGMsLF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_aqlBaWgD, 0.0f);
  numBytes += cVar_init_f(&cVar_nzfvQfl5, 1337.0f);
  numBytes += cVar_init_f(&cVar_Hw0dSvtT, 0.3f);
  numBytes += cBinop_init(&cBinop_VCgINkwx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QhVq19BG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sQ1FMGHd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CcArPbrJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oyYK1We8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xcVGHm3r, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1Ydzc9Pa, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ML7f2CBL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_pDqMG2it, 0.0f);
  numBytes += cVar_init_f(&cVar_orzAmyRG, 1337.0f);
  numBytes += cVar_init_f(&cVar_dVgKpR9V, 0.313f);
  numBytes += cBinop_init(&cBinop_dfo1IAeF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vQpNkFrr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WsXr7t49, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_N0WPMcWq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uJeKwntL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CQZDrhAL, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_IjpA2cqL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_GcIQ03XV, 0.0f);
  numBytes += cVar_init_f(&cVar_GRerQSDA, 1037.0f);
  numBytes += cVar_init_f(&cVar_SSul8cq5, 0.4f);
  numBytes += cBinop_init(&cBinop_aMtpD6M3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_x8mjWASz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KxUOGgS4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MBJup9me, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_testLfTg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_K99fdeMP, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_ouROMeP0, 1, -1);
  numBytes += cVar_init_f(&cVar_3PgGF4P4, 1337.0f);
  numBytes += cVar_init_f(&cVar_dp6hvvgW, 0.0f);
  numBytes += cIf_init(&cIf_3VibC99o, false);
  numBytes += cIf_init(&cIf_69Il6JAQ, false);
  numBytes += cBinop_init(&cBinop_AEcLR5Y9, 0.0f); // __pow
  numBytes += cIf_init(&cIf_uMhQ0gRB, false);
  numBytes += cBinop_init(&cBinop_7hFn8TCk, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_PwqR61h8, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hxxEBsCd, 0.0f);
  numBytes += cIf_init(&cIf_VDQfolBU, false);
  numBytes += cIf_init(&cIf_cjizRTn2, false);
  numBytes += cBinop_init(&cBinop_qkbA2U2M, 0.0f); // __pow
  numBytes += cIf_init(&cIf_4Jt1hOI0, false);
  numBytes += cBinop_init(&cBinop_mv0b9Lp7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_nIX2N14N, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_WWQlMVOE, 0.0f);
  numBytes += cIf_init(&cIf_lifWyRcr, false);
  numBytes += cIf_init(&cIf_ibLpSk32, false);
  numBytes += cBinop_init(&cBinop_LRQqvI4A, 0.0f); // __pow
  numBytes += cIf_init(&cIf_LnXbYXdV, false);
  numBytes += cBinop_init(&cBinop_7mBAUI7C, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_QuXC7dGW, -15.0f); // __eq
  numBytes += cIf_init(&cIf_jpnrDbiS, false);
  numBytes += cSlice_init(&cSlice_UqE1IqLM, 1, -1);
  numBytes += cVar_init_f(&cVar_T4tOSQKF, 0.0f);
  numBytes += cSlice_init(&cSlice_bTPxX6EW, 1, -1);
  numBytes += cVar_init_f(&cVar_zEdgtR1v, 0.0f);
  numBytes += cSlice_init(&cSlice_pLZ4Pgsh, 1, -1);
  numBytes += cVar_init_f(&cVar_v7Xs3ApL, 0.0f);
  numBytes += cSlice_init(&cSlice_E4saVIRo, 1, -1);
  numBytes += cVar_init_f(&cVar_PN6qdr3Z, 0.313f);
  numBytes += cBinop_init(&cBinop_yxWlkIPM, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_bFqXZ27u, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1EaEQlZd, 0.0f);
  numBytes += cVar_init_f(&cVar_YYUfom53, 1337.0f);
  numBytes += cVar_init_f(&cVar_3mpIzTap, 0.3f);
  numBytes += cBinop_init(&cBinop_UOG7LwG3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qgvYyY8P, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DoCMH1hD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Zgi70Tqp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_C8vbIEH2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1QUaj8nn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FZh4sR6t, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_rNfxinpw, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_K8rhLRhd, 0.0f);
  numBytes += cVar_init_f(&cVar_xyqG6Z71, 1337.0f);
  numBytes += cVar_init_f(&cVar_6tV9By3M, 0.313f);
  numBytes += cBinop_init(&cBinop_C4umZw7r, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Il6bsO6E, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_19NLVI7z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_n2g3rpZd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5Y79VTFU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NRVhThBs, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_2o3R8FZn, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_NDPR4DR9, 0.0f);
  numBytes += cVar_init_f(&cVar_DhuSmcrY, 1037.0f);
  numBytes += cVar_init_f(&cVar_GaTmltD0, 0.4f);
  numBytes += cBinop_init(&cBinop_Vt9wthlC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LIrFr0Ki, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mVeRiBtv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SINEkNgQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xAjQjbRz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Naimq5t8, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_2aqfYcRg, 5705.6f);
  numBytes += cVar_init_f(&cVar_LnLP05iS, 313.3f);
  numBytes += cBinop_init(&cBinop_lMdK1RMU, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_5TXwprJ9, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_4i0Qw3xp, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_Gi2tbwCd, 1, -1);
  numBytes += cVar_init_f(&cVar_E0sSumlV, 0.5f);
  numBytes += cVar_init_f(&cVar_tpz2Ayt9, 0.0f);
  numBytes += cVar_init_f(&cVar_zH6ilnJZ, 0.0f);
  numBytes += cIf_init(&cIf_alhZcJVU, false);
  numBytes += cIf_init(&cIf_meailEo3, false);
  numBytes += cDelay_init(this, &cDelay_ppH9Xqxa, 10.0f);
  numBytes += cIf_init(&cIf_c10yPlEo, false);
  numBytes += cIf_init(&cIf_bJwdbAc8, false);
  numBytes += cDelay_init(this, &cDelay_0VKTGOxN, 10.0f);
  numBytes += cIf_init(&cIf_xFSmsuTb, false);
  numBytes += cIf_init(&cIf_Qd9r86x4, false);
  numBytes += cDelay_init(this, &cDelay_JvAcCvz0, 10.0f);
  numBytes += cIf_init(&cIf_Y2iN6zfq, false);
  numBytes += cIf_init(&cIf_F4ZMHTCQ, false);
  numBytes += cDelay_init(this, &cDelay_KAZYR6oE, 10.0f);
  numBytes += cIf_init(&cIf_HbUJQXBp, false);
  numBytes += cIf_init(&cIf_gbjiYTzV, false);
  numBytes += cDelay_init(this, &cDelay_TEIsw2w5, 10.0f);
  numBytes += cIf_init(&cIf_vrlQrv6s, false);
  numBytes += cIf_init(&cIf_PQN7w77S, false);
  numBytes += cDelay_init(this, &cDelay_MHCpKcj9, 10.0f);
  numBytes += cIf_init(&cIf_M25aSm3W, false);
  numBytes += cIf_init(&cIf_VTf2vE1D, false);
  numBytes += cDelay_init(this, &cDelay_AaGOPNQT, 10.0f);
  numBytes += cIf_init(&cIf_aYb7KKcU, false);
  numBytes += cIf_init(&cIf_z8inUTIj, false);
  numBytes += cDelay_init(this, &cDelay_nHItdQm0, 10.0f);
  numBytes += cIf_init(&cIf_n5ktV2jD, false);
  numBytes += cIf_init(&cIf_fWNhLeEg, false);
  numBytes += cDelay_init(this, &cDelay_BH9PQKMq, 10.0f);
  numBytes += cIf_init(&cIf_af64EpV7, false);
  numBytes += cIf_init(&cIf_TASut2SG, false);
  numBytes += cDelay_init(this, &cDelay_ESmAffwF, 10.0f);
  numBytes += cIf_init(&cIf_BLgGitwB, false);
  numBytes += cIf_init(&cIf_uT3Nm4zv, false);
  numBytes += cDelay_init(this, &cDelay_kRNl7iqe, 10.0f);
  numBytes += cIf_init(&cIf_m5ObJPfx, false);
  numBytes += cIf_init(&cIf_fW5G5W7p, false);
  numBytes += cDelay_init(this, &cDelay_q1DXgPMQ, 10.0f);
  numBytes += sVarf_init(&sVarf_5p80XTxQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vRHct2UK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eearNQGP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zyrg8TJi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oFgdbCNS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1MkUiChc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EDhr0Lwx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PZWOtdHY, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_cOWXTprG, 0.0f);
  numBytes += cSlice_init(&cSlice_Tg3OiwRR, 1, -1);
  numBytes += cVar_init_f(&cVar_n7RFc5X8, 1.0f);
  numBytes += cSlice_init(&cSlice_SgRUIicr, 1, -1);
  numBytes += cVar_init_f(&cVar_NuZMECkq, 0.0f);
  numBytes += cSlice_init(&cSlice_GpDv10kv, 1, -1);
  numBytes += cVar_init_f(&cVar_85r93S0R, 512.0f);
  numBytes += cSlice_init(&cSlice_WJlamLdA, 1, -1);
  numBytes += cVar_init_f(&cVar_c3gLPIC6, 1.0f);
  numBytes += cSlice_init(&cSlice_uxI6e4O6, 1, -1);
  numBytes += cVar_init_f(&cVar_Br5OWdTp, 1.0f);
  numBytes += cDelay_init(this, &cDelay_RMzxaWnP, 20.0f);
  numBytes += cVar_init_f(&cVar_AglgkQpw, 0.0f);
  numBytes += cIf_init(&cIf_A70OWdIS, false);
  numBytes += cIf_init(&cIf_5wLJCNIS, false);
  numBytes += cBinop_init(&cBinop_WlrDvfY5, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_UkWkthuw, 1, -1);
  numBytes += cVar_init_f(&cVar_jIbOsbuG, 0.0f);
  numBytes += sVarf_init(&sVarf_H5CHMZN9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_R2qDvbAJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LN7pHLBI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NhR6rgxM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ATqffRbS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nX66Efhx, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_8r1jjJs6, 0.0f);
  numBytes += cVar_init_f(&cVar_sElN3TEl, 0.0f);
  numBytes += cIf_init(&cIf_ghj8usLp, false);
  numBytes += cIf_init(&cIf_429WOeVx, false);
  numBytes += cDelay_init(this, &cDelay_mGnL3XmW, 10.0f);
  numBytes += cIf_init(&cIf_PyCtxq3t, false);
  numBytes += cIf_init(&cIf_DRaWn2PA, false);
  numBytes += cDelay_init(this, &cDelay_6tnyDIjF, 10.0f);
  numBytes += cIf_init(&cIf_iHmKKdbn, false);
  numBytes += cIf_init(&cIf_SpNo87N9, false);
  numBytes += cDelay_init(this, &cDelay_CPh6Okrm, 10.0f);
  numBytes += cIf_init(&cIf_QxZhU89B, false);
  numBytes += cIf_init(&cIf_WIefDMrO, false);
  numBytes += cDelay_init(this, &cDelay_13bsvVmQ, 10.0f);
  numBytes += cIf_init(&cIf_Y38P0DJP, false);
  numBytes += cIf_init(&cIf_FpM58E0r, false);
  numBytes += cDelay_init(this, &cDelay_64KbzPzo, 10.0f);
  numBytes += cIf_init(&cIf_K3A5TcZ1, false);
  numBytes += cIf_init(&cIf_TE8XDhV9, false);
  numBytes += cDelay_init(this, &cDelay_AYry6BZV, 10.0f);
  numBytes += cIf_init(&cIf_kAiSoQdR, false);
  numBytes += cIf_init(&cIf_Msw0PTwr, false);
  numBytes += cDelay_init(this, &cDelay_T28BYXwx, 10.0f);
  numBytes += cIf_init(&cIf_DI3LmWyD, false);
  numBytes += cIf_init(&cIf_YIZm0osh, false);
  numBytes += cDelay_init(this, &cDelay_MB1x9Jis, 10.0f);
  numBytes += cIf_init(&cIf_PJ8UeAYl, false);
  numBytes += cIf_init(&cIf_2RdOviKl, false);
  numBytes += cDelay_init(this, &cDelay_T8bWFNYw, 10.0f);
  numBytes += cIf_init(&cIf_bjta63IU, false);
  numBytes += cIf_init(&cIf_GvRUyyFE, false);
  numBytes += cDelay_init(this, &cDelay_MWgNY9cH, 10.0f);
  numBytes += cIf_init(&cIf_xEynUhUU, false);
  numBytes += cIf_init(&cIf_HFlnCSZl, false);
  numBytes += cDelay_init(this, &cDelay_DdPsVTvk, 10.0f);
  numBytes += cIf_init(&cIf_OeAGC0oG, false);
  numBytes += cIf_init(&cIf_ePryvCLW, false);
  numBytes += cDelay_init(this, &cDelay_vRuVgbgY, 10.0f);
  numBytes += sVarf_init(&sVarf_DR2Kv0yw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0rEgGZW5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B4InUmKX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oUMHNhSx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eVkSPqQy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v6S5ZnlV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LSqe8dW4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_18NRkB6R, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_PQ0JWc7m, 0.0f);
  numBytes += cSlice_init(&cSlice_sgGbxBNa, 1, -1);
  numBytes += cVar_init_f(&cVar_JFGvcXOD, 1.0f);
  numBytes += cSlice_init(&cSlice_VYXAVzUZ, 1, -1);
  numBytes += cVar_init_f(&cVar_j0J1EHva, 0.0f);
  numBytes += cSlice_init(&cSlice_4DN050z4, 1, -1);
  numBytes += cVar_init_f(&cVar_VjQ2qqPZ, 512.0f);
  numBytes += cSlice_init(&cSlice_aikWKTNy, 1, -1);
  numBytes += cVar_init_f(&cVar_0l2dwnpE, 1.0f);
  numBytes += cSlice_init(&cSlice_gYZH7Pwl, 1, -1);
  numBytes += cVar_init_f(&cVar_2HpZ4ah4, 1.0f);
  numBytes += cDelay_init(this, &cDelay_4EsI3WKB, 20.0f);
  numBytes += cVar_init_f(&cVar_mKRYnTrN, 0.0f);
  numBytes += cIf_init(&cIf_Bun4OblK, false);
  numBytes += cIf_init(&cIf_5Mrjvlha, false);
  numBytes += cBinop_init(&cBinop_zNDqUyVr, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_pbbz9Wtf, 1, -1);
  numBytes += cVar_init_f(&cVar_3L3pXb7K, 0.0f);
  numBytes += sVarf_init(&sVarf_OThyx2wt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ikv8AkO2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MpBBLwy0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tB7Cwcz0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_32U0LF0b, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EZOpL5tY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dHpzMTnO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Yv8iwrUB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BEogxK3e, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AKkRrT9z, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_C9Z2lDRE, 0.0f);
  numBytes += cVar_init_f(&cVar_QfrneSS5, 0.0f);
  numBytes += cVar_init_f(&cVar_xramEk4y, 0.0f);
  numBytes += cVar_init_f(&cVar_9q9SOcbV, 0.0f);
  numBytes += cVar_init_f(&cVar_alVox0ps, 0.0f);
  numBytes += cVar_init_f(&cVar_YsZqaxoL, 1.0f);
  numBytes += cSlice_init(&cSlice_diSGsyuK, 1, -1);
  numBytes += cVar_init_f(&cVar_qy2T9dSm, 0.5f);
  numBytes += cVar_init_f(&cVar_kjfh58CW, 0.0f);
  numBytes += cVar_init_f(&cVar_Ld4SavDd, 0.0f);
  numBytes += cIf_init(&cIf_onpd118V, false);
  numBytes += cIf_init(&cIf_joGt9nQB, false);
  numBytes += cDelay_init(this, &cDelay_O1dNuno0, 10.0f);
  numBytes += cIf_init(&cIf_5F8fEERk, false);
  numBytes += cIf_init(&cIf_kIooVKKW, false);
  numBytes += cDelay_init(this, &cDelay_L7THvo0J, 10.0f);
  numBytes += cIf_init(&cIf_adj6PEyh, false);
  numBytes += cIf_init(&cIf_pcVMcAcB, false);
  numBytes += cDelay_init(this, &cDelay_6wmQ7Kcy, 10.0f);
  numBytes += cIf_init(&cIf_NeEbBbMD, false);
  numBytes += cIf_init(&cIf_7byDdM3i, false);
  numBytes += cDelay_init(this, &cDelay_kF9c4RKq, 10.0f);
  numBytes += cIf_init(&cIf_GiPeOTOk, false);
  numBytes += cIf_init(&cIf_6fHzxva6, false);
  numBytes += cDelay_init(this, &cDelay_e4XKHAxA, 10.0f);
  numBytes += cIf_init(&cIf_oM4jF1Bo, false);
  numBytes += cIf_init(&cIf_UjYI7Lot, false);
  numBytes += cDelay_init(this, &cDelay_xLLX1hJF, 10.0f);
  numBytes += cIf_init(&cIf_NgY4v3F4, false);
  numBytes += cIf_init(&cIf_wzMRsxGt, false);
  numBytes += cDelay_init(this, &cDelay_jop5rzk7, 10.0f);
  numBytes += cIf_init(&cIf_UB0zNEpM, false);
  numBytes += cIf_init(&cIf_WSq9HN6T, false);
  numBytes += cDelay_init(this, &cDelay_cR6J84ma, 10.0f);
  numBytes += cIf_init(&cIf_z3SRlci1, false);
  numBytes += cIf_init(&cIf_Yp4EAEDN, false);
  numBytes += cDelay_init(this, &cDelay_ISrqKmGW, 10.0f);
  numBytes += cIf_init(&cIf_UCsewp2k, false);
  numBytes += cIf_init(&cIf_ggLaSgcE, false);
  numBytes += cDelay_init(this, &cDelay_Duj4M3bC, 10.0f);
  numBytes += cIf_init(&cIf_jfuGJxw3, false);
  numBytes += cIf_init(&cIf_uemAYJap, false);
  numBytes += cDelay_init(this, &cDelay_Y25HzZLf, 10.0f);
  numBytes += cIf_init(&cIf_IlEGdRQc, false);
  numBytes += cIf_init(&cIf_ljH4Bqer, false);
  numBytes += cDelay_init(this, &cDelay_tXueBXUs, 10.0f);
  numBytes += sVarf_init(&sVarf_qZUXz2YZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eTaAMX9s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nWlBCSg6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4ntEynzN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mXCbseIo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_p4F0BAYH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5IOdNNRu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Q9CQPMxC, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_HX9UGaL7, 0.0f);
  numBytes += cSlice_init(&cSlice_2eav210C, 1, -1);
  numBytes += cVar_init_f(&cVar_nHBDsWuT, 1.0f);
  numBytes += cSlice_init(&cSlice_Xr9s3uT0, 1, -1);
  numBytes += cVar_init_f(&cVar_Fu0RGTOt, 0.0f);
  numBytes += cSlice_init(&cSlice_9LIaU37Q, 1, -1);
  numBytes += cVar_init_f(&cVar_zzD7s9V3, 512.0f);
  numBytes += cSlice_init(&cSlice_CLVvaqQS, 1, -1);
  numBytes += cVar_init_f(&cVar_LeHQTddB, 1.0f);
  numBytes += cSlice_init(&cSlice_0Oy9qBn4, 1, -1);
  numBytes += cVar_init_f(&cVar_1ajPrGv5, 1.0f);
  numBytes += cDelay_init(this, &cDelay_5YzlATna, 20.0f);
  numBytes += cVar_init_f(&cVar_7ai6HrlG, 0.0f);
  numBytes += cIf_init(&cIf_kTknJ4IN, false);
  numBytes += cIf_init(&cIf_5x4NnjQJ, false);
  numBytes += cBinop_init(&cBinop_clmRpkFc, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_6zlHNZR8, 1, -1);
  numBytes += cVar_init_f(&cVar_eRgFbCt3, 0.0f);
  numBytes += sVarf_init(&sVarf_ERmPhFNj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_c6R3xGu7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QPjZbYpS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gotQyIzU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RwKEqzPj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XlK9vW7e, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_0HPs7n0s, 0.0f);
  numBytes += cVar_init_f(&cVar_WLwxyyF5, 0.0f);
  numBytes += cIf_init(&cIf_eggSzFzt, false);
  numBytes += cIf_init(&cIf_gFmnjIpF, false);
  numBytes += cDelay_init(this, &cDelay_hyW5L8Ah, 10.0f);
  numBytes += cIf_init(&cIf_v6Dkx8HX, false);
  numBytes += cIf_init(&cIf_IAWhjizE, false);
  numBytes += cDelay_init(this, &cDelay_vZAz0x7M, 10.0f);
  numBytes += cIf_init(&cIf_mLwCt70C, false);
  numBytes += cIf_init(&cIf_vbMwGUKF, false);
  numBytes += cDelay_init(this, &cDelay_Js4X4xq3, 10.0f);
  numBytes += cIf_init(&cIf_NWPwxPzm, false);
  numBytes += cIf_init(&cIf_hPaC37Mp, false);
  numBytes += cDelay_init(this, &cDelay_kWO6CMo4, 10.0f);
  numBytes += cIf_init(&cIf_1xL1kYSN, false);
  numBytes += cIf_init(&cIf_74CH0Ljv, false);
  numBytes += cDelay_init(this, &cDelay_8LImJnQK, 10.0f);
  numBytes += cIf_init(&cIf_0F90dNht, false);
  numBytes += cIf_init(&cIf_npVY4Oqz, false);
  numBytes += cDelay_init(this, &cDelay_sOcvxEzV, 10.0f);
  numBytes += cIf_init(&cIf_fGIKexGu, false);
  numBytes += cIf_init(&cIf_ALJProw5, false);
  numBytes += cDelay_init(this, &cDelay_C5cZOPEH, 10.0f);
  numBytes += cIf_init(&cIf_sfjpHQRF, false);
  numBytes += cIf_init(&cIf_xccO4mrR, false);
  numBytes += cDelay_init(this, &cDelay_2z9mC6Mz, 10.0f);
  numBytes += cIf_init(&cIf_tndYhfsl, false);
  numBytes += cIf_init(&cIf_YIlwxxuN, false);
  numBytes += cDelay_init(this, &cDelay_zeU7jZJq, 10.0f);
  numBytes += cIf_init(&cIf_Djv8ptfc, false);
  numBytes += cIf_init(&cIf_RkfA5eeQ, false);
  numBytes += cDelay_init(this, &cDelay_UAU5218J, 10.0f);
  numBytes += cIf_init(&cIf_E3i1gpjg, false);
  numBytes += cIf_init(&cIf_wxvmEQrE, false);
  numBytes += cDelay_init(this, &cDelay_Ux2ecb2b, 10.0f);
  numBytes += cIf_init(&cIf_5f85Zpi3, false);
  numBytes += cIf_init(&cIf_rUmjFHZl, false);
  numBytes += cDelay_init(this, &cDelay_VT2ypioo, 10.0f);
  numBytes += sVarf_init(&sVarf_TNdJCnQt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rhbTpn59, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ot2rT9kl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_p9kqwrwD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WzFCRfe7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TfEC67vl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AjqCR0lt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HhvHY0BH, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_avpRM5Vt, 0.0f);
  numBytes += cSlice_init(&cSlice_9EZytB0y, 1, -1);
  numBytes += cVar_init_f(&cVar_IeU4aKDO, 1.0f);
  numBytes += cSlice_init(&cSlice_BevxgnMZ, 1, -1);
  numBytes += cVar_init_f(&cVar_TC7GY2No, 0.0f);
  numBytes += cSlice_init(&cSlice_Pw10QKrf, 1, -1);
  numBytes += cVar_init_f(&cVar_YtJXFepk, 512.0f);
  numBytes += cSlice_init(&cSlice_bnukTEZ1, 1, -1);
  numBytes += cVar_init_f(&cVar_Yzx6fMDl, 1.0f);
  numBytes += cSlice_init(&cSlice_xEXd3Xej, 1, -1);
  numBytes += cVar_init_f(&cVar_MzTReQOz, 1.0f);
  numBytes += cDelay_init(this, &cDelay_RYydmjCB, 20.0f);
  numBytes += cVar_init_f(&cVar_sRIJ9n69, 0.0f);
  numBytes += cIf_init(&cIf_vS3Ij8CC, false);
  numBytes += cIf_init(&cIf_Oi4x9DGK, false);
  numBytes += cBinop_init(&cBinop_5Vg1s1yo, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_Ri0pOpE4, 1, -1);
  numBytes += cVar_init_f(&cVar_ofd3WStB, 0.0f);
  numBytes += sVarf_init(&sVarf_gpAdmsSq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8bYUxfBB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hzPbZWb5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qYUz2bxN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2mJHspjJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fVCODvfX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CJxtPuJv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zYwEtN7f, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fp4KBYrl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4qYhRKJu, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Ks0bMys5, 0.0f);
  numBytes += cVar_init_f(&cVar_rNGgIymJ, 0.0f);
  numBytes += cVar_init_f(&cVar_lIDqKwSJ, 0.0f);
  numBytes += cVar_init_f(&cVar_qk0iGwb7, 0.0f);
  numBytes += cVar_init_f(&cVar_mJAlRwOA, 0.0f);
  numBytes += cVar_init_f(&cVar_4W41IuiM, 1.0f);
  numBytes += cSlice_init(&cSlice_BWs1tudI, 1, -1);
  numBytes += cVar_init_f(&cVar_VDrhDdzp, 0.5f);
  numBytes += cVar_init_f(&cVar_RN1AOJk8, 0.0f);
  numBytes += cVar_init_f(&cVar_1Ak6Ct8m, 0.0f);
  numBytes += cIf_init(&cIf_8PARhZfg, false);
  numBytes += cIf_init(&cIf_CWLWCGot, false);
  numBytes += cDelay_init(this, &cDelay_9K3LX7IB, 10.0f);
  numBytes += cIf_init(&cIf_FQXQqtO7, false);
  numBytes += cIf_init(&cIf_RHESocK4, false);
  numBytes += cDelay_init(this, &cDelay_Bve9FkVh, 10.0f);
  numBytes += cIf_init(&cIf_f2k6rPbg, false);
  numBytes += cIf_init(&cIf_jRwDXfzD, false);
  numBytes += cDelay_init(this, &cDelay_RtCaaW6r, 10.0f);
  numBytes += cIf_init(&cIf_O9njpAlv, false);
  numBytes += cIf_init(&cIf_q1WLixiy, false);
  numBytes += cDelay_init(this, &cDelay_alNcPjuf, 10.0f);
  numBytes += cIf_init(&cIf_zq3MsY6W, false);
  numBytes += cIf_init(&cIf_bGqUJuMn, false);
  numBytes += cDelay_init(this, &cDelay_NYTbRTrx, 10.0f);
  numBytes += cIf_init(&cIf_8Ht0wuWw, false);
  numBytes += cIf_init(&cIf_VP8d3Rvq, false);
  numBytes += cDelay_init(this, &cDelay_6rLsjQDP, 10.0f);
  numBytes += cIf_init(&cIf_UISHmHgS, false);
  numBytes += cIf_init(&cIf_CasJI4c5, false);
  numBytes += cDelay_init(this, &cDelay_s5dOQDlj, 10.0f);
  numBytes += cIf_init(&cIf_HcFKwAUe, false);
  numBytes += cIf_init(&cIf_h3GmSm5U, false);
  numBytes += cDelay_init(this, &cDelay_4hZwyo70, 10.0f);
  numBytes += cIf_init(&cIf_Ais36E1z, false);
  numBytes += cIf_init(&cIf_KwVBhTdM, false);
  numBytes += cDelay_init(this, &cDelay_p3yg9CUR, 10.0f);
  numBytes += cIf_init(&cIf_wsyOQihT, false);
  numBytes += cIf_init(&cIf_hYoWfZvq, false);
  numBytes += cDelay_init(this, &cDelay_srSARrj8, 10.0f);
  numBytes += cIf_init(&cIf_lFPJrNN8, false);
  numBytes += cIf_init(&cIf_zkzfz5XE, false);
  numBytes += cDelay_init(this, &cDelay_hue7kVS0, 10.0f);
  numBytes += cIf_init(&cIf_7EJ1Jcb5, false);
  numBytes += cIf_init(&cIf_luV6DaNB, false);
  numBytes += cDelay_init(this, &cDelay_uvrSLIIy, 10.0f);
  numBytes += sVarf_init(&sVarf_92FWFDH7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lwnG2ZmE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ijq6Votl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HnPtuyGZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xnp1cOat, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PCj0ooER, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HrBYeENf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8kZAHZze, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_adlfWpm1, 0.0f);
  numBytes += cSlice_init(&cSlice_3VGD6U4J, 1, -1);
  numBytes += cVar_init_f(&cVar_52QPa1GD, 1.0f);
  numBytes += cSlice_init(&cSlice_x8lvXa0f, 1, -1);
  numBytes += cVar_init_f(&cVar_sUhhHzfa, 0.0f);
  numBytes += cSlice_init(&cSlice_FNqgRRii, 1, -1);
  numBytes += cVar_init_f(&cVar_3UJBlSrN, 512.0f);
  numBytes += cSlice_init(&cSlice_0BO4c30i, 1, -1);
  numBytes += cVar_init_f(&cVar_XCh9bzr0, 1.0f);
  numBytes += cSlice_init(&cSlice_AS1kZf2r, 1, -1);
  numBytes += cVar_init_f(&cVar_XXVo7NES, 1.0f);
  numBytes += cDelay_init(this, &cDelay_KqPWIewa, 20.0f);
  numBytes += cVar_init_f(&cVar_nN3FqDLq, 0.0f);
  numBytes += cIf_init(&cIf_iTug8sI6, false);
  numBytes += cIf_init(&cIf_lQ7Vq929, false);
  numBytes += cBinop_init(&cBinop_j4U9ywzT, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_gEsQZv7z, 1, -1);
  numBytes += cVar_init_f(&cVar_Vd1zShIP, 0.0f);
  numBytes += sVarf_init(&sVarf_bhk2YBwq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4FqNZHaC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1c25nviz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iO4RJbmN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NgrFMjfK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qVU2QHz3, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_XI0JeX7y, 0.0f);
  numBytes += cVar_init_f(&cVar_u8YlXVYC, 0.0f);
  numBytes += cIf_init(&cIf_OUFQeyVA, false);
  numBytes += cIf_init(&cIf_lMHcLhbk, false);
  numBytes += cDelay_init(this, &cDelay_C8Y1eer5, 10.0f);
  numBytes += cIf_init(&cIf_Dy7jnDoe, false);
  numBytes += cIf_init(&cIf_dP1XfxYy, false);
  numBytes += cDelay_init(this, &cDelay_Ctbkvi02, 10.0f);
  numBytes += cIf_init(&cIf_84Rlw4bt, false);
  numBytes += cIf_init(&cIf_TX9bo1Qf, false);
  numBytes += cDelay_init(this, &cDelay_un9WwyFC, 10.0f);
  numBytes += cIf_init(&cIf_EQswa34K, false);
  numBytes += cIf_init(&cIf_5oGhZbVf, false);
  numBytes += cDelay_init(this, &cDelay_Jl7gv0B1, 10.0f);
  numBytes += cIf_init(&cIf_boahbzXI, false);
  numBytes += cIf_init(&cIf_DrbzBEOv, false);
  numBytes += cDelay_init(this, &cDelay_eIA3jfjV, 10.0f);
  numBytes += cIf_init(&cIf_TNg7FyOA, false);
  numBytes += cIf_init(&cIf_oWKbDK1m, false);
  numBytes += cDelay_init(this, &cDelay_f7xbR6NN, 10.0f);
  numBytes += cIf_init(&cIf_BbeF0xwV, false);
  numBytes += cIf_init(&cIf_h3bcADmk, false);
  numBytes += cDelay_init(this, &cDelay_yyzkE2rs, 10.0f);
  numBytes += cIf_init(&cIf_ldowuEux, false);
  numBytes += cIf_init(&cIf_zu9HItwH, false);
  numBytes += cDelay_init(this, &cDelay_oQrx20Aa, 10.0f);
  numBytes += cIf_init(&cIf_8kNFJpgh, false);
  numBytes += cIf_init(&cIf_a5hCCRRg, false);
  numBytes += cDelay_init(this, &cDelay_7CxrSv7y, 10.0f);
  numBytes += cIf_init(&cIf_cvPYxhxU, false);
  numBytes += cIf_init(&cIf_pgTymucB, false);
  numBytes += cDelay_init(this, &cDelay_3L9OAYmN, 10.0f);
  numBytes += cIf_init(&cIf_K7LolLND, false);
  numBytes += cIf_init(&cIf_hfjaHmPT, false);
  numBytes += cDelay_init(this, &cDelay_IRbqJv4n, 10.0f);
  numBytes += cIf_init(&cIf_l1zJCirT, false);
  numBytes += cIf_init(&cIf_UQ9KrUDI, false);
  numBytes += cDelay_init(this, &cDelay_dY2ImBl3, 10.0f);
  numBytes += sVarf_init(&sVarf_Jb5dyiII, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iMjwYf8N, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jbDc2HCY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BXcmlUfz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UGEfQjFp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BR6oV6w8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ckrcODWw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YXY1mb8o, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_gfQuqo7q, 0.0f);
  numBytes += cSlice_init(&cSlice_sz41cj3r, 1, -1);
  numBytes += cVar_init_f(&cVar_P17kuMNp, 1.0f);
  numBytes += cSlice_init(&cSlice_ZWfD9NtT, 1, -1);
  numBytes += cVar_init_f(&cVar_sfA1s3Sw, 0.0f);
  numBytes += cSlice_init(&cSlice_rGJJAaxR, 1, -1);
  numBytes += cVar_init_f(&cVar_43GfZYBd, 512.0f);
  numBytes += cSlice_init(&cSlice_xZbXq0Kx, 1, -1);
  numBytes += cVar_init_f(&cVar_czjYz9fX, 1.0f);
  numBytes += cSlice_init(&cSlice_4WIqwxo2, 1, -1);
  numBytes += cVar_init_f(&cVar_WoC2ol27, 1.0f);
  numBytes += cDelay_init(this, &cDelay_0zdiP8gp, 20.0f);
  numBytes += cVar_init_f(&cVar_VTAdhxfX, 0.0f);
  numBytes += cIf_init(&cIf_iOyEEMsI, false);
  numBytes += cIf_init(&cIf_Mjn3VTJO, false);
  numBytes += cBinop_init(&cBinop_uXoS3dDO, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_9dT6tRce, 1, -1);
  numBytes += cVar_init_f(&cVar_TsITJvRp, 0.0f);
  numBytes += sVarf_init(&sVarf_D76jqmQe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_D6JHMBiy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lETMH4cI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1PZJkIHA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7mJFZV7y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RJKl7wYt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_81CoeDXV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w6a3ASQ3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sAIBfR45, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SxIn0Huo, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Jip6Ri9K, 0.0f);
  numBytes += cVar_init_f(&cVar_i83ItpF4, 0.0f);
  numBytes += cVar_init_f(&cVar_x2wRLsCL, 0.0f);
  numBytes += sVarf_init(&sVarf_Nf2r6lEi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CHKRUlq3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_M8gkB6Bl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QecjrQDg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nB28qran, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UY3fjGpk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pPmQH1iD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_glUiwL60, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_si5ABmfj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Os5dzgeG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LtQs6aUU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7zzFDQlP, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_BCUizeyW);
  sEnv_free(&sEnv_KM6l8BCd);
  sEnv_free(&sEnv_ZbWcTrEe);
  sEnv_free(&sEnv_jRZfyZe7);
  sEnv_free(&sEnv_unUtm1qA);
  sEnv_free(&sEnv_dsffpoPy);
  sEnv_free(&sEnv_kUbljVQe);
  sEnv_free(&sEnv_Wk53PUtk);
  sEnv_free(&sEnv_a1NYBl4D);
  sEnv_free(&sEnv_ZTQubMs0);
  sEnv_free(&sEnv_QFxVoMhr);
  sEnv_free(&sEnv_4VlCUEcL);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vtAygWAU_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7Qr5j9bh_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m6kB4VNR_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zXdjYFC4_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M90bJM04_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vwLNOqpX_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d11NdOMD_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0Cc6vpCO_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f58QkQk9_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CQ7ufHbf_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LaMcOniv_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_47ui3TrQ_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RaXFs8t5_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dv9OfEue_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WHR74Pih_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vqDWI6aa_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4dGV1Bmm_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pauCVrU5_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OmALedDF_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_15sngfiw_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MV3sLiHP_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DxDbfSLk_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f9uYtK8S_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_D5hNU51G_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BrC4OvhH_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Sx5qgBgG_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s7hbKDLj_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f7MlT223_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sRmoI3PF_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YO2vHiOs_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RQQiJUaY_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fsVnnMh9_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qGOPsxwk_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PdSTiEnU_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eP7unyu5_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eXIyxPZD_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tc3wVE1z_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pWFq4PdX_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kAqvampd_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EIPaZai5_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pLdYZGuY_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ls0Ioo6I_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cwDMaQ3v_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ycOpbzhq_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gLwTBLFx_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KoWGF65p_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2nCD967D_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qVspi1CC_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SDY01T5e_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_V4tTKxWy_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Z3rrgvdZ_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uFPlEcg6_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YSvClWhB_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c87b9xKB_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yXHzWMBz_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hCNxj7fa_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MKufJJhs_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jwg0BVYC_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jyb17J7t_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GdX12s4I_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GTEnmwau_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LCi0PAB5_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NHhlrOw9_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DXno7MHr_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jbU572Kj_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8nUMSjxs_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NWRTSUmf_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pPixn0UN_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fGbmJubB_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ttZ4dY9j_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m0DEBlAj_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rKWJFMgn_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zz7hYlhB_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4LGlDM8c_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AWjjOHCs_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qK823ny8_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BBhEccgB_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YR9XrXym_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3JI383kK_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hrKO8YpD_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mLvQZyXz_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZqW4VYu8_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qAtnrP1j_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5xupRvvA_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_puzMgJQs_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WQFva1jt_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0KVyg2MB_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vfpE7BsO_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sPIXNCq0_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pRWwYELw_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rpGLCyqN_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ujAmU9tg_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oJWXHGlY_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_wKbD1Z71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_an4p3w5o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_TWFYKzea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KdzjJyKl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_2iMaYoBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_exXijmko_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_rEgLR6MH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YSGlSTFh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Mwv2yz7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0i1kkAOM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_KpKkfzlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uNecbRaT_sendMessage);
  cMsg_hccWQ6KX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_uNecbRaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KpKkfzlI, 1, m, &cVar_KpKkfzlI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9kxEd14H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FELzqVMz_sendMessage(_c, 0, m);
  cMsg_x8DBMpcV_sendMessage(_c, 0, m);
  cMsg_vqfB7FyK_sendMessage(_c, 0, m);
  cMsg_T5DyXBVr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_1PbEQr7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zPCN1skt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_LedYrwCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_li5tdiPj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_0GjL3vM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oE7wmHgq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_J1Cskvl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QjGcbAVe_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0aeie5GA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lFy7032b_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DcBRfLVB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iJ7pJJLO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hB8bXNLb, 0, m, &cSlice_hB8bXNLb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oMWHIVkt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_hB8bXNLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_p8yify8b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_p8yify8b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_of5s3swg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_p8yify8b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_p8yify8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_f7MlT223_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_igDE3udd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_M6hVDK8T_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_2DzhsS2t, 0, m, &cIf_2DzhsS2t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_2DzhsS2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0Job3943_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_tap6Dlbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_8EszXcGQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_SfeyoWki_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_orodcjJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_u44qF4FG, HV_BINOP_POW, 0, m, &cBinop_u44qF4FG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u44qF4FG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fWRHajFT, 0, m, &cIf_fWRHajFT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zAAwY7zs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8McL7OQl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JEcvfTs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xVG8NeBd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JhXcJDu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tap6Dlbh, 0, m, &cIf_tap6Dlbh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xVG8NeBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tap6Dlbh, 1, m, &cIf_tap6Dlbh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SfeyoWki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_zAAwY7zs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8EszXcGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_fWRHajFT, 0, m, &cIf_fWRHajFT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8McL7OQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u44qF4FG, HV_BINOP_POW, 1, m, &cBinop_u44qF4FG_sendMessage);
  cMsg_orodcjJM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_fWRHajFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_flBbBdbJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_M6hVDK8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2DzhsS2t, 1, m, &cIf_2DzhsS2t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0Job3943_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xol2zKgm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ya7WAeNW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EfKfeDHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JEcvfTs5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JhXcJDu3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gpykRmBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fWRHajFT, 1, m, &cIf_fWRHajFT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WMNcEhEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rRD4VSWG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rRD4VSWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_flBbBdbJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UcrukFKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_EfKfeDHg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ya7WAeNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gpykRmBn, HV_BINOP_GREATER_THAN, 1, m, &cBinop_gpykRmBn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Xol2zKgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WMNcEhEG, HV_BINOP_EQ, 1, m, &cBinop_WMNcEhEG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H5TYXpbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_igDE3udd, 0, m, &cVar_igDE3udd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qp5FacyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gpykRmBn, HV_BINOP_GREATER_THAN, 0, m, &cBinop_gpykRmBn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SK2TcAJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WMNcEhEG, HV_BINOP_EQ, 0, m, &cBinop_WMNcEhEG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LRTP4uAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UcrukFKi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_c4bLdeEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_J8r7ngMG_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_t0JWTusd, 0, m, &cIf_t0JWTusd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_t0JWTusd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CmaGhhtG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BJFaGDBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ysBxnRWW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NQYoWeqW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_G7tpW08c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ElziK6c6, HV_BINOP_POW, 0, m, &cBinop_ElziK6c6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ElziK6c6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FRB3xPKG, 0, m, &cIf_FRB3xPKG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fuTYRHiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_U2rbPHtl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cJnty5PT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QuO8xagw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gOH9xHZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BJFaGDBi, 0, m, &cIf_BJFaGDBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QuO8xagw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BJFaGDBi, 1, m, &cIf_BJFaGDBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NQYoWeqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_fuTYRHiV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ysBxnRWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_FRB3xPKG, 0, m, &cIf_FRB3xPKG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U2rbPHtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ElziK6c6, HV_BINOP_POW, 1, m, &cBinop_ElziK6c6_sendMessage);
  cMsg_G7tpW08c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_FRB3xPKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KBb017TB_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CZwrkxP0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_J8r7ngMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t0JWTusd, 1, m, &cIf_t0JWTusd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CmaGhhtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_35ViTH0p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_81zkeybK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Fc0hdZGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cJnty5PT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gOH9xHZp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ue7jrKtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FRB3xPKG, 1, m, &cIf_FRB3xPKG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lKFeQ2tn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rUA0VFwB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rUA0VFwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KBb017TB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CZwrkxP0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7bDCg5D7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Fc0hdZGU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_35ViTH0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lKFeQ2tn, HV_BINOP_EQ, 1, m, &cBinop_lKFeQ2tn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_81zkeybK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ue7jrKtg, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Ue7jrKtg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hIBNH3hF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lKFeQ2tn, HV_BINOP_EQ, 0, m, &cBinop_lKFeQ2tn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NsHlfAdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7bDCg5D7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_LXhPzFZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c4bLdeEJ, 0, m, &cVar_c4bLdeEJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cOCoWvqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ue7jrKtg, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Ue7jrKtg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_JrkBlI8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_X0sTLQBF_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ylhlStLU, 0, m, &cIf_ylhlStLU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_ylhlStLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_i8Y0B27j_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CAxeqa6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_UUY792qi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_xE0SMGWR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_ibw280bR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_THKNKWhM, HV_BINOP_POW, 0, m, &cBinop_THKNKWhM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_THKNKWhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AofnNpPq, 0, m, &cIf_AofnNpPq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VW816vyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_GK4iVnnT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ww7NlDSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CAxeqa6Z, 0, m, &cIf_CAxeqa6Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jZwfG50H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZneIQPvr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZneIQPvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CAxeqa6Z, 1, m, &cIf_CAxeqa6Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xE0SMGWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_VW816vyv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UUY792qi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AofnNpPq, 0, m, &cIf_AofnNpPq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GK4iVnnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_THKNKWhM, HV_BINOP_POW, 1, m, &cBinop_THKNKWhM_sendMessage);
  cMsg_ibw280bR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_AofnNpPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3OxnriqY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_X0sTLQBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ylhlStLU, 1, m, &cIf_ylhlStLU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i8Y0B27j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WZE1uCT0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yZTSqCCE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D3I5paVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jZwfG50H_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ww7NlDSd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Fn0qvvRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AofnNpPq, 1, m, &cIf_AofnNpPq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UIXMSc1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_83Ptv6IC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_83Ptv6IC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_3OxnriqY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9K5ftlHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_D3I5paVI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WZE1uCT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UIXMSc1C, HV_BINOP_EQ, 1, m, &cBinop_UIXMSc1C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yZTSqCCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fn0qvvRt, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Fn0qvvRt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TH372THX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UIXMSc1C, HV_BINOP_EQ, 0, m, &cBinop_UIXMSc1C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yXY1yaMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9K5ftlHG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_rSfWjGIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JrkBlI8a, 0, m, &cVar_JrkBlI8a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WgCIgo8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fn0qvvRt, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Fn0qvvRt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_61YCAbcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AgkbW42o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1QwWeKE8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rjzmKeH3, 0, m, &cSlice_rjzmKeH3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_whHVosGW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_rjzmKeH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hlG6suVU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hlG6suVU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_BEjQ8BTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hlG6suVU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hlG6suVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Sx5qgBgG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_whHVosGW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9wmEFDEo, 0, m, &cSlice_9wmEFDEo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_iJ7pJJLO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9wmEFDEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_q20qZScn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_q20qZScn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_gu1mKmbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_q20qZScn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_q20qZScn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YO2vHiOs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oMWHIVkt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mmteMlCh, 0, m, &cSlice_mmteMlCh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_i99wmyzY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_mmteMlCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_J2s6VZbx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_J2s6VZbx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_1Zgt3ank_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_J2s6VZbx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_J2s6VZbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_s7hbKDLj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_i99wmyzY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WjpGWqs3, 0, m, &cSlice_WjpGWqs3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_WjpGWqs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4huzPwGT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4huzPwGT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_9nVITjRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4huzPwGT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_4huzPwGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sRmoI3PF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KUXKUQov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mIs1bR8N, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_38WolyjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1aqcl6Rj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_V9ZDWt9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r4iL8Oa0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RMWKE7Ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_U2WfoVfU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wDf7K2mo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B7rvE1jF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dxsdirKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Kr4yc0Nu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_Kr4yc0Nu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EK6TtkYa, HV_BINOP_DIVIDE, 1, m, &cBinop_EK6TtkYa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nrgPIS0X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ubZlGCXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_eiMa1TkR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mkGGzu17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ubZlGCXF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eiMa1TkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EK6TtkYa, HV_BINOP_DIVIDE, 0, m, &cBinop_EK6TtkYa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nrgPIS0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mkGGzu17_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EK6TtkYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jWWGMsLF, HV_BINOP_MULTIPLY, 1, m, &cBinop_jWWGMsLF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jWWGMsLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cGrVYOWr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ui0wUhyB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_VKjeSgx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hHcBb5wh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_TFhNfxyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8vpwr8J6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_11s0Ba4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_xhd2UzIO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xhd2UzIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jWWGMsLF, HV_BINOP_MULTIPLY, 0, m, &cBinop_jWWGMsLF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kJFwnQh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_OpSTmJYW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OpSTmJYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sFqTGvTV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_641uqvkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aqlBaWgD, 1, m, &cVar_aqlBaWgD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_aqlBaWgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_awiRuqGo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ZVhVpL0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QhVq19BG, HV_BINOP_MULTIPLY, 1, m, &cBinop_QhVq19BG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GWHEl0Bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZVhVpL0H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Zui9T056_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_bhtVpaSP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bhtVpaSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sQ1FMGHd, HV_BINOP_MULTIPLY, 1, m, &cBinop_sQ1FMGHd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i038SCkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CcArPbrJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_CcArPbrJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_37MeNhmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_i038SCkp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aZeWVx62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oyYK1We8, HV_BINOP_MULTIPLY, 1, m, &cBinop_oyYK1We8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K1ZitC0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Vt7KAQYk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Vt7KAQYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xcVGHm3r, HV_BINOP_MULTIPLY, 1, m, &cBinop_xcVGHm3r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_nzfvQfl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2ROUgz4X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_11s0Ba4x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pgnuzJJF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Hw0dSvtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_kJFwnQh4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ui0wUhyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_TFhNfxyy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cGrVYOWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_VKjeSgx0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_hHcBb5wh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qGOPsxwk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8vpwr8J6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fsVnnMh9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_6mm1VXpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RQQiJUaY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sFqTGvTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8UcORWS7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8UcORWS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VCgINkwx, HV_BINOP_MULTIPLY, 1, m, &cBinop_VCgINkwx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VCgINkwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zEyGYoIu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zEyGYoIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6mm1VXpB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_awiRuqGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8FdMQnLh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8FdMQnLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WGO1udDr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pBjDBthm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5s8HSTZ3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wQPJTvuG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SQRf9iZP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bnUQ5sqs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QhVq19BG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KUXKUQov_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sQ1FMGHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_38WolyjV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CcArPbrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V9ZDWt9H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_oyYK1We8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RMWKE7Ko_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xcVGHm3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wDf7K2mo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_OnBgSVrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nzfvQfl5, 0, m, &cVar_nzfvQfl5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EWRxcl1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hw0dSvtT, 1, m, &cVar_Hw0dSvtT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wQPJTvuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CcArPbrJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_CcArPbrJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WGO1udDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_bnUQ5sqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QhVq19BG, HV_BINOP_MULTIPLY, 0, m, &cBinop_QhVq19BG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5s8HSTZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oyYK1We8, HV_BINOP_MULTIPLY, 0, m, &cBinop_oyYK1We8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SQRf9iZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sQ1FMGHd, HV_BINOP_MULTIPLY, 0, m, &cBinop_sQ1FMGHd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pBjDBthm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xcVGHm3r, HV_BINOP_MULTIPLY, 0, m, &cBinop_xcVGHm3r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pgnuzJJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aqlBaWgD, 0, m, &cVar_aqlBaWgD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2ROUgz4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hw0dSvtT, 0, m, &cVar_Hw0dSvtT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1zjep1AD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hCaAZUX0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_q5h1YGYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xw6YiCE5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ljytrgF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_acifBcx4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GV7XyF8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uJg4kzbC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lXpMtPVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_myDvPIUP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_myDvPIUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Ydzc9Pa, HV_BINOP_DIVIDE, 1, m, &cBinop_1Ydzc9Pa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5OjRU8JF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_qlOykKk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_56QNXs9i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Hs83M7ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_qlOykKk6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_56QNXs9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Ydzc9Pa, HV_BINOP_DIVIDE, 0, m, &cBinop_1Ydzc9Pa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5OjRU8JF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hs83M7ry_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_1Ydzc9Pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ML7f2CBL, HV_BINOP_MULTIPLY, 1, m, &cBinop_ML7f2CBL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ML7f2CBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IutufSG7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kwSoj9nr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_wE3kIUjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4ZO44ALb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_n4rApBn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dnvHJBVa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_k4yZUd0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_nIKljl9B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nIKljl9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ML7f2CBL, HV_BINOP_MULTIPLY, 0, m, &cBinop_ML7f2CBL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hdP6oxD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ErZLKmBH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ErZLKmBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QW0e3Adq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0Z1ZUpcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WsXr7t49, HV_BINOP_MULTIPLY, 1, m, &cBinop_WsXr7t49_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QmyVP3Ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pDqMG2it, 1, m, &cVar_pDqMG2it_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OWYQxIP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N0WPMcWq, HV_BINOP_MULTIPLY, 1, m, &cBinop_N0WPMcWq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nIRYiqfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2J860AcI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2J860AcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uJeKwntL, HV_BINOP_MULTIPLY, 1, m, &cBinop_uJeKwntL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_pDqMG2it_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MBKGw6vJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_orzAmyRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AZgnXhN4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_k4yZUd0m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VyMiAb6q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_dVgKpR9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_hdP6oxD9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IutufSG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_wE3kIUjw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kwSoj9nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_n4rApBn0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_4ZO44ALb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eXIyxPZD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dnvHJBVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eP7unyu5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_u83DAr6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PdSTiEnU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QW0e3Adq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OKVd7Fke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OKVd7Fke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dfo1IAeF, HV_BINOP_MULTIPLY, 1, m, &cBinop_dfo1IAeF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dfo1IAeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oImIo0NP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oImIo0NP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_u83DAr6g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MBKGw6vJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iPJQOM0d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iPJQOM0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S6QOUq2X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_edtQNmbp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CxDoD2JB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_014ioQot_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vQpNkFrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1zjep1AD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WsXr7t49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q5h1YGYc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_N0WPMcWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ljytrgF6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_uJeKwntL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GV7XyF8G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_tlklmzaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dVgKpR9V, 1, m, &cVar_dVgKpR9V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TRFIbxQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_orzAmyRG, 0, m, &cVar_orzAmyRG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AZgnXhN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dVgKpR9V, 0, m, &cVar_dVgKpR9V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VyMiAb6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pDqMG2it, 0, m, &cVar_pDqMG2it_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CxDoD2JB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WsXr7t49, HV_BINOP_MULTIPLY, 0, m, &cBinop_WsXr7t49_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_edtQNmbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N0WPMcWq, HV_BINOP_MULTIPLY, 0, m, &cBinop_N0WPMcWq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_014ioQot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vQpNkFrr, HV_BINOP_MULTIPLY, 0, m, &cBinop_vQpNkFrr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S6QOUq2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uJeKwntL, HV_BINOP_MULTIPLY, 0, m, &cBinop_uJeKwntL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vtyMbtYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ad44Ybgc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vCEnWfhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iQo1KLlG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eOYTqy6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ioW7baIw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jGN27Eo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IeftKuW4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mmMRZOBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1YsUL5wp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Vob4DQDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0dgTYGFU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_0dgTYGFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CQZDrhAL, HV_BINOP_DIVIDE, 1, m, &cBinop_CQZDrhAL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2rOkL8uf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_jVCC3Mjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_qZ6lRfDb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fVlXASB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jVCC3Mjp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qZ6lRfDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CQZDrhAL, HV_BINOP_DIVIDE, 0, m, &cBinop_CQZDrhAL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2rOkL8uf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fVlXASB0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CQZDrhAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IjpA2cqL, HV_BINOP_MULTIPLY, 1, m, &cBinop_IjpA2cqL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IjpA2cqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wS9h9E6P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uukz4D8l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_CD7tMAeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_g38F0mL7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_beBxRxup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sou0fxZx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_5o6X7q97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_KizXIFDt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KizXIFDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IjpA2cqL, HV_BINOP_MULTIPLY, 0, m, &cBinop_IjpA2cqL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f8XAT4D1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_I7bAqOa9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I7bAqOa9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pYeS9m6C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HkokDaAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x8mjWASz, HV_BINOP_MULTIPLY, 1, m, &cBinop_x8mjWASz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J6MPqLUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sdnO2Svm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sdnO2Svm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HkokDaAI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w80iMS58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tNdRdjnW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tNdRdjnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KxUOGgS4, HV_BINOP_MULTIPLY, 1, m, &cBinop_KxUOGgS4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DAoZG2kb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MBJup9me, HV_BINOP_MULTIPLY, 1, m, &cBinop_MBJup9me_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fZrTViwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PjwqWkal_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PjwqWkal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DAoZG2kb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9umTfKd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GcIQ03XV, 1, m, &cVar_GcIQ03XV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gkX12FKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_testLfTg, HV_BINOP_MULTIPLY, 1, m, &cBinop_testLfTg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qnrQr6Tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MZ2JeCgW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MZ2JeCgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K99fdeMP, HV_BINOP_MULTIPLY, 1, m, &cBinop_K99fdeMP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_GcIQ03XV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wj8yDSNi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_GRerQSDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e4fr9AR2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_5o6X7q97_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Lw9l55r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_SSul8cq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_f8XAT4D1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wS9h9E6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_CD7tMAeS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uukz4D8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_beBxRxup_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_g38F0mL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kAqvampd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sou0fxZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pWFq4PdX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_wLstA1gX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tc3wVE1z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pYeS9m6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gLj3PDKw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gLj3PDKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aMtpD6M3, HV_BINOP_MULTIPLY, 1, m, &cBinop_aMtpD6M3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aMtpD6M3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JU7coNff_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JU7coNff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wLstA1gX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Wj8yDSNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fkEzHbwT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fkEzHbwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nCx7vL70_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xt1nOi1e_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L0zMFd5B_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OyR0Et09_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8uaCd0C6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wo0oR22W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_x8mjWASz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vtyMbtYD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_KxUOGgS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vCEnWfhO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MBJup9me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eOYTqy6V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_testLfTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jGN27Eo5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_K99fdeMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mmMRZOBg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_9DWItz8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GRerQSDA, 0, m, &cVar_GRerQSDA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J9dr33Kx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SSul8cq5, 1, m, &cVar_SSul8cq5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nCx7vL70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_Wo0oR22W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x8mjWASz, HV_BINOP_MULTIPLY, 0, m, &cBinop_x8mjWASz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L0zMFd5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_testLfTg, HV_BINOP_MULTIPLY, 0, m, &cBinop_testLfTg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8uaCd0C6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KxUOGgS4, HV_BINOP_MULTIPLY, 0, m, &cBinop_KxUOGgS4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xt1nOi1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K99fdeMP, HV_BINOP_MULTIPLY, 0, m, &cBinop_K99fdeMP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OyR0Et09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MBJup9me, HV_BINOP_MULTIPLY, 0, m, &cBinop_MBJup9me_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3Lw9l55r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GcIQ03XV, 0, m, &cVar_GcIQ03XV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e4fr9AR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SSul8cq5, 0, m, &cVar_SSul8cq5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tTvJyE2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_61YCAbcn, 1, m, &cIf_61YCAbcn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qM4K158M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_AgkbW42o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ZQISP8JO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qM4K158M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_KsYs6vKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_61YCAbcn, 0, m, &cIf_61YCAbcn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_flBbBdbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FlmIGQ1n, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AgkbW42o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z8hZYdls, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3OxnriqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PEmmWLuV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_KBb017TB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tTvJyE2L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZQISP8JO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CZwrkxP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_KsYs6vKP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_b6ooJ9tX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ouROMeP0, 0, m, &cSlice_ouROMeP0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FHnS6eKP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ouROMeP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xngRhHro_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xngRhHro_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3PgGF4P4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xngRhHro_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xngRhHro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ls0Ioo6I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_dp6hvvgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RsmlAwx4_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_3VibC99o, 0, m, &cIf_3VibC99o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_3VibC99o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GAQWyLUe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_69Il6JAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_gwADKQlU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NU0IEi5F_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_01WORu2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AEcLR5Y9, HV_BINOP_POW, 0, m, &cBinop_AEcLR5Y9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AEcLR5Y9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uMhQ0gRB, 0, m, &cIf_uMhQ0gRB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HICYu9Gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_yk77wM8t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oOEKANIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_scjYDz7c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sFnpZg5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_69Il6JAQ, 0, m, &cIf_69Il6JAQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_scjYDz7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_69Il6JAQ, 1, m, &cIf_69Il6JAQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NU0IEi5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_HICYu9Gv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gwADKQlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_uMhQ0gRB, 0, m, &cIf_uMhQ0gRB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yk77wM8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AEcLR5Y9, HV_BINOP_POW, 1, m, &cBinop_AEcLR5Y9_sendMessage);
  cMsg_01WORu2E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_uMhQ0gRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_w7mLMJOp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_RsmlAwx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3VibC99o, 1, m, &cIf_3VibC99o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GAQWyLUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mgs4Vgx9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qelgaHbz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JXsefPlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oOEKANIw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sFnpZg5r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7hFn8TCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uMhQ0gRB, 1, m, &cIf_uMhQ0gRB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PwqR61h8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3YekeKyG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3YekeKyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_w7mLMJOp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_boYFn9i2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_JXsefPlu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qelgaHbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7hFn8TCk, HV_BINOP_GREATER_THAN, 1, m, &cBinop_7hFn8TCk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Mgs4Vgx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PwqR61h8, HV_BINOP_EQ, 1, m, &cBinop_PwqR61h8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_30rrNMJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_boYFn9i2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_2pwaxHEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7hFn8TCk, HV_BINOP_GREATER_THAN, 0, m, &cBinop_7hFn8TCk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ChK9Hg9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dp6hvvgW, 0, m, &cVar_dp6hvvgW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vgHwkbdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PwqR61h8, HV_BINOP_EQ, 0, m, &cBinop_PwqR61h8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_hxxEBsCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FGDPu5Rn_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VDQfolBU, 0, m, &cIf_VDQfolBU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_VDQfolBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nLTWnKPi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_cjizRTn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_gbAlWwK4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ASm7DRrC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_hiYkBtLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qkbA2U2M, HV_BINOP_POW, 0, m, &cBinop_qkbA2U2M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qkbA2U2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4Jt1hOI0, 0, m, &cIf_4Jt1hOI0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GAzJZPon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_TFIKb4Ph_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mGNK7ilH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BLp2vqyF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KLv0GQ3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cjizRTn2, 0, m, &cIf_cjizRTn2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BLp2vqyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cjizRTn2, 1, m, &cIf_cjizRTn2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ASm7DRrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GAzJZPon_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gbAlWwK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_4Jt1hOI0, 0, m, &cIf_4Jt1hOI0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TFIKb4Ph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qkbA2U2M, HV_BINOP_POW, 1, m, &cBinop_qkbA2U2M_sendMessage);
  cMsg_hiYkBtLs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_4Jt1hOI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vKQZ3f6W_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J2W5DNtW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_FGDPu5Rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VDQfolBU, 1, m, &cIf_VDQfolBU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nLTWnKPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NQucddV6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kizcS0PM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jdaNKSnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mGNK7ilH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KLv0GQ3O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mv0b9Lp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4Jt1hOI0, 1, m, &cIf_4Jt1hOI0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nIX2N14N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_edQMkOCJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_edQMkOCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vKQZ3f6W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J2W5DNtW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TJhQOqrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_jdaNKSnt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kizcS0PM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mv0b9Lp7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_mv0b9Lp7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NQucddV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nIX2N14N, HV_BINOP_EQ, 1, m, &cBinop_nIX2N14N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XbzYUxHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hxxEBsCd, 0, m, &cVar_hxxEBsCd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WKgHz5Jb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mv0b9Lp7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_mv0b9Lp7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DKjlaBmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nIX2N14N, HV_BINOP_EQ, 0, m, &cBinop_nIX2N14N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8iIwy8Ak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TJhQOqrH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_WWQlMVOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xs4E1lwG_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_lifWyRcr, 0, m, &cIf_lifWyRcr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_lifWyRcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kEF0bewm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ibLpSk32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3ZKtSVQb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_UN5VyTUe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_LfcuvrvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LRQqvI4A, HV_BINOP_POW, 0, m, &cBinop_LRQqvI4A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LRQqvI4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LnXbYXdV, 0, m, &cIf_LnXbYXdV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G0XAJ0AA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Z6z8S5RV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Nnf9ql7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ibLpSk32, 0, m, &cIf_ibLpSk32_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5EM0toTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_r5z5tXNS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_r5z5tXNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ibLpSk32, 1, m, &cIf_ibLpSk32_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UN5VyTUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_G0XAJ0AA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3ZKtSVQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_LnXbYXdV, 0, m, &cIf_LnXbYXdV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z6z8S5RV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LRQqvI4A, HV_BINOP_POW, 1, m, &cBinop_LRQqvI4A_sendMessage);
  cMsg_LfcuvrvX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_LnXbYXdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YHLpWlRw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_xs4E1lwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lifWyRcr, 1, m, &cIf_lifWyRcr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kEF0bewm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hcUTY78W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MaSjdlEU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_okv33wBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5EM0toTB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nnf9ql7z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7mBAUI7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LnXbYXdV, 1, m, &cIf_LnXbYXdV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QuXC7dGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lIw6rYPs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lIw6rYPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_YHLpWlRw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DubUb6Ip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_okv33wBF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MaSjdlEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7mBAUI7C, HV_BINOP_GREATER_THAN, 1, m, &cBinop_7mBAUI7C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hcUTY78W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QuXC7dGW, HV_BINOP_EQ, 1, m, &cBinop_QuXC7dGW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FhpOeiby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QuXC7dGW, HV_BINOP_EQ, 0, m, &cBinop_QuXC7dGW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4oLARuHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DubUb6Ip_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_AdDx4ySO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WWQlMVOE, 0, m, &cVar_WWQlMVOE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KSEwbAJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7mBAUI7C, HV_BINOP_GREATER_THAN, 0, m, &cBinop_7mBAUI7C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_jpnrDbiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bCjFT7lI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_08zKuaBy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UqE1IqLM, 0, m, &cSlice_UqE1IqLM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cUQlz3Em_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_UqE1IqLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iXPTuYCt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iXPTuYCt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_T4tOSQKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iXPTuYCt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_iXPTuYCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EIPaZai5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cUQlz3Em_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bTPxX6EW, 0, m, &cSlice_bTPxX6EW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_b6ooJ9tX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bTPxX6EW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sZ5RhKNG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sZ5RhKNG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_zEdgtR1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sZ5RhKNG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sZ5RhKNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ycOpbzhq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FHnS6eKP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pLZ4Pgsh, 0, m, &cSlice_pLZ4Pgsh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_n4fFr6Gs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_pLZ4Pgsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aOq4zva8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aOq4zva8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_v7Xs3ApL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aOq4zva8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_aOq4zva8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pLdYZGuY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_n4fFr6Gs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_E4saVIRo, 0, m, &cSlice_E4saVIRo_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_E4saVIRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ptQhciqk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ptQhciqk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PN6qdr3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ptQhciqk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ptQhciqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cwDMaQ3v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ozD6MkZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3LpPWyug, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KHi6NTiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qpdrRC15, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yCWK1OJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kEuNRKdZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jeVgym25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fq9kDkW9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lFWtKrP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_77yCnGr2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NaCl7QLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZNfMC6jg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_ZNfMC6jg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yxWlkIPM, HV_BINOP_DIVIDE, 1, m, &cBinop_yxWlkIPM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OpUN4pw2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_3baw6XWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_C6Eefncm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DC2UCSou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_3baw6XWf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C6Eefncm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yxWlkIPM, HV_BINOP_DIVIDE, 0, m, &cBinop_yxWlkIPM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OpUN4pw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DC2UCSou_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_yxWlkIPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bFqXZ27u, HV_BINOP_MULTIPLY, 1, m, &cBinop_bFqXZ27u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bFqXZ27u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UpNpHscb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dRaYjnFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_416pgVyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KP5dNRHQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_oCY5FDJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FPZDqOdV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wWpLruqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_mQLLRDS3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mQLLRDS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bFqXZ27u, HV_BINOP_MULTIPLY, 0, m, &cBinop_bFqXZ27u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BmssjMH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_UfuK2zM3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UfuK2zM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dbgt7kdh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_U6c13rXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1EaEQlZd, 1, m, &cVar_1EaEQlZd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_1EaEQlZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Oo3SDEm4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Ka6kaGHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qgvYyY8P, HV_BINOP_MULTIPLY, 1, m, &cBinop_qgvYyY8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CIt32T2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ka6kaGHv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_16rOofGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4WjqdCKH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4WjqdCKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DoCMH1hD, HV_BINOP_MULTIPLY, 1, m, &cBinop_DoCMH1hD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U89efKI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zgi70Tqp, HV_BINOP_MULTIPLY, 1, m, &cBinop_Zgi70Tqp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9N4I8W76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_U89efKI6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1wg18UMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C8vbIEH2, HV_BINOP_MULTIPLY, 1, m, &cBinop_C8vbIEH2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XvnYmDzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YXR44QpT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YXR44QpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1QUaj8nn, HV_BINOP_MULTIPLY, 1, m, &cBinop_1QUaj8nn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_YYUfom53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nnp1Jked_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wWpLruqU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SD1xv3n8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_3mpIzTap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_BmssjMH1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UpNpHscb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_416pgVyx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dRaYjnFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_oCY5FDJN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_KP5dNRHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2nCD967D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FPZDqOdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KoWGF65p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Ursu1Cib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gLwTBLFx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Dbgt7kdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Z0etwo5O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z0etwo5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UOG7LwG3, HV_BINOP_MULTIPLY, 1, m, &cBinop_UOG7LwG3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UOG7LwG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BeHPnOJb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BeHPnOJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ursu1Cib_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Oo3SDEm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zU5eC3Ec_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zU5eC3Ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HuhXFV6g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bcqEa2BB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uZXXf88W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqoQDC2k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m8YCOp4M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_93xDEq1U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qgvYyY8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ozD6MkZx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_DoCMH1hD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KHi6NTiY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Zgi70Tqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yCWK1OJF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_C8vbIEH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jeVgym25_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_1QUaj8nn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lFWtKrP5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_1mnWygVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YYUfom53, 0, m, &cVar_YYUfom53_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FThBszQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3mpIzTap, 1, m, &cVar_3mpIzTap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HuhXFV6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_93xDEq1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qgvYyY8P, HV_BINOP_MULTIPLY, 0, m, &cBinop_qgvYyY8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uZXXf88W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C8vbIEH2, HV_BINOP_MULTIPLY, 0, m, &cBinop_C8vbIEH2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_m8YCOp4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DoCMH1hD, HV_BINOP_MULTIPLY, 0, m, &cBinop_DoCMH1hD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bcqEa2BB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1QUaj8nn, HV_BINOP_MULTIPLY, 0, m, &cBinop_1QUaj8nn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OqoQDC2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zgi70Tqp, HV_BINOP_MULTIPLY, 0, m, &cBinop_Zgi70Tqp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SD1xv3n8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1EaEQlZd, 0, m, &cVar_1EaEQlZd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nnp1Jked_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3mpIzTap, 0, m, &cVar_3mpIzTap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x6jEn429_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V7sZJ2v9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_x5zZtO1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fDU0mjDL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Xuj2fVjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FQEogp4h, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xSgGLLqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L0EyKR68, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gtQ3v2Hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gAoD13Zl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_gAoD13Zl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FZh4sR6t, HV_BINOP_DIVIDE, 1, m, &cBinop_FZh4sR6t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8E1jewrP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_k6a9ZqA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ea9HqMLP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jCqv04Mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_k6a9ZqA0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ea9HqMLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FZh4sR6t, HV_BINOP_DIVIDE, 0, m, &cBinop_FZh4sR6t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8E1jewrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jCqv04Mp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_FZh4sR6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rNfxinpw, HV_BINOP_MULTIPLY, 1, m, &cBinop_rNfxinpw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rNfxinpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PC2kUKAA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zh4L7k99_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_pPXDVUvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ih4Z2RrI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_7jfrCmtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QGezjHg5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ZVOnwQ7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_DM2S5l1q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DM2S5l1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rNfxinpw, HV_BINOP_MULTIPLY, 0, m, &cBinop_rNfxinpw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W0C3W1qF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_P8K3QYIH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P8K3QYIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E3PgK6ic_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_gPiOI4y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_19NLVI7z, HV_BINOP_MULTIPLY, 1, m, &cBinop_19NLVI7z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CcXwdmHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K8rhLRhd, 1, m, &cVar_K8rhLRhd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HZn69tOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n2g3rpZd, HV_BINOP_MULTIPLY, 1, m, &cBinop_n2g3rpZd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6t8qfY1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EZZ0OyI0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EZZ0OyI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Y79VTFU, HV_BINOP_MULTIPLY, 1, m, &cBinop_5Y79VTFU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_K8rhLRhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kLevf5S3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_xyqG6Z71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aRGJH1Y4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ZVOnwQ7K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ggmzTspk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_6tV9By3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_W0C3W1qF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PC2kUKAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_pPXDVUvx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Zh4L7k99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_7jfrCmtg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_ih4Z2RrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_V4tTKxWy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QGezjHg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SDY01T5e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7XLfKVSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qVspi1CC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_E3PgK6ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gSa4Q9yi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gSa4Q9yi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C4umZw7r, HV_BINOP_MULTIPLY, 1, m, &cBinop_C4umZw7r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C4umZw7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qpwtoCXY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qpwtoCXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7XLfKVSI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kLevf5S3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mAG42AHb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mAG42AHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9OQVR0Ur_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0Udafam1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7vLAqY3q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_th7rDYQD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Il6bsO6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x6jEn429_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_19NLVI7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x5zZtO1H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_n2g3rpZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xuj2fVjC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_5Y79VTFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xSgGLLqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_hlp7YDAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6tV9By3M, 1, m, &cVar_6tV9By3M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1ilqNmZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xyqG6Z71, 0, m, &cVar_xyqG6Z71_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ggmzTspk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K8rhLRhd, 0, m, &cVar_K8rhLRhd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aRGJH1Y4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6tV9By3M, 0, m, &cVar_6tV9By3M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7vLAqY3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_19NLVI7z, HV_BINOP_MULTIPLY, 0, m, &cBinop_19NLVI7z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0Udafam1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n2g3rpZd, HV_BINOP_MULTIPLY, 0, m, &cBinop_n2g3rpZd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_th7rDYQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Il6bsO6E, HV_BINOP_MULTIPLY, 0, m, &cBinop_Il6bsO6E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9OQVR0Ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Y79VTFU, HV_BINOP_MULTIPLY, 0, m, &cBinop_5Y79VTFU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GNfZr3Xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CqZMAYCX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WyHQd4Fu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pR6RTMuY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NCsLe8Mu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mxgQW420, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uyiQSlze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O0JThNCj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SGjXUdLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ii0fLJNg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tfQ0JX5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C2LpGdLt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_C2LpGdLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NRVhThBs, HV_BINOP_DIVIDE, 1, m, &cBinop_NRVhThBs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gikb8SAK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_i6xLdrun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_j94Oyirw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CHm7UB4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_i6xLdrun_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j94Oyirw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NRVhThBs, HV_BINOP_DIVIDE, 0, m, &cBinop_NRVhThBs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gikb8SAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CHm7UB4l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NRVhThBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2o3R8FZn, HV_BINOP_MULTIPLY, 1, m, &cBinop_2o3R8FZn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2o3R8FZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WoV0I3Gp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_prPxpztx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ys7E5Nw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_laatB94G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_al0zKrTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m8SwWF6n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_VwWjkyKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_748rzu5T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_748rzu5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2o3R8FZn, HV_BINOP_MULTIPLY, 0, m, &cBinop_2o3R8FZn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7dDt9AIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_m9itZHok_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m9itZHok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5QeUndhi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_s21KvvJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LIrFr0Ki, HV_BINOP_MULTIPLY, 1, m, &cBinop_LIrFr0Ki_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Tvk77PDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wSKZe8ni_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wSKZe8ni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_s21KvvJi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a6MHIr4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nSRJj8Ah_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nSRJj8Ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mVeRiBtv, HV_BINOP_MULTIPLY, 1, m, &cBinop_mVeRiBtv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bQZGyJJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SINEkNgQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_SINEkNgQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_muTrZ0zF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CzUK2BwS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CzUK2BwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bQZGyJJJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UKoR4VQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NDPR4DR9, 1, m, &cVar_NDPR4DR9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2IG0J1c9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAjQjbRz, HV_BINOP_MULTIPLY, 1, m, &cBinop_xAjQjbRz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NbWz5pQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UFhiZ2KF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UFhiZ2KF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Naimq5t8, HV_BINOP_MULTIPLY, 1, m, &cBinop_Naimq5t8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_NDPR4DR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q1m2sAkl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_DhuSmcrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jAkh1P83_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_VwWjkyKu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ua2IK5EL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_GaTmltD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_7dDt9AIN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_prPxpztx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_al0zKrTV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WoV0I3Gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ys7E5Nw4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_laatB94G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YSvClWhB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_m8SwWF6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uFPlEcg6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_rueYWFQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Z3rrgvdZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5QeUndhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RxEsM31f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RxEsM31f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vt9wthlC, HV_BINOP_MULTIPLY, 1, m, &cBinop_Vt9wthlC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Vt9wthlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_H4l400nd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_H4l400nd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rueYWFQI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_q1m2sAkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XrsLSj6Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XrsLSj6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aO17EyDS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RR1E2Vdg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RTwhH2Jx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tRyW4sp6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dpb8rJa5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jkTsaFfO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LIrFr0Ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GNfZr3Xd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mVeRiBtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WyHQd4Fu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_SINEkNgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NCsLe8Mu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xAjQjbRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uyiQSlze_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Naimq5t8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SGjXUdLq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_YtAHPaRS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GaTmltD0, 1, m, &cVar_GaTmltD0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7LZNnHaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DhuSmcrY, 0, m, &cVar_DhuSmcrY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tRyW4sp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SINEkNgQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_SINEkNgQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aO17EyDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_jkTsaFfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LIrFr0Ki, HV_BINOP_MULTIPLY, 0, m, &cBinop_LIrFr0Ki_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RTwhH2Jx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAjQjbRz, HV_BINOP_MULTIPLY, 0, m, &cBinop_xAjQjbRz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Dpb8rJa5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mVeRiBtv, HV_BINOP_MULTIPLY, 0, m, &cBinop_mVeRiBtv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RR1E2Vdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Naimq5t8, HV_BINOP_MULTIPLY, 0, m, &cBinop_Naimq5t8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jAkh1P83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GaTmltD0, 0, m, &cVar_GaTmltD0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ua2IK5EL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NDPR4DR9, 0, m, &cVar_NDPR4DR9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DGJjgT8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jpnrDbiS, 1, m, &cIf_jpnrDbiS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pix2yPmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_bCjFT7lI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_VqXh63tY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pix2yPmU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_FaqD5A8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jpnrDbiS, 0, m, &cIf_jpnrDbiS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w7mLMJOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4rRFUI0Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bCjFT7lI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2KaTQhi1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YHLpWlRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s8OH6a0H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vKQZ3f6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DGJjgT8B_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VqXh63tY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J2W5DNtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_FaqD5A8G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_2aqfYcRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5TXwprJ9, HV_BINOP_DIVIDE, 0, m, &cBinop_5TXwprJ9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_LnLP05iS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lMdK1RMU, HV_BINOP_DIVIDE, 1, m, &cBinop_lMdK1RMU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5TXwprJ9, HV_BINOP_DIVIDE, 1, m, &cBinop_5TXwprJ9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_tuvG8of3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4i0Qw3xp, HV_BINOP_DIVIDE, 0, m, &cBinop_4i0Qw3xp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_qdpYHYtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4i0Qw3xp, HV_BINOP_DIVIDE, 1, m, &cBinop_4i0Qw3xp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lFy7032b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2aqfYcRg, 0, m, &cVar_2aqfYcRg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0aeie5GA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LnLP05iS, 0, m, &cVar_LnLP05iS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DcBRfLVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lMdK1RMU, HV_BINOP_DIVIDE, 0, m, &cBinop_lMdK1RMU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lMdK1RMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_tuvG8of3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5TXwprJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_qdpYHYtI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4i0Qw3xp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_bykl6BPn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_hUeoXwSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_XuXosVEl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JwkWWDMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_SulOlYkp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bykl6BPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_JwkWWDMF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SulOlYkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_hUeoXwSj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XuXosVEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xDloProb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_U8Y8VqPk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Gi2tbwCd, 0, m, &cSlice_Gi2tbwCd_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Gi2tbwCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qc5HffU7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qc5HffU7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_E0sSumlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qc5HffU7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_qc5HffU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c87b9xKB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_AAj9Q0f6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_JeDw55iY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JeDw55iY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_k5FtfF5h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k5FtfF5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_EaBflLEd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EaBflLEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JtscX1s1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lXaJExnM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lXaJExnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8v9k8IcK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JtscX1s1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2lZHomIC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2lZHomIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vgBXErBQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8v9k8IcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3wCyHSQV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3wCyHSQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zcJfoCh0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vgBXErBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LwBsTHJU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_zcJfoCh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mq0IAzBV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LwBsTHJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kMPMBM6C, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Mq0IAzBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7HEyDSYL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_tpz2Ayt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zVVSegu8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_zH6ilnJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rn2ZQkQg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pNucKtWh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c4y4eIMi_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_esjbrIkw_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ptnCneF2_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1tENThXM_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z1QdGhsE_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nnqL389I_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_c4y4eIMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XyZXYFFB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_esjbrIkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PUWX6NVW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ptnCneF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P2OaMe4T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_1tENThXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SMMYdZew_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Z1QdGhsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o6AHQDuj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_nnqL389I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6ZCSSaeD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_alhZcJVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vQkhJCQ2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_meailEo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_397uCeVG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4tSHs6iE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9GnOZMdU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9GnOZMdU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ppH9Xqxa, 1, m, &cDelay_ppH9Xqxa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ilpHrLsM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ppH9Xqxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ppH9Xqxa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_alhZcJVU, 0, m, &cIf_alhZcJVU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9GnOZMdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ppH9Xqxa, 0, m, &cDelay_ppH9Xqxa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ilpHrLsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ppH9Xqxa, 0, m, &cDelay_ppH9Xqxa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Mh1ONJ7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QZXk3SCV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M0H66zDx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_z9MEPeta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TlryDqG0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qABoGdbH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TlryDqG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_alhZcJVU, 1, m, &cIf_alhZcJVU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qABoGdbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4tSHs6iE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QZXk3SCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_meailEo3, 1, m, &cIf_meailEo3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M0H66zDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_meailEo3, 0, m, &cIf_meailEo3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_397uCeVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sit8fAf1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vQkhJCQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sit8fAf1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_c10yPlEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NXY0CGJm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bJwdbAc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mPxdAcTB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_L3Hw9AwH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oorka9Wi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oorka9Wi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0VKTGOxN, 1, m, &cDelay_0VKTGOxN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lRZxiSjC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0VKTGOxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0VKTGOxN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_c10yPlEo, 0, m, &cIf_c10yPlEo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oorka9Wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0VKTGOxN, 0, m, &cDelay_0VKTGOxN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lRZxiSjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0VKTGOxN, 0, m, &cDelay_0VKTGOxN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dNAp3hqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RJC5d3zh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D4CQO8Rc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fejq3KFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l8wJoDRA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UozH9NjH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l8wJoDRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c10yPlEo, 1, m, &cIf_c10yPlEo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UozH9NjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_L3Hw9AwH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RJC5d3zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bJwdbAc8, 1, m, &cIf_bJwdbAc8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D4CQO8Rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bJwdbAc8, 0, m, &cIf_bJwdbAc8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mPxdAcTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vg2Zp1yK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NXY0CGJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vg2Zp1yK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xFSmsuTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Dn3W5I88_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Qd9r86x4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uFJ23twA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JNk6jQep_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3JUYoJ4H_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3JUYoJ4H_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JvAcCvz0, 1, m, &cDelay_JvAcCvz0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yBT2RNSf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JvAcCvz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JvAcCvz0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xFSmsuTb, 0, m, &cIf_xFSmsuTb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3JUYoJ4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JvAcCvz0, 0, m, &cDelay_JvAcCvz0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yBT2RNSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JvAcCvz0, 0, m, &cDelay_JvAcCvz0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qv4HLhya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F2BlBCMc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dXDZO3xZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TFTl0lgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KJrvr8O8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7QkiHKOx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KJrvr8O8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xFSmsuTb, 1, m, &cIf_xFSmsuTb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7QkiHKOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JNk6jQep_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_dXDZO3xZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qd9r86x4, 0, m, &cIf_Qd9r86x4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F2BlBCMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qd9r86x4, 1, m, &cIf_Qd9r86x4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uFJ23twA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F9CZ4nPG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Dn3W5I88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F9CZ4nPG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Y2iN6zfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_28g16xBx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_F4ZMHTCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VKF580S8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_M5wFiTbg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HOMlKyAM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HOMlKyAM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KAZYR6oE, 1, m, &cDelay_KAZYR6oE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QeGobbKQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KAZYR6oE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KAZYR6oE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Y2iN6zfq, 0, m, &cIf_Y2iN6zfq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HOMlKyAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KAZYR6oE, 0, m, &cDelay_KAZYR6oE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QeGobbKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KAZYR6oE, 0, m, &cDelay_KAZYR6oE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hHSFKXAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0kjtItgg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dvOTH6cz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZvFGGwir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z4cFJdsq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MGcK36NH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MGcK36NH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_M5wFiTbg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Z4cFJdsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y2iN6zfq, 1, m, &cIf_Y2iN6zfq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dvOTH6cz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F4ZMHTCQ, 0, m, &cIf_F4ZMHTCQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0kjtItgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F4ZMHTCQ, 1, m, &cIf_F4ZMHTCQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VKF580S8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JuLAwOOH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_28g16xBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JuLAwOOH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_HbUJQXBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yg1Lr4xQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gbjiYTzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HEXjLJsj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_A4uyUa9a_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bobTUoWq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bobTUoWq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TEIsw2w5, 1, m, &cDelay_TEIsw2w5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XKnF5oOF_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TEIsw2w5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TEIsw2w5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HbUJQXBp, 0, m, &cIf_HbUJQXBp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bobTUoWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TEIsw2w5, 0, m, &cDelay_TEIsw2w5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XKnF5oOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TEIsw2w5, 0, m, &cDelay_TEIsw2w5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XbwGaVLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bcofy3iq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G9WJJRjd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Hk7NiMcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e7f8XkOa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_edYWx4Dx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_edYWx4Dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_A4uyUa9a_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_e7f8XkOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HbUJQXBp, 1, m, &cIf_HbUJQXBp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G9WJJRjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gbjiYTzV, 0, m, &cIf_gbjiYTzV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bcofy3iq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gbjiYTzV, 1, m, &cIf_gbjiYTzV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HEXjLJsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b62RQYxO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yg1Lr4xQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b62RQYxO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_vrlQrv6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yc4gnexo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_PQN7w77S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_96eJKbQJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_a1Qgmofa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DORiHqFM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DORiHqFM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MHCpKcj9, 1, m, &cDelay_MHCpKcj9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vgzGMxEi_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MHCpKcj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MHCpKcj9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vrlQrv6s, 0, m, &cIf_vrlQrv6s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DORiHqFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MHCpKcj9, 0, m, &cDelay_MHCpKcj9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vgzGMxEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MHCpKcj9, 0, m, &cDelay_MHCpKcj9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PrlX6DUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LYrNaS1t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YOhx7akn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xB4cqIYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WQXjizDT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yq9k2OIc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WQXjizDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vrlQrv6s, 1, m, &cIf_vrlQrv6s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yq9k2OIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_a1Qgmofa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YOhx7akn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PQN7w77S, 0, m, &cIf_PQN7w77S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LYrNaS1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PQN7w77S, 1, m, &cIf_PQN7w77S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_96eJKbQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q5aXWgio, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yc4gnexo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q5aXWgio, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_M25aSm3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jnWTrVbb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_VTf2vE1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XTKFAd3p_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hBVu02yz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CbS8x1IP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CbS8x1IP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AaGOPNQT, 1, m, &cDelay_AaGOPNQT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GFqpqiEU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AaGOPNQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AaGOPNQT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_M25aSm3W, 0, m, &cIf_M25aSm3W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CbS8x1IP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AaGOPNQT, 0, m, &cDelay_AaGOPNQT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GFqpqiEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AaGOPNQT, 0, m, &cDelay_AaGOPNQT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kWPrLaMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gPAUoncA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pGw64b9K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R9UGRGbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yGeqKIzx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3k5JzzCa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yGeqKIzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M25aSm3W, 1, m, &cIf_M25aSm3W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3k5JzzCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hBVu02yz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gPAUoncA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VTf2vE1D, 1, m, &cIf_VTf2vE1D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pGw64b9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VTf2vE1D, 0, m, &cIf_VTf2vE1D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XTKFAd3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P0OaMtXP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jnWTrVbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P0OaMtXP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aYb7KKcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GNqbdkI3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_z8inUTIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qQ8SRfT5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qlHsNRiY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8nbnV79O_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8nbnV79O_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nHItdQm0, 1, m, &cDelay_nHItdQm0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_axbpR8Ci_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nHItdQm0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nHItdQm0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aYb7KKcU, 0, m, &cIf_aYb7KKcU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8nbnV79O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nHItdQm0, 0, m, &cDelay_nHItdQm0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_axbpR8Ci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nHItdQm0, 0, m, &cDelay_nHItdQm0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9RoKbzwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TE0beAVi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pGlGkyoV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_N6ZyIpk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f3Rd9eQQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gZjwzku2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f3Rd9eQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aYb7KKcU, 1, m, &cIf_aYb7KKcU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gZjwzku2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qlHsNRiY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_TE0beAVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z8inUTIj, 1, m, &cIf_z8inUTIj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pGlGkyoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z8inUTIj, 0, m, &cIf_z8inUTIj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qQ8SRfT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3Nrcd90m, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GNqbdkI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3Nrcd90m, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_n5ktV2jD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iek80U3j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fWNhLeEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ufM2wBJX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5p5SpLZs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_drO7tZbU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_drO7tZbU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BH9PQKMq, 1, m, &cDelay_BH9PQKMq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mJ4Ph5It_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BH9PQKMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BH9PQKMq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_n5ktV2jD, 0, m, &cIf_n5ktV2jD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_drO7tZbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BH9PQKMq, 0, m, &cDelay_BH9PQKMq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mJ4Ph5It_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BH9PQKMq, 0, m, &cDelay_BH9PQKMq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wiGgwnC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1kzdHYzC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KwbvIeWi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nt4kMQcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VLlmwNTJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WR53c2cv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WR53c2cv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5p5SpLZs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VLlmwNTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n5ktV2jD, 1, m, &cIf_n5ktV2jD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1kzdHYzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fWNhLeEg, 1, m, &cIf_fWNhLeEg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KwbvIeWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fWNhLeEg, 0, m, &cIf_fWNhLeEg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ufM2wBJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qOcd6Ljv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iek80U3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qOcd6Ljv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_af64EpV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JSGoc2X1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_TASut2SG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YUi7Vk96_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oJMOJnMO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vNADmmqC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vNADmmqC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ESmAffwF, 1, m, &cDelay_ESmAffwF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cZZ48xIk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ESmAffwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ESmAffwF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_af64EpV7, 0, m, &cIf_af64EpV7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vNADmmqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ESmAffwF, 0, m, &cDelay_ESmAffwF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cZZ48xIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ESmAffwF, 0, m, &cDelay_ESmAffwF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rrRuV0HJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DXTMn3co_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XLaJNFc1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1pK2Al3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5OB4Tu5a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0aCw32v2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0aCw32v2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oJMOJnMO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5OB4Tu5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_af64EpV7, 1, m, &cIf_af64EpV7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XLaJNFc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TASut2SG, 0, m, &cIf_TASut2SG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DXTMn3co_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TASut2SG, 1, m, &cIf_TASut2SG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YUi7Vk96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LqOW5cbx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JSGoc2X1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LqOW5cbx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BLgGitwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_35k1remb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_uT3Nm4zv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zuC1MUGx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_w8yOXOzR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_q0VgP3Lg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_q0VgP3Lg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kRNl7iqe, 1, m, &cDelay_kRNl7iqe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2yBqxQOp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kRNl7iqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kRNl7iqe, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BLgGitwB, 0, m, &cIf_BLgGitwB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_q0VgP3Lg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kRNl7iqe, 0, m, &cDelay_kRNl7iqe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2yBqxQOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kRNl7iqe, 0, m, &cDelay_kRNl7iqe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3hpoUQmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NsZzlSvL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FRYn6Lai_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I23kHuXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uqHU5U1k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Uz1mzqDp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uqHU5U1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BLgGitwB, 1, m, &cIf_BLgGitwB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Uz1mzqDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_w8yOXOzR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NsZzlSvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uT3Nm4zv, 1, m, &cIf_uT3Nm4zv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FRYn6Lai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uT3Nm4zv, 0, m, &cIf_uT3Nm4zv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zuC1MUGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DJhFh3d0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_35k1remb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DJhFh3d0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_m5ObJPfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qSO8wXLe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fW5G5W7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nOAUfNcE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XglxtyLH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_z9yneHUS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_z9yneHUS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_q1DXgPMQ, 1, m, &cDelay_q1DXgPMQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iOAxGEfn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_q1DXgPMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_q1DXgPMQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_m5ObJPfx, 0, m, &cIf_m5ObJPfx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z9yneHUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_q1DXgPMQ, 0, m, &cDelay_q1DXgPMQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iOAxGEfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_q1DXgPMQ, 0, m, &cDelay_q1DXgPMQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bAYR3TMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ciOpiosa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dQqZQyJN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U8TYHU2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H46xsSXn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_19eTmuGG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H46xsSXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m5ObJPfx, 1, m, &cIf_m5ObJPfx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_19eTmuGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XglxtyLH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ciOpiosa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fW5G5W7p, 1, m, &cIf_fW5G5W7p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dQqZQyJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fW5G5W7p, 0, m, &cIf_fW5G5W7p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nOAUfNcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QkvYRPOo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qSO8wXLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QkvYRPOo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XyZXYFFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_xKQkMiGt_sendMessage(_c, 0, m);
  cMsg_JaVAaTIi_sendMessage(_c, 0, m);
  cMsg_rRYqyQBs_sendMessage(_c, 0, m);
  cMsg_4wJacPVg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PUWX6NVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_xKQkMiGt_sendMessage(_c, 0, m);
  cMsg_ZgLcTuqW_sendMessage(_c, 0, m);
  cMsg_09V0JSNY_sendMessage(_c, 0, m);
  cMsg_obOdWTjO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_P2OaMe4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_8CjjAcOa_sendMessage(_c, 0, m);
  cMsg_ZgLcTuqW_sendMessage(_c, 0, m);
  cMsg_4wJacPVg_sendMessage(_c, 0, m);
  cMsg_cOPZM6eA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SMMYdZew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_8CjjAcOa_sendMessage(_c, 0, m);
  cMsg_hl2h5AFC_sendMessage(_c, 0, m);
  cMsg_rRYqyQBs_sendMessage(_c, 0, m);
  cMsg_WNap41ZG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_o6AHQDuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_zn9iSg0r_sendMessage(_c, 0, m);
  cMsg_obOdWTjO_sendMessage(_c, 0, m);
  cMsg_JdzHqSm9_sendMessage(_c, 0, m);
  cMsg_rRYqyQBs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6ZCSSaeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_zn9iSg0r_sendMessage(_c, 0, m);
  cMsg_WNap41ZG_sendMessage(_c, 0, m);
  cMsg_ZgLcTuqW_sendMessage(_c, 0, m);
  cMsg_UZOm9xvZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ESpnbFmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_z9MEPeta_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Mh1ONJ7k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uxdPi4uK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_z9MEPeta_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Mh1ONJ7k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PshVKSLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fejq3KFb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dNAp3hqV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KtjatnOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fejq3KFb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dNAp3hqV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JIf9OUF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TFTl0lgG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qv4HLhya_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M6PX3Cwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TFTl0lgG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qv4HLhya_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xKQkMiGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_ESpnbFmS_sendMessage(_c, 0, m);
  cMsg_KtjatnOf_sendMessage(_c, 0, m);
  cMsg_M6PX3Cwu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8CjjAcOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_uxdPi4uK_sendMessage(_c, 0, m);
  cMsg_PshVKSLp_sendMessage(_c, 0, m);
  cMsg_M6PX3Cwu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zn9iSg0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_uxdPi4uK_sendMessage(_c, 0, m);
  cMsg_KtjatnOf_sendMessage(_c, 0, m);
  cMsg_JIf9OUF5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_41CeV0Rv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZvFGGwir_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hHSFKXAp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C7JZknOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZvFGGwir_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hHSFKXAp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Dji4tak0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Hk7NiMcP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XbwGaVLG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CAtgyUw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Hk7NiMcP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XbwGaVLG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O8HmbP2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xB4cqIYW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PrlX6DUe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Gpdi7iZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xB4cqIYW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PrlX6DUe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZgLcTuqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_C7JZknOm_sendMessage(_c, 0, m);
  cMsg_CAtgyUw6_sendMessage(_c, 0, m);
  cMsg_Gpdi7iZj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JaVAaTIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_C7JZknOm_sendMessage(_c, 0, m);
  cMsg_Dji4tak0_sendMessage(_c, 0, m);
  cMsg_O8HmbP2R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hl2h5AFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_41CeV0Rv_sendMessage(_c, 0, m);
  cMsg_CAtgyUw6_sendMessage(_c, 0, m);
  cMsg_O8HmbP2R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MjIiJUhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1pK2Al3X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rrRuV0HJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zX4Oqi9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1pK2Al3X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rrRuV0HJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LdocIVbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_I23kHuXa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3hpoUQmQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2q2YRGcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_I23kHuXa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3hpoUQmQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0SCl5trl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U8TYHU2J_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bAYR3TMP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R4H4mf1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U8TYHU2J_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bAYR3TMP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WNap41ZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_MjIiJUhN_sendMessage(_c, 0, m);
  cMsg_2q2YRGcn_sendMessage(_c, 0, m);
  cMsg_R4H4mf1Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_obOdWTjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_zX4Oqi9Z_sendMessage(_c, 0, m);
  cMsg_LdocIVbC_sendMessage(_c, 0, m);
  cMsg_R4H4mf1Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4wJacPVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_zX4Oqi9Z_sendMessage(_c, 0, m);
  cMsg_2q2YRGcn_sendMessage(_c, 0, m);
  cMsg_0SCl5trl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VRgEtypy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R9UGRGbN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kWPrLaMA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tlT6W6cn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R9UGRGbN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kWPrLaMA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ii18hP28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_N6ZyIpk1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9RoKbzwG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5WwjgTlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_N6ZyIpk1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9RoKbzwG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_f9cw3oHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nt4kMQcS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wiGgwnC3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SRhHMd10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nt4kMQcS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wiGgwnC3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rRYqyQBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_tlT6W6cn_sendMessage(_c, 0, m);
  cMsg_5WwjgTlg_sendMessage(_c, 0, m);
  cMsg_SRhHMd10_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_09V0JSNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_tlT6W6cn_sendMessage(_c, 0, m);
  cMsg_ii18hP28_sendMessage(_c, 0, m);
  cMsg_f9cw3oHz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UZOm9xvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_VRgEtypy_sendMessage(_c, 0, m);
  cMsg_ii18hP28_sendMessage(_c, 0, m);
  cMsg_SRhHMd10_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JdzHqSm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_41CeV0Rv_sendMessage(_c, 0, m);
  cMsg_Dji4tak0_sendMessage(_c, 0, m);
  cMsg_Gpdi7iZj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cOPZM6eA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_VRgEtypy_sendMessage(_c, 0, m);
  cMsg_5WwjgTlg_sendMessage(_c, 0, m);
  cMsg_f9cw3oHz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_cOWXTprG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TRXYVsol_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JY1jwUpi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Tg3OiwRR, 0, m, &cSlice_Tg3OiwRR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MJdwq6Rd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Tg3OiwRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cPZjo3j5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cPZjo3j5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_n7RFc5X8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cPZjo3j5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_cPZjo3j5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hCNxj7fa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_H8naOuME_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SgRUIicr, 0, m, &cSlice_SgRUIicr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ib3s0JnX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_SgRUIicr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_j85mVG5U_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_j85mVG5U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_NuZMECkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_j85mVG5U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_j85mVG5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GdX12s4I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ib3s0JnX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GpDv10kv, 0, m, &cSlice_GpDv10kv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JY1jwUpi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_GpDv10kv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cUsHsmsX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cUsHsmsX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_85r93S0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cUsHsmsX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_cUsHsmsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yXHzWMBz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MJdwq6Rd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WJlamLdA, 0, m, &cSlice_WJlamLdA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QV2XQvoH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_WJlamLdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dMRkuIAz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dMRkuIAz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_c3gLPIC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dMRkuIAz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dMRkuIAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Jyb17J7t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QV2XQvoH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uxI6e4O6, 0, m, &cSlice_uxI6e4O6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wlLS3wXP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_uxI6e4O6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iEy7JIxY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iEy7JIxY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Br5OWdTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iEy7JIxY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_iEy7JIxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jwg0BVYC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nfRcZCTe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9sRIkGTy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9sRIkGTy_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RMzxaWnP, 1, m, &cDelay_RMzxaWnP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkrgkSR7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RMzxaWnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RMzxaWnP, m);
  cMsg_HoervUPW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9sRIkGTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RMzxaWnP, 0, m, &cDelay_RMzxaWnP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nkrgkSR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RMzxaWnP, 0, m, &cDelay_RMzxaWnP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_AglgkQpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WlrDvfY5, HV_BINOP_SUBTRACT, 0, m, &cBinop_WlrDvfY5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_A70OWdIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ogWtPd5y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5wLJCNIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ogWtPd5y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_BCUizeyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AglgkQpw, 0, m, &cVar_AglgkQpw_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_KM6l8BCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fwDsMl9r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ctfblg1R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9D3XqH89_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WlrDvfY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hnr47Emz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hnr47Emz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1fc3kqOn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1fc3kqOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_4INhLyNz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xhOFQ2c2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6xC1b8MB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_openVwfv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_openVwfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ujcgWtk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_6xC1b8MB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A70OWdIS, 1, m, &cIf_A70OWdIS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rcJ1cM67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5wLJCNIS, 1, m, &cIf_5wLJCNIS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2ujcgWtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_A70OWdIS, 0, m, &cIf_A70OWdIS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4INhLyNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5wLJCNIS, 0, m, &cIf_5wLJCNIS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ctfblg1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WlrDvfY5, HV_BINOP_SUBTRACT, 1, m, &cBinop_WlrDvfY5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fwDsMl9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_9D3XqH89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AglgkQpw, 0, m, &cVar_AglgkQpw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ogWtPd5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0CWc1D0p, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wlLS3wXP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UkWkthuw, 0, m, &cSlice_UkWkthuw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_UkWkthuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ANawjRid_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ANawjRid_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_jIbOsbuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ANawjRid_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ANawjRid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MKufJJhs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zVVSegu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gGQzqAlO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rn2ZQkQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mbYyBrS7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_foDwT9lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zH6ilnJZ, 0, m, &cVar_zH6ilnJZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TRXYVsol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uW0vG9pL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sJNnKpHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nfRcZCTe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2PkA8gJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sqSYl1Fo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HoervUPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LrBXUQk6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sqSYl1Fo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LrBXUQk6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IzYBs4Sx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_xxMmUwBQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xxMmUwBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cP7TphBL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cP7TphBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HlyeOxQy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_8r1jjJs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WcLzPLqi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_sElN3TEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3b2z4oUw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lRhpMoze_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QkVM05zy_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NBX7F1Ew_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z9zx0G4n_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mKLmtILf_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jTeCGvhH_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iz3HIf2G_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_QkVM05zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1mg4szaE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_NBX7F1Ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SMeyAslS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_z9zx0G4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pUmCgF7j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_mKLmtILf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FZ3EUHvD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jTeCGvhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rLYj5uKv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_iz3HIf2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yVujnH07_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_ghj8usLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FCPy1zBl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_429WOeVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xaFHe8eM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4mlAm01a_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CObdHi4U_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CObdHi4U_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mGnL3XmW, 1, m, &cDelay_mGnL3XmW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BvM75pwC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mGnL3XmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mGnL3XmW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ghj8usLp, 0, m, &cIf_ghj8usLp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CObdHi4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mGnL3XmW, 0, m, &cDelay_mGnL3XmW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BvM75pwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mGnL3XmW, 0, m, &cDelay_mGnL3XmW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TlzFntnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nq49O7xM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8oNJe4yD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_URLdmxhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fbWcG2e9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kASVHhQy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kASVHhQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4mlAm01a_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fbWcG2e9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ghj8usLp, 1, m, &cIf_ghj8usLp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8oNJe4yD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_429WOeVx, 0, m, &cIf_429WOeVx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nq49O7xM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_429WOeVx, 1, m, &cIf_429WOeVx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xaFHe8eM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F1NRnlab, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FCPy1zBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F1NRnlab, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PyCtxq3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lHlL2pkg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DRaWn2PA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_A3gVr3rl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0QAdDs0X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_H189DmZk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_H189DmZk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6tnyDIjF, 1, m, &cDelay_6tnyDIjF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KyUNnxMA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6tnyDIjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6tnyDIjF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PyCtxq3t, 0, m, &cIf_PyCtxq3t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H189DmZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6tnyDIjF, 0, m, &cDelay_6tnyDIjF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KyUNnxMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6tnyDIjF, 0, m, &cDelay_6tnyDIjF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J6FcDeHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IHRj9lQl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9T38K1gD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_saEnRfxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HobAUehP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7w16Q9SJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HobAUehP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PyCtxq3t, 1, m, &cIf_PyCtxq3t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7w16Q9SJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0QAdDs0X_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_IHRj9lQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DRaWn2PA, 1, m, &cIf_DRaWn2PA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9T38K1gD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DRaWn2PA, 0, m, &cIf_DRaWn2PA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_A3gVr3rl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QE4US8el, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lHlL2pkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QE4US8el, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_iHmKKdbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UgbVhYD7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_SpNo87N9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4Q1XmlSU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FXLmzMAL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4y3D60LH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4y3D60LH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CPh6Okrm, 1, m, &cDelay_CPh6Okrm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WilY0GjS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CPh6Okrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CPh6Okrm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iHmKKdbn, 0, m, &cIf_iHmKKdbn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4y3D60LH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CPh6Okrm, 0, m, &cDelay_CPh6Okrm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WilY0GjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CPh6Okrm, 0, m, &cDelay_CPh6Okrm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OJYGe36h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0Qui2MP0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zIJGv1NR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HNSA3VxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YCyAF5Lw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rRNtlZ0v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rRNtlZ0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FXLmzMAL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YCyAF5Lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iHmKKdbn, 1, m, &cIf_iHmKKdbn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0Qui2MP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SpNo87N9, 1, m, &cIf_SpNo87N9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zIJGv1NR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SpNo87N9, 0, m, &cIf_SpNo87N9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4Q1XmlSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s9zea3B0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UgbVhYD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s9zea3B0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_QxZhU89B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jmgqSVJw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WIefDMrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ffoXlKPg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_y8m57Jiz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WuMoYSlU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WuMoYSlU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_13bsvVmQ, 1, m, &cDelay_13bsvVmQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xlDskJKd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_13bsvVmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_13bsvVmQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QxZhU89B, 0, m, &cIf_QxZhU89B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WuMoYSlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_13bsvVmQ, 0, m, &cDelay_13bsvVmQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xlDskJKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_13bsvVmQ, 0, m, &cDelay_13bsvVmQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e5v62b7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IKIWSk0B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e8Fa7bqB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pK4hIayk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xoasiHto_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J1sgFFXw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J1sgFFXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_y8m57Jiz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xoasiHto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QxZhU89B, 1, m, &cIf_QxZhU89B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e8Fa7bqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WIefDMrO, 0, m, &cIf_WIefDMrO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IKIWSk0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WIefDMrO, 1, m, &cIf_WIefDMrO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ffoXlKPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AtddN7ak, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jmgqSVJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AtddN7ak, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Y38P0DJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4CuRVC6z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FpM58E0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Hl0NxuiS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LPgnr5vv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZW20OIPs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZW20OIPs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_64KbzPzo, 1, m, &cDelay_64KbzPzo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8cdyw2pP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_64KbzPzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_64KbzPzo, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Y38P0DJP, 0, m, &cIf_Y38P0DJP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZW20OIPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_64KbzPzo, 0, m, &cDelay_64KbzPzo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8cdyw2pP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_64KbzPzo, 0, m, &cDelay_64KbzPzo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QQbhCe58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ihjGz5Bf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5UdavZbu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ti4cWvGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ymBscFn6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3y2XUsK9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3y2XUsK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LPgnr5vv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ymBscFn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y38P0DJP, 1, m, &cIf_Y38P0DJP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5UdavZbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FpM58E0r, 0, m, &cIf_FpM58E0r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ihjGz5Bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FpM58E0r, 1, m, &cIf_FpM58E0r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Hl0NxuiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XfjpVt35, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4CuRVC6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XfjpVt35, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_K3A5TcZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s8igi8r1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_TE8XDhV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sCfDrsEl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lWUkufTp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QB5q7ISg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QB5q7ISg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AYry6BZV, 1, m, &cDelay_AYry6BZV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hYZiSz0t_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AYry6BZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AYry6BZV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_K3A5TcZ1, 0, m, &cIf_K3A5TcZ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QB5q7ISg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AYry6BZV, 0, m, &cDelay_AYry6BZV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hYZiSz0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AYry6BZV, 0, m, &cDelay_AYry6BZV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ma69VdJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9rU8FQOh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3LDGKYAd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2K9SQVlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DpFCCUNM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zAUuPNrv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zAUuPNrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lWUkufTp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_DpFCCUNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K3A5TcZ1, 1, m, &cIf_K3A5TcZ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3LDGKYAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TE8XDhV9, 0, m, &cIf_TE8XDhV9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9rU8FQOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TE8XDhV9, 1, m, &cIf_TE8XDhV9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sCfDrsEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gUkDy3T9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_s8igi8r1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gUkDy3T9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_kAiSoQdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZD5bynTL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Msw0PTwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hS5U2Y1D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xilDPAj4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5AvuJnju_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5AvuJnju_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_T28BYXwx, 1, m, &cDelay_T28BYXwx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zQN6ey1K_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_T28BYXwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_T28BYXwx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kAiSoQdR, 0, m, &cIf_kAiSoQdR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5AvuJnju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_T28BYXwx, 0, m, &cDelay_T28BYXwx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zQN6ey1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_T28BYXwx, 0, m, &cDelay_T28BYXwx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9c7LCaGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EAalpvxf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mxcLEBkQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hd13pqoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JLHvk2fG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JENwOuAC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JENwOuAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xilDPAj4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JLHvk2fG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kAiSoQdR, 1, m, &cIf_kAiSoQdR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mxcLEBkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Msw0PTwr, 0, m, &cIf_Msw0PTwr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EAalpvxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Msw0PTwr, 1, m, &cIf_Msw0PTwr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hS5U2Y1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_adKn952P, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZD5bynTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_adKn952P, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_DI3LmWyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JKNNUY6i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YIZm0osh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Bnjy5RwY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_C7ZVk7Zq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vPAln3Re_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vPAln3Re_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MB1x9Jis, 1, m, &cDelay_MB1x9Jis_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n4gquJCJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MB1x9Jis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MB1x9Jis, m);
  cIf_onMessage(_c, &Context(_c)->cIf_DI3LmWyD, 0, m, &cIf_DI3LmWyD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vPAln3Re_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MB1x9Jis, 0, m, &cDelay_MB1x9Jis_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n4gquJCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MB1x9Jis, 0, m, &cDelay_MB1x9Jis_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f9nvxObP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E2R1J8qc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d2VPk0q5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1TrLEpjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GrTX4EH9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xWiZJbeZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GrTX4EH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DI3LmWyD, 1, m, &cIf_DI3LmWyD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xWiZJbeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_C7ZVk7Zq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_d2VPk0q5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YIZm0osh, 0, m, &cIf_YIZm0osh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E2R1J8qc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YIZm0osh, 1, m, &cIf_YIZm0osh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Bnjy5RwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TH16F7y8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JKNNUY6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TH16F7y8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PJ8UeAYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YluVEvIU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2RdOviKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vMdZ4UqW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kClLWE2u_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ogpfppa3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ogpfppa3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_T8bWFNYw, 1, m, &cDelay_T8bWFNYw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dpHyvhpP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_T8bWFNYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_T8bWFNYw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PJ8UeAYl, 0, m, &cIf_PJ8UeAYl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ogpfppa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_T8bWFNYw, 0, m, &cDelay_T8bWFNYw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dpHyvhpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_T8bWFNYw, 0, m, &cDelay_T8bWFNYw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D5c81Qma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xUvU8Bsf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EkJR4zUU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EtZmb6M8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gfEOYW5R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3FxnbjH2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3FxnbjH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kClLWE2u_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gfEOYW5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PJ8UeAYl, 1, m, &cIf_PJ8UeAYl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EkJR4zUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2RdOviKl, 0, m, &cIf_2RdOviKl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xUvU8Bsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2RdOviKl, 1, m, &cIf_2RdOviKl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vMdZ4UqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mmONQ0k0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YluVEvIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mmONQ0k0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_bjta63IU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NMyhHe7P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_GvRUyyFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uRhVvI9P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lasv83t8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TNI7FAxG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TNI7FAxG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MWgNY9cH, 1, m, &cDelay_MWgNY9cH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HX8xU5gH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MWgNY9cH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MWgNY9cH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bjta63IU, 0, m, &cIf_bjta63IU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TNI7FAxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MWgNY9cH, 0, m, &cDelay_MWgNY9cH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HX8xU5gH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MWgNY9cH, 0, m, &cDelay_MWgNY9cH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Rk4mf3gS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gL4fPM1T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NuHLFcPj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0wL3ss1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_79FaQf7E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9vRnSPOQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9vRnSPOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lasv83t8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_79FaQf7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bjta63IU, 1, m, &cIf_bjta63IU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NuHLFcPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GvRUyyFE, 0, m, &cIf_GvRUyyFE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gL4fPM1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GvRUyyFE, 1, m, &cIf_GvRUyyFE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uRhVvI9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o0q5LLrD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NMyhHe7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o0q5LLrD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xEynUhUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gKhagQH5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HFlnCSZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wKdmmi37_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gKji7iAS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uD9zwrTo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uD9zwrTo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_DdPsVTvk, 1, m, &cDelay_DdPsVTvk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WM8PTMqO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_DdPsVTvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DdPsVTvk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xEynUhUU, 0, m, &cIf_xEynUhUU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uD9zwrTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DdPsVTvk, 0, m, &cDelay_DdPsVTvk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WM8PTMqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DdPsVTvk, 0, m, &cDelay_DdPsVTvk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mxkQ0N24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KKup6SWF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V6Vh3mfS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZBIgCtrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FBOrxtLH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j1J7y1kY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j1J7y1kY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gKji7iAS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FBOrxtLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xEynUhUU, 1, m, &cIf_xEynUhUU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V6Vh3mfS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HFlnCSZl, 0, m, &cIf_HFlnCSZl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KKup6SWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HFlnCSZl, 1, m, &cIf_HFlnCSZl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wKdmmi37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gKRjP5rj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gKhagQH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gKRjP5rj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OeAGC0oG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eaon5n3f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ePryvCLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xV4QLLIA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8Yu0JmoN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PH8bFZLm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PH8bFZLm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vRuVgbgY, 1, m, &cDelay_vRuVgbgY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3HAFf6B9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vRuVgbgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vRuVgbgY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OeAGC0oG, 0, m, &cIf_OeAGC0oG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PH8bFZLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vRuVgbgY, 0, m, &cDelay_vRuVgbgY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3HAFf6B9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vRuVgbgY, 0, m, &cDelay_vRuVgbgY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4onwoXkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wNWCPMEs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tSQnergi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g7cW4PvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aVG94kWE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8gBEGfpA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aVG94kWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OeAGC0oG, 1, m, &cIf_OeAGC0oG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8gBEGfpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8Yu0JmoN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_tSQnergi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ePryvCLW, 0, m, &cIf_ePryvCLW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wNWCPMEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ePryvCLW, 1, m, &cIf_ePryvCLW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xV4QLLIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qAa16wI6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eaon5n3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qAa16wI6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1mg4szaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_JB2xvYTg_sendMessage(_c, 0, m);
  cMsg_pEy5jU7d_sendMessage(_c, 0, m);
  cMsg_XITYX2fL_sendMessage(_c, 0, m);
  cMsg_VhB2m3zh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SMeyAslS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_JB2xvYTg_sendMessage(_c, 0, m);
  cMsg_DdLsmP5E_sendMessage(_c, 0, m);
  cMsg_nIA39tXF_sendMessage(_c, 0, m);
  cMsg_CMiu9yLB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pUmCgF7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_IR3vhf45_sendMessage(_c, 0, m);
  cMsg_DdLsmP5E_sendMessage(_c, 0, m);
  cMsg_VhB2m3zh_sendMessage(_c, 0, m);
  cMsg_3JEh4QYp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FZ3EUHvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_IR3vhf45_sendMessage(_c, 0, m);
  cMsg_17lwTyR1_sendMessage(_c, 0, m);
  cMsg_XITYX2fL_sendMessage(_c, 0, m);
  cMsg_YA4Qf2tA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rLYj5uKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_alkfn0u1_sendMessage(_c, 0, m);
  cMsg_CMiu9yLB_sendMessage(_c, 0, m);
  cMsg_ZWNKCn2X_sendMessage(_c, 0, m);
  cMsg_XITYX2fL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yVujnH07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_alkfn0u1_sendMessage(_c, 0, m);
  cMsg_YA4Qf2tA_sendMessage(_c, 0, m);
  cMsg_DdLsmP5E_sendMessage(_c, 0, m);
  cMsg_CBBFN8Fc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rVtx04Al_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_URLdmxhK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TlzFntnJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_r21xwHM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_URLdmxhK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TlzFntnJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7ClB6ON2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_saEnRfxM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_J6FcDeHI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3gw9JFAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_saEnRfxM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_J6FcDeHI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8IJRqRni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HNSA3VxV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OJYGe36h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vhhv0RV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HNSA3VxV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OJYGe36h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JB2xvYTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_rVtx04Al_sendMessage(_c, 0, m);
  cMsg_3gw9JFAK_sendMessage(_c, 0, m);
  cMsg_Vhhv0RV4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IR3vhf45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_r21xwHM6_sendMessage(_c, 0, m);
  cMsg_7ClB6ON2_sendMessage(_c, 0, m);
  cMsg_Vhhv0RV4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_alkfn0u1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_r21xwHM6_sendMessage(_c, 0, m);
  cMsg_3gw9JFAK_sendMessage(_c, 0, m);
  cMsg_8IJRqRni_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aM6o7Nuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pK4hIayk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_e5v62b7w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6Xf5kPva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pK4hIayk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_e5v62b7w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_djyblUcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ti4cWvGw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QQbhCe58_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IGwoa3NE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ti4cWvGw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QQbhCe58_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Pwi9fOXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2K9SQVlJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ma69VdJu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WorcqiBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2K9SQVlJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ma69VdJu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DdLsmP5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_6Xf5kPva_sendMessage(_c, 0, m);
  cMsg_IGwoa3NE_sendMessage(_c, 0, m);
  cMsg_WorcqiBB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pEy5jU7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_6Xf5kPva_sendMessage(_c, 0, m);
  cMsg_djyblUcV_sendMessage(_c, 0, m);
  cMsg_Pwi9fOXo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_17lwTyR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_aM6o7Nuv_sendMessage(_c, 0, m);
  cMsg_IGwoa3NE_sendMessage(_c, 0, m);
  cMsg_Pwi9fOXo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_drYJyyZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0wL3ss1q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Rk4mf3gS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zm8oRwdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0wL3ss1q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Rk4mf3gS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rE7qZO90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZBIgCtrs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mxkQ0N24_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qZk8DOId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZBIgCtrs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mxkQ0N24_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wVA1xo0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g7cW4PvK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4onwoXkR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XwOt2kRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g7cW4PvK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4onwoXkR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YA4Qf2tA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_drYJyyZ0_sendMessage(_c, 0, m);
  cMsg_qZk8DOId_sendMessage(_c, 0, m);
  cMsg_XwOt2kRb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CMiu9yLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_zm8oRwdE_sendMessage(_c, 0, m);
  cMsg_rE7qZO90_sendMessage(_c, 0, m);
  cMsg_XwOt2kRb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VhB2m3zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_zm8oRwdE_sendMessage(_c, 0, m);
  cMsg_qZk8DOId_sendMessage(_c, 0, m);
  cMsg_wVA1xo0U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sgwR5cnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hd13pqoq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9c7LCaGU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GcX0vW3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hd13pqoq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9c7LCaGU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XCio3gpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1TrLEpjJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_f9nvxObP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u8nUMggQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1TrLEpjJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_f9nvxObP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PkpBvmpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EtZmb6M8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_D5c81Qma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wh32oLQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EtZmb6M8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_D5c81Qma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XITYX2fL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_GcX0vW3f_sendMessage(_c, 0, m);
  cMsg_u8nUMggQ_sendMessage(_c, 0, m);
  cMsg_wh32oLQ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nIA39tXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_GcX0vW3f_sendMessage(_c, 0, m);
  cMsg_XCio3gpT_sendMessage(_c, 0, m);
  cMsg_PkpBvmpb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CBBFN8Fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_sgwR5cnU_sendMessage(_c, 0, m);
  cMsg_XCio3gpT_sendMessage(_c, 0, m);
  cMsg_wh32oLQ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZWNKCn2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_aM6o7Nuv_sendMessage(_c, 0, m);
  cMsg_djyblUcV_sendMessage(_c, 0, m);
  cMsg_WorcqiBB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3JEh4QYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_sgwR5cnU_sendMessage(_c, 0, m);
  cMsg_u8nUMggQ_sendMessage(_c, 0, m);
  cMsg_PkpBvmpb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_PQ0JWc7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mEYNTJPb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QouFXSyD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sgGbxBNa, 0, m, &cSlice_sgGbxBNa_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MuoyRRdR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_sgGbxBNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4LtAawuq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4LtAawuq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_JFGvcXOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4LtAawuq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_4LtAawuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LCi0PAB5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AHmCCI8G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VYXAVzUZ, 0, m, &cSlice_VYXAVzUZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lnRJZxhU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_VYXAVzUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ODCWemHZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ODCWemHZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_j0J1EHva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ODCWemHZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ODCWemHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8nUMSjxs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lnRJZxhU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4DN050z4, 0, m, &cSlice_4DN050z4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QouFXSyD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_4DN050z4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6UeLrd4u_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6UeLrd4u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_VjQ2qqPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6UeLrd4u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_6UeLrd4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GTEnmwau_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MuoyRRdR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aikWKTNy, 0, m, &cSlice_aikWKTNy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fjFLNvyB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_aikWKTNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DbkhhGiB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DbkhhGiB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_0l2dwnpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DbkhhGiB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_DbkhhGiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jbU572Kj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fjFLNvyB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gYZH7Pwl, 0, m, &cSlice_gYZH7Pwl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UXlxpd19_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gYZH7Pwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pJegXz9U_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pJegXz9U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_2HpZ4ah4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pJegXz9U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_pJegXz9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DXno7MHr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ceu5iICO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_v8EFMqtz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_v8EFMqtz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4EsI3WKB, 1, m, &cDelay_4EsI3WKB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F1A1g6t9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4EsI3WKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4EsI3WKB, m);
  cMsg_waaxrvFt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v8EFMqtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4EsI3WKB, 0, m, &cDelay_4EsI3WKB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F1A1g6t9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4EsI3WKB, 0, m, &cDelay_4EsI3WKB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_mKRYnTrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zNDqUyVr, HV_BINOP_SUBTRACT, 0, m, &cBinop_zNDqUyVr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_Bun4OblK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bpFSfXik_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5Mrjvlha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bpFSfXik_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_ZbWcTrEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mKRYnTrN, 0, m, &cVar_mKRYnTrN_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_jRZfyZe7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dLHmRk4B_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nil6g1JB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZdcskqQd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zNDqUyVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vgvg3hst_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Vgvg3hst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rqwNHHzG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rqwNHHzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_2U4YzeU6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s3cOO0X3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vB5Gsmpr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zXGTG729_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vB5Gsmpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bun4OblK, 1, m, &cIf_Bun4OblK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zXGTG729_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xfbmTjn5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_pefNx7bX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5Mrjvlha, 1, m, &cIf_5Mrjvlha_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xfbmTjn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Bun4OblK, 0, m, &cIf_Bun4OblK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2U4YzeU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5Mrjvlha, 0, m, &cIf_5Mrjvlha_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dLHmRk4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_ZdcskqQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mKRYnTrN, 0, m, &cVar_mKRYnTrN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nil6g1JB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zNDqUyVr, HV_BINOP_SUBTRACT, 1, m, &cBinop_zNDqUyVr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bpFSfXik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j9iVez3r, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UXlxpd19_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pbbz9Wtf, 0, m, &cSlice_pbbz9Wtf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_pbbz9Wtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_u8mF5tw6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_u8mF5tw6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3L3pXb7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_u8mF5tw6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_u8mF5tw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NHhlrOw9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WcLzPLqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xSrlWqJI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3b2z4oUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F86lFQ5w, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_PxPEamr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sElN3TEl, 0, m, &cVar_sElN3TEl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mEYNTJPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B1R7OPFy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_KAL02zyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NUc7kkVQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_2ljW0l0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ceu5iICO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_waaxrvFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dngmJLbk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NUc7kkVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dngmJLbk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DapvS51a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_ygy3WU5n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ygy3WU5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xlUzW6H9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xlUzW6H9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MxR9ZKIf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_C9Z2lDRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WGXGm6jl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_QfrneSS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_06negG0J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_xramEk4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xEYsB0bf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9q9SOcbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xXUHhZTS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_alVox0ps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cqYfjzN3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_YsZqaxoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hQ5en7fN_sendMessage);
  cMsg_MVgmRfrG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_hQ5en7fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YsZqaxoL, 1, m, &cVar_YsZqaxoL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ovnVcyBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xc5NZcNP_sendMessage(_c, 0, m);
  cMsg_pC3MLICa_sendMessage(_c, 0, m);
  cMsg_5L1JorEQ_sendMessage(_c, 0, m);
  cMsg_WyWeCiVQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UfrTMLbu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_diSGsyuK, 0, m, &cSlice_diSGsyuK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_diSGsyuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yfwWk5q8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yfwWk5q8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qy2T9dSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yfwWk5q8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yfwWk5q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NWRTSUmf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_hU6TO4pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_f1vVT4nH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f1vVT4nH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_QhDmRwgm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QhDmRwgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_dE468fTK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dE468fTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QOH1F1Ac_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bbAw4Snn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bbAw4Snn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Z9UZ54c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_QOH1F1Ac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Y0vojsU7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Y0vojsU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Eobb59DD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7Z9UZ54c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wgIw49F4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wgIw49F4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CVAyV8Ad_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Eobb59DD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6lwKceup_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CVAyV8Ad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4lcm9Pcx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6lwKceup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ElI9PlYs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4lcm9Pcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9Dk1OErN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_kjfh58CW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rdj9ARgM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Ld4SavDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AhW1DwYb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0o0egYYI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GYbd0RNN_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3UqV89bX_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fPd1HUZT_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E7pfjqVt_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_96ffj33Z_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_82UqJ7Yo_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_GYbd0RNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oTVpIdma_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_3UqV89bX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_npEDua8d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_fPd1HUZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NujYA0Os_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_E7pfjqVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jv3CbLsO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_96ffj33Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_97ieHf1j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_82UqJ7Yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aiINLcq4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_onpd118V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WlKCsSXN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_joGt9nQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LqyDlvtc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cJyhvDqN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_enOC5j3B_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_enOC5j3B_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_O1dNuno0, 1, m, &cDelay_O1dNuno0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9R9RyXtX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_O1dNuno0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_O1dNuno0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_onpd118V, 0, m, &cIf_onpd118V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_enOC5j3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_O1dNuno0, 0, m, &cDelay_O1dNuno0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9R9RyXtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_O1dNuno0, 0, m, &cDelay_O1dNuno0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qjNIkLzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h0VptyN4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j57uCI4j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NCXuUXsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SAH0fdYi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o3SvDY3L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_o3SvDY3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cJyhvDqN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SAH0fdYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_onpd118V, 1, m, &cIf_onpd118V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j57uCI4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_joGt9nQB, 0, m, &cIf_joGt9nQB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h0VptyN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_joGt9nQB, 1, m, &cIf_joGt9nQB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LqyDlvtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YoVWbcln, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WlKCsSXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YoVWbcln, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5F8fEERk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fLfN52am_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kIooVKKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lBHzxEp5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gywz8Voz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dh2jHTBp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dh2jHTBp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_L7THvo0J, 1, m, &cDelay_L7THvo0J_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h41n2Idw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_L7THvo0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_L7THvo0J, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5F8fEERk, 0, m, &cIf_5F8fEERk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dh2jHTBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_L7THvo0J, 0, m, &cDelay_L7THvo0J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h41n2Idw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_L7THvo0J, 0, m, &cDelay_L7THvo0J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HVC1Spe3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YO1JHQzM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xZlfFCY2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5c6h8cSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QxxAZzJ0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9xyC1WZo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9xyC1WZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gywz8Voz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QxxAZzJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5F8fEERk, 1, m, &cIf_5F8fEERk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xZlfFCY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kIooVKKW, 0, m, &cIf_kIooVKKW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YO1JHQzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kIooVKKW, 1, m, &cIf_kIooVKKW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lBHzxEp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Gby8D26P, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fLfN52am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Gby8D26P, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_adj6PEyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dXGp0RYc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_pcVMcAcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_J96j6Lac_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_au9aHlrb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Sz3AWqCm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Sz3AWqCm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6wmQ7Kcy, 1, m, &cDelay_6wmQ7Kcy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H97nbGB1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6wmQ7Kcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6wmQ7Kcy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_adj6PEyh, 0, m, &cIf_adj6PEyh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Sz3AWqCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6wmQ7Kcy, 0, m, &cDelay_6wmQ7Kcy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H97nbGB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6wmQ7Kcy, 0, m, &cDelay_6wmQ7Kcy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PrKferPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cNfey2Zn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e1AYtqlP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BLhzxaJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IW7uk0I3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6JdTTrKc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6JdTTrKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_au9aHlrb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_IW7uk0I3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_adj6PEyh, 1, m, &cIf_adj6PEyh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e1AYtqlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pcVMcAcB, 0, m, &cIf_pcVMcAcB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cNfey2Zn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pcVMcAcB, 1, m, &cIf_pcVMcAcB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J96j6Lac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_US0RuV7m, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dXGp0RYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_US0RuV7m, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NeEbBbMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1RyIsvIm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7byDdM3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FBFrkpcM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rVLRbECX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aDe77jFK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aDe77jFK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kF9c4RKq, 1, m, &cDelay_kF9c4RKq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oTEgMgye_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kF9c4RKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kF9c4RKq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NeEbBbMD, 0, m, &cIf_NeEbBbMD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aDe77jFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kF9c4RKq, 0, m, &cDelay_kF9c4RKq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oTEgMgye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kF9c4RKq, 0, m, &cDelay_kF9c4RKq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9laT7RWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sl7df0l9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rb5Zgq8m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jpHLnJmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LHJVjQwv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hi79M0cV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hi79M0cV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rVLRbECX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LHJVjQwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NeEbBbMD, 1, m, &cIf_NeEbBbMD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Sl7df0l9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7byDdM3i, 1, m, &cIf_7byDdM3i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Rb5Zgq8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7byDdM3i, 0, m, &cIf_7byDdM3i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FBFrkpcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fAmvIqX1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1RyIsvIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fAmvIqX1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GiPeOTOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WzxECway_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6fHzxva6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qOPJbzwX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_C55iX4fz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ddp9dMXL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ddp9dMXL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_e4XKHAxA, 1, m, &cDelay_e4XKHAxA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_efhOxE9H_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_e4XKHAxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_e4XKHAxA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GiPeOTOk, 0, m, &cIf_GiPeOTOk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ddp9dMXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_e4XKHAxA, 0, m, &cDelay_e4XKHAxA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_efhOxE9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_e4XKHAxA, 0, m, &cDelay_e4XKHAxA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GGfUIkrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QcgiVsKF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AHlPpw2j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4EoBc4KC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MVFSaxJ3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bZQay6i6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bZQay6i6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_C55iX4fz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MVFSaxJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GiPeOTOk, 1, m, &cIf_GiPeOTOk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AHlPpw2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6fHzxva6, 0, m, &cIf_6fHzxva6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QcgiVsKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6fHzxva6, 1, m, &cIf_6fHzxva6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qOPJbzwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DS98NZZM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WzxECway_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DS98NZZM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oM4jF1Bo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JXwhPdiK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UjYI7Lot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Wc6BC7ee_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HtMoFcPg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ohvbmv8O_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ohvbmv8O_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xLLX1hJF, 1, m, &cDelay_xLLX1hJF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9xY048ta_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xLLX1hJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xLLX1hJF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oM4jF1Bo, 0, m, &cIf_oM4jF1Bo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ohvbmv8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xLLX1hJF, 0, m, &cDelay_xLLX1hJF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9xY048ta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xLLX1hJF, 0, m, &cDelay_xLLX1hJF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jqob0huQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FETNGlnv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Akb0SxdM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y1qmnuEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rbveVAWl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E1lKSuOU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E1lKSuOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HtMoFcPg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rbveVAWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oM4jF1Bo, 1, m, &cIf_oM4jF1Bo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Akb0SxdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UjYI7Lot, 0, m, &cIf_UjYI7Lot_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FETNGlnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UjYI7Lot, 1, m, &cIf_UjYI7Lot_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wc6BC7ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LNUiYcAv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JXwhPdiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LNUiYcAv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NgY4v3F4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JYSr4fd0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wzMRsxGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3aWrDKjX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MHzG5ZOg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2xtgFxmQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2xtgFxmQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jop5rzk7, 1, m, &cDelay_jop5rzk7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xNEMVAO3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jop5rzk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jop5rzk7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NgY4v3F4, 0, m, &cIf_NgY4v3F4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2xtgFxmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jop5rzk7, 0, m, &cDelay_jop5rzk7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xNEMVAO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jop5rzk7, 0, m, &cDelay_jop5rzk7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9wjJ9Vxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_400bL4Qu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RpjGZvPd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0twRhHHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_knXZkILR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pasL8EzN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pasL8EzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MHzG5ZOg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_knXZkILR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NgY4v3F4, 1, m, &cIf_NgY4v3F4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RpjGZvPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wzMRsxGt, 0, m, &cIf_wzMRsxGt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_400bL4Qu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wzMRsxGt, 1, m, &cIf_wzMRsxGt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3aWrDKjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XV3hsCd4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JYSr4fd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XV3hsCd4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_UB0zNEpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Pm6cB0Ag_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WSq9HN6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pKcq5eZn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VABFCzZZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hATJGwrv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hATJGwrv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cR6J84ma, 1, m, &cDelay_cR6J84ma_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_npr6KaS8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cR6J84ma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cR6J84ma, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UB0zNEpM, 0, m, &cIf_UB0zNEpM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hATJGwrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cR6J84ma, 0, m, &cDelay_cR6J84ma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_npr6KaS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cR6J84ma, 0, m, &cDelay_cR6J84ma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VIR5Trl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tNTW3WEV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JTFOkbOI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LHQppaoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Utc4NwM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UXvoimGf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UXvoimGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VABFCzZZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5Utc4NwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UB0zNEpM, 1, m, &cIf_UB0zNEpM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JTFOkbOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WSq9HN6T, 0, m, &cIf_WSq9HN6T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tNTW3WEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WSq9HN6T, 1, m, &cIf_WSq9HN6T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pKcq5eZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rulvoW8b, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Pm6cB0Ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rulvoW8b, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_z3SRlci1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PABRaTTd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Yp4EAEDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5KS1dtAt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1rKWJ1GS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vVd84Vg3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vVd84Vg3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ISrqKmGW, 1, m, &cDelay_ISrqKmGW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fu8UKaS8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ISrqKmGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ISrqKmGW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_z3SRlci1, 0, m, &cIf_z3SRlci1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vVd84Vg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ISrqKmGW, 0, m, &cDelay_ISrqKmGW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fu8UKaS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ISrqKmGW, 0, m, &cDelay_ISrqKmGW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HZMDbOby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GkxI9YGf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i9mlzdP2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DBvrHH0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dAHycu8M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5YzMDUys_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dAHycu8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z3SRlci1, 1, m, &cIf_z3SRlci1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5YzMDUys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1rKWJ1GS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_i9mlzdP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yp4EAEDN, 0, m, &cIf_Yp4EAEDN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GkxI9YGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yp4EAEDN, 1, m, &cIf_Yp4EAEDN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5KS1dtAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KTQi2dUc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PABRaTTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KTQi2dUc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_UCsewp2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JJlwq6X5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ggLaSgcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Iy8pyWIt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FxVuNBmd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2H3idLSa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2H3idLSa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Duj4M3bC, 1, m, &cDelay_Duj4M3bC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8N50TDTD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Duj4M3bC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Duj4M3bC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UCsewp2k, 0, m, &cIf_UCsewp2k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2H3idLSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Duj4M3bC, 0, m, &cDelay_Duj4M3bC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8N50TDTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Duj4M3bC, 0, m, &cDelay_Duj4M3bC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0Zl8smy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DxneOmMI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OeO14Pka_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CPkFbAzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5LsS8g3K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OiFLz3sW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5LsS8g3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UCsewp2k, 1, m, &cIf_UCsewp2k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OiFLz3sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FxVuNBmd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_DxneOmMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ggLaSgcE, 1, m, &cIf_ggLaSgcE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OeO14Pka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ggLaSgcE, 0, m, &cIf_ggLaSgcE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Iy8pyWIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7kcbiean, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JJlwq6X5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7kcbiean, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jfuGJxw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uguld98o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_uemAYJap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7ICkioLi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_K3RfjGff_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2nFJAmDy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2nFJAmDy_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Y25HzZLf, 1, m, &cDelay_Y25HzZLf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IjQAh6IG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Y25HzZLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y25HzZLf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jfuGJxw3, 0, m, &cIf_jfuGJxw3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2nFJAmDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y25HzZLf, 0, m, &cDelay_Y25HzZLf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IjQAh6IG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y25HzZLf, 0, m, &cDelay_Y25HzZLf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Blqhtl7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LqzbceXZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fTi29n6y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dxWrNFPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iPAtpx1A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_85LLGY0B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iPAtpx1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jfuGJxw3, 1, m, &cIf_jfuGJxw3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_85LLGY0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_K3RfjGff_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LqzbceXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uemAYJap, 1, m, &cIf_uemAYJap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fTi29n6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uemAYJap, 0, m, &cIf_uemAYJap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7ICkioLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1y9MnWiR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uguld98o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1y9MnWiR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_IlEGdRQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_y1JtzTD9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ljH4Bqer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DrVO7Am7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZQaDpCoo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zOnj48t4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zOnj48t4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tXueBXUs, 1, m, &cDelay_tXueBXUs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LMjDSOmj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tXueBXUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tXueBXUs, m);
  cIf_onMessage(_c, &Context(_c)->cIf_IlEGdRQc, 0, m, &cIf_IlEGdRQc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zOnj48t4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tXueBXUs, 0, m, &cDelay_tXueBXUs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LMjDSOmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tXueBXUs, 0, m, &cDelay_tXueBXUs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NRGogDqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Evs6sQXC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cu6V0PAe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Xh4G8ruC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lo5NJYMV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YmfEQUyG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YmfEQUyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZQaDpCoo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lo5NJYMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IlEGdRQc, 1, m, &cIf_IlEGdRQc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Cu6V0PAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ljH4Bqer, 0, m, &cIf_ljH4Bqer_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Evs6sQXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ljH4Bqer, 1, m, &cIf_ljH4Bqer_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DrVO7Am7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vq9Uo03o, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_y1JtzTD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vq9Uo03o, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oTVpIdma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_ijlwV74l_sendMessage(_c, 0, m);
  cMsg_bDfZ9VpE_sendMessage(_c, 0, m);
  cMsg_hjQUwNzS_sendMessage(_c, 0, m);
  cMsg_5bZ0bv9R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_npEDua8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_ijlwV74l_sendMessage(_c, 0, m);
  cMsg_eAy0C4oj_sendMessage(_c, 0, m);
  cMsg_RjfUvmJz_sendMessage(_c, 0, m);
  cMsg_fRhRykvl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NujYA0Os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_w66o16FD_sendMessage(_c, 0, m);
  cMsg_eAy0C4oj_sendMessage(_c, 0, m);
  cMsg_5bZ0bv9R_sendMessage(_c, 0, m);
  cMsg_tKgmU8Aj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Jv3CbLsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_w66o16FD_sendMessage(_c, 0, m);
  cMsg_UqZq3njm_sendMessage(_c, 0, m);
  cMsg_hjQUwNzS_sendMessage(_c, 0, m);
  cMsg_Ct773HlI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_97ieHf1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_jOOv5QlT_sendMessage(_c, 0, m);
  cMsg_fRhRykvl_sendMessage(_c, 0, m);
  cMsg_W2kDmUG4_sendMessage(_c, 0, m);
  cMsg_hjQUwNzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aiINLcq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_jOOv5QlT_sendMessage(_c, 0, m);
  cMsg_Ct773HlI_sendMessage(_c, 0, m);
  cMsg_eAy0C4oj_sendMessage(_c, 0, m);
  cMsg_Pd0THU1H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SPtnygbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NCXuUXsC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qjNIkLzy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6UogGHAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NCXuUXsC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qjNIkLzy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UjcnYDVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5c6h8cSp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HVC1Spe3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AFjjj1aQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5c6h8cSp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HVC1Spe3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FzEoXTM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BLhzxaJl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PrKferPT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HLOHhBlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BLhzxaJl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PrKferPT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ijlwV74l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_SPtnygbI_sendMessage(_c, 0, m);
  cMsg_AFjjj1aQ_sendMessage(_c, 0, m);
  cMsg_HLOHhBlb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_w66o16FD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_6UogGHAW_sendMessage(_c, 0, m);
  cMsg_UjcnYDVP_sendMessage(_c, 0, m);
  cMsg_HLOHhBlb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jOOv5QlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_6UogGHAW_sendMessage(_c, 0, m);
  cMsg_AFjjj1aQ_sendMessage(_c, 0, m);
  cMsg_FzEoXTM1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8ZS8ghdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jpHLnJmM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9laT7RWy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gJ9z4djP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jpHLnJmM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9laT7RWy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_960bPC4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4EoBc4KC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GGfUIkrv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7NArQf3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4EoBc4KC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GGfUIkrv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_msBx7ICJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y1qmnuEV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jqob0huQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Yteq3UfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y1qmnuEV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jqob0huQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eAy0C4oj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_gJ9z4djP_sendMessage(_c, 0, m);
  cMsg_7NArQf3M_sendMessage(_c, 0, m);
  cMsg_Yteq3UfW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bDfZ9VpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_gJ9z4djP_sendMessage(_c, 0, m);
  cMsg_960bPC4p_sendMessage(_c, 0, m);
  cMsg_msBx7ICJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UqZq3njm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_8ZS8ghdV_sendMessage(_c, 0, m);
  cMsg_7NArQf3M_sendMessage(_c, 0, m);
  cMsg_msBx7ICJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kkyaH4Kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CPkFbAzI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0Zl8smy1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fZyXUEWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CPkFbAzI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0Zl8smy1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_10cCjwcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dxWrNFPz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Blqhtl7c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_prUPCHBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dxWrNFPz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Blqhtl7c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3VgRxtO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Xh4G8ruC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NRGogDqf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iCe29l9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Xh4G8ruC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NRGogDqf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ct773HlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_kkyaH4Kp_sendMessage(_c, 0, m);
  cMsg_prUPCHBd_sendMessage(_c, 0, m);
  cMsg_iCe29l9X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fRhRykvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_fZyXUEWG_sendMessage(_c, 0, m);
  cMsg_10cCjwcn_sendMessage(_c, 0, m);
  cMsg_iCe29l9X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5bZ0bv9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_fZyXUEWG_sendMessage(_c, 0, m);
  cMsg_prUPCHBd_sendMessage(_c, 0, m);
  cMsg_3VgRxtO9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NJ67fdPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0twRhHHX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9wjJ9Vxe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vVF3yGqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0twRhHHX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9wjJ9Vxe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7kKvQyZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LHQppaoJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VIR5Trl8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4tPvarHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LHQppaoJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VIR5Trl8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l4KbwNFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DBvrHH0K_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HZMDbOby_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kUNcRj8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DBvrHH0K_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HZMDbOby_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hjQUwNzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_vVF3yGqe_sendMessage(_c, 0, m);
  cMsg_4tPvarHS_sendMessage(_c, 0, m);
  cMsg_kUNcRj8k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RjfUvmJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_vVF3yGqe_sendMessage(_c, 0, m);
  cMsg_7kKvQyZf_sendMessage(_c, 0, m);
  cMsg_l4KbwNFr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Pd0THU1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_NJ67fdPB_sendMessage(_c, 0, m);
  cMsg_7kKvQyZf_sendMessage(_c, 0, m);
  cMsg_kUNcRj8k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_W2kDmUG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_8ZS8ghdV_sendMessage(_c, 0, m);
  cMsg_960bPC4p_sendMessage(_c, 0, m);
  cMsg_Yteq3UfW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tKgmU8Aj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_NJ67fdPB_sendMessage(_c, 0, m);
  cMsg_4tPvarHS_sendMessage(_c, 0, m);
  cMsg_l4KbwNFr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_HX9UGaL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rMtFKzmS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WmMZHJKk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2eav210C, 0, m, &cSlice_2eav210C_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cFBjCh2O_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_2eav210C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_P6S91okE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_P6S91okE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_nHBDsWuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P6S91okE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_P6S91okE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fGbmJubB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6FlnY3NO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Xr9s3uT0, 0, m, &cSlice_Xr9s3uT0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LUkSkI2e_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Xr9s3uT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YVCD1OLf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YVCD1OLf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Fu0RGTOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YVCD1OLf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_YVCD1OLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zz7hYlhB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LUkSkI2e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9LIaU37Q, 0, m, &cSlice_9LIaU37Q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WmMZHJKk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9LIaU37Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_epsVQlaE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_epsVQlaE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_zzD7s9V3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_epsVQlaE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_epsVQlaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pPixn0UN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cFBjCh2O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CLVvaqQS, 0, m, &cSlice_CLVvaqQS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZyPfW27c_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_CLVvaqQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5R7dg4BJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5R7dg4BJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_LeHQTddB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5R7dg4BJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5R7dg4BJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rKWJFMgn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZyPfW27c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0Oy9qBn4, 0, m, &cSlice_0Oy9qBn4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lhJPQ9LQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0Oy9qBn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9cyRXPF3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9cyRXPF3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_1ajPrGv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9cyRXPF3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9cyRXPF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_m0DEBlAj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_D2pSJUM3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RNY2d97s_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RNY2d97s_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5YzlATna, 1, m, &cDelay_5YzlATna_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i4zUxgVs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5YzlATna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5YzlATna, m);
  cMsg_uwfW2jJU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RNY2d97s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5YzlATna, 0, m, &cDelay_5YzlATna_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i4zUxgVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5YzlATna, 0, m, &cDelay_5YzlATna_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_7ai6HrlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_clmRpkFc, HV_BINOP_SUBTRACT, 0, m, &cBinop_clmRpkFc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_kTknJ4IN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aZHOS6pc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5x4NnjQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aZHOS6pc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_unUtm1qA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7ai6HrlG, 0, m, &cVar_7ai6HrlG_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_dsffpoPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OggXMt2L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JPmJRspx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RF9PAYXo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_clmRpkFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IySYiJKG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IySYiJKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SmX6774R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SmX6774R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_axwSAVJV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Gft26hOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_50pCNrju_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SRZWP8UP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_50pCNrju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kTknJ4IN, 1, m, &cIf_kTknJ4IN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SRZWP8UP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QYsETfrZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vGMKTXcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5x4NnjQJ, 1, m, &cIf_5x4NnjQJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QYsETfrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_kTknJ4IN, 0, m, &cIf_kTknJ4IN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_axwSAVJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5x4NnjQJ, 0, m, &cIf_5x4NnjQJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OggXMt2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_RF9PAYXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7ai6HrlG, 0, m, &cVar_7ai6HrlG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JPmJRspx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_clmRpkFc, HV_BINOP_SUBTRACT, 1, m, &cBinop_clmRpkFc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aZHOS6pc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_neW54wkG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lhJPQ9LQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6zlHNZR8, 0, m, &cSlice_6zlHNZR8_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_6zlHNZR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_n1BxAVb0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_n1BxAVb0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_eRgFbCt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n1BxAVb0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_n1BxAVb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ttZ4dY9j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rdj9ARgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rFnOWmyY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AhW1DwYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h3YyEIwv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_aoHXfIMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ld4SavDd, 0, m, &cVar_Ld4SavDd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rMtFKzmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zifyF84m, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_UmDXorZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mKlkPoHG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_7Php8fxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_D2pSJUM3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uwfW2jJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8rJgERe9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mKlkPoHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8rJgERe9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dz7JvEnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_8AFkGnR1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8AFkGnR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I6WjSF1l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_I6WjSF1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TvIfc1jM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_0HPs7n0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qfws2E2b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_WLwxyyF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xHj3urIu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_d2itPwjM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YvoqoedX_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8jQyR8Nx_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBXwLOpB_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XJMaqqIO_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vz34kBcj_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ln4mBQXp_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_YvoqoedX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TB4bxT69_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8jQyR8Nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nCluTwbj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ZBXwLOpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cxefCH4o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XJMaqqIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pwjTIaNZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_vz34kBcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zQPW1xXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ln4mBQXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K7YJWmVB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_eggSzFzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wxZEmnVa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gFmnjIpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tdLpxKIp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_o9uyqUTF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xifOHXNI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xifOHXNI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hyW5L8Ah, 1, m, &cDelay_hyW5L8Ah_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2o8EKqwa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hyW5L8Ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hyW5L8Ah, m);
  cIf_onMessage(_c, &Context(_c)->cIf_eggSzFzt, 0, m, &cIf_eggSzFzt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xifOHXNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hyW5L8Ah, 0, m, &cDelay_hyW5L8Ah_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2o8EKqwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hyW5L8Ah, 0, m, &cDelay_hyW5L8Ah_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O2eNyuQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MH0Qg4js_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p0jngjpk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vGXp2k0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OkZqwAdu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n6jPhknA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OkZqwAdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eggSzFzt, 1, m, &cIf_eggSzFzt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n6jPhknA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_o9uyqUTF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MH0Qg4js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gFmnjIpF, 1, m, &cIf_gFmnjIpF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p0jngjpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gFmnjIpF, 0, m, &cIf_gFmnjIpF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tdLpxKIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d7JFQIFx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wxZEmnVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d7JFQIFx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_v6Dkx8HX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_C8iyKgoz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IAWhjizE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QswNsxUL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FDEJbKur_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_N9SlkXYv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_N9SlkXYv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vZAz0x7M, 1, m, &cDelay_vZAz0x7M_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XSqGfOpp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vZAz0x7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vZAz0x7M, m);
  cIf_onMessage(_c, &Context(_c)->cIf_v6Dkx8HX, 0, m, &cIf_v6Dkx8HX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N9SlkXYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vZAz0x7M, 0, m, &cDelay_vZAz0x7M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XSqGfOpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vZAz0x7M, 0, m, &cDelay_vZAz0x7M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AsRUmdLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4V5NMPX1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T6MASfip_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9sVYdegP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g2dB6UqP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FRlOuvBZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FRlOuvBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FDEJbKur_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_g2dB6UqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v6Dkx8HX, 1, m, &cIf_v6Dkx8HX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4V5NMPX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IAWhjizE, 1, m, &cIf_IAWhjizE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T6MASfip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IAWhjizE, 0, m, &cIf_IAWhjizE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QswNsxUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YHYI01h1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_C8iyKgoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YHYI01h1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mLwCt70C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EaRaf2Kx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vbMwGUKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_feEZxu5j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5cuOmlmR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UG665PKq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UG665PKq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Js4X4xq3, 1, m, &cDelay_Js4X4xq3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D0kV7Nyz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Js4X4xq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Js4X4xq3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mLwCt70C, 0, m, &cIf_mLwCt70C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UG665PKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Js4X4xq3, 0, m, &cDelay_Js4X4xq3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D0kV7Nyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Js4X4xq3, 0, m, &cDelay_Js4X4xq3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_70PtUcxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_58JRboT9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZLP6d6aV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HLtI7ZiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tj8dHcRr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Eb2S3pL6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Tj8dHcRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mLwCt70C, 1, m, &cIf_mLwCt70C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Eb2S3pL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5cuOmlmR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZLP6d6aV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbMwGUKF, 0, m, &cIf_vbMwGUKF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_58JRboT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbMwGUKF, 1, m, &cIf_vbMwGUKF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_feEZxu5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tQwhKKEA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EaRaf2Kx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tQwhKKEA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NWPwxPzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CeQ8akLu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hPaC37Mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eXkguBC7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wLi2SyS2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lmbH8ImS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lmbH8ImS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kWO6CMo4, 1, m, &cDelay_kWO6CMo4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sBE7g3Pk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kWO6CMo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kWO6CMo4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NWPwxPzm, 0, m, &cIf_NWPwxPzm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lmbH8ImS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kWO6CMo4, 0, m, &cDelay_kWO6CMo4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sBE7g3Pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kWO6CMo4, 0, m, &cDelay_kWO6CMo4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C8b73wNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1Rw1biM0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GQevgPMh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vK3x5F6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h5BVS0FE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mIDqKYOi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h5BVS0FE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NWPwxPzm, 1, m, &cIf_NWPwxPzm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mIDqKYOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wLi2SyS2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1Rw1biM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hPaC37Mp, 1, m, &cIf_hPaC37Mp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GQevgPMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hPaC37Mp, 0, m, &cIf_hPaC37Mp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eXkguBC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZHFNeKcX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CeQ8akLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZHFNeKcX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_1xL1kYSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oblUZTgK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_74CH0Ljv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hD9LXovV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NtolwPJ7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mq00uwvf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mq00uwvf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8LImJnQK, 1, m, &cDelay_8LImJnQK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_65PWa5aQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_8LImJnQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8LImJnQK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1xL1kYSN, 0, m, &cIf_1xL1kYSN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mq00uwvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8LImJnQK, 0, m, &cDelay_8LImJnQK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_65PWa5aQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8LImJnQK, 0, m, &cDelay_8LImJnQK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VgTjUxma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NVVHYuLi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oM9tl5Vj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7jc4AJyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rxbltfQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QE0IO7Lz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rxbltfQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1xL1kYSN, 1, m, &cIf_1xL1kYSN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QE0IO7Lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NtolwPJ7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NVVHYuLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_74CH0Ljv, 1, m, &cIf_74CH0Ljv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oM9tl5Vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_74CH0Ljv, 0, m, &cIf_74CH0Ljv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hD9LXovV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KjHubgBS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oblUZTgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KjHubgBS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_0F90dNht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3AM5uFTG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_npVY4Oqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RWRHurGX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9iQj3Pks_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CZBWOrXn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CZBWOrXn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sOcvxEzV, 1, m, &cDelay_sOcvxEzV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G8Nxgpiz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_sOcvxEzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sOcvxEzV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_0F90dNht, 0, m, &cIf_0F90dNht_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CZBWOrXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sOcvxEzV, 0, m, &cDelay_sOcvxEzV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G8Nxgpiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sOcvxEzV, 0, m, &cDelay_sOcvxEzV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_biBmRyzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GDPLv5We_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yo8Q1XNo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i0RL1oq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A2h9WRNi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jBY7E2P9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jBY7E2P9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9iQj3Pks_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_A2h9WRNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0F90dNht, 1, m, &cIf_0F90dNht_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GDPLv5We_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_npVY4Oqz, 1, m, &cIf_npVY4Oqz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yo8Q1XNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_npVY4Oqz, 0, m, &cIf_npVY4Oqz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RWRHurGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hCRNK5YP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3AM5uFTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hCRNK5YP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_fGIKexGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fOFLmx0k_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ALJProw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mkX5UXWB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MNIE82bY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LWNYDvuM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LWNYDvuM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_C5cZOPEH, 1, m, &cDelay_C5cZOPEH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dvQZ4uMV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_C5cZOPEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C5cZOPEH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fGIKexGu, 0, m, &cIf_fGIKexGu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LWNYDvuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_C5cZOPEH, 0, m, &cDelay_C5cZOPEH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dvQZ4uMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C5cZOPEH, 0, m, &cDelay_C5cZOPEH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n4TGmJXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vd59SRBz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hZVYKNyv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ipmn8F2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fqavkZub_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_arxRyH0d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_arxRyH0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MNIE82bY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fqavkZub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fGIKexGu, 1, m, &cIf_fGIKexGu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hZVYKNyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ALJProw5, 0, m, &cIf_ALJProw5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Vd59SRBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ALJProw5, 1, m, &cIf_ALJProw5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mkX5UXWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oEzxKcks, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fOFLmx0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oEzxKcks, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_sfjpHQRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JPBTHqO7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xccO4mrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oxuWnNkj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Ply6nzOY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nLkWxOYQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nLkWxOYQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2z9mC6Mz, 1, m, &cDelay_2z9mC6Mz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oP0r8XdA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2z9mC6Mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2z9mC6Mz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sfjpHQRF, 0, m, &cIf_sfjpHQRF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nLkWxOYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2z9mC6Mz, 0, m, &cDelay_2z9mC6Mz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oP0r8XdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2z9mC6Mz, 0, m, &cDelay_2z9mC6Mz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5hHhE2P8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QXMN95p6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K3wGaqmH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XSnAzkfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4EPWZCCl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OVFf1bFS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OVFf1bFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ply6nzOY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4EPWZCCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sfjpHQRF, 1, m, &cIf_sfjpHQRF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K3wGaqmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xccO4mrR, 0, m, &cIf_xccO4mrR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QXMN95p6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xccO4mrR, 1, m, &cIf_xccO4mrR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oxuWnNkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tosSCqTX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JPBTHqO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tosSCqTX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tndYhfsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NiERT3ET_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YIlwxxuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SQez5WYd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PiX8pP4R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RRbZsvHz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RRbZsvHz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zeU7jZJq, 1, m, &cDelay_zeU7jZJq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_57t8q1GV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zeU7jZJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zeU7jZJq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tndYhfsl, 0, m, &cIf_tndYhfsl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RRbZsvHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zeU7jZJq, 0, m, &cDelay_zeU7jZJq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_57t8q1GV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zeU7jZJq, 0, m, &cDelay_zeU7jZJq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YK5k8ZMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_atZaJS7p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dub7gw20_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1UsQVEHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t1TqE5Hj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bUM6h07q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bUM6h07q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PiX8pP4R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_t1TqE5Hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tndYhfsl, 1, m, &cIf_tndYhfsl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Dub7gw20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YIlwxxuN, 0, m, &cIf_YIlwxxuN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_atZaJS7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YIlwxxuN, 1, m, &cIf_YIlwxxuN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SQez5WYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fxAcAYg5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NiERT3ET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fxAcAYg5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Djv8ptfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wakPapsJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RkfA5eeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PvNyv2Us_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dYQbod8T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Tcny2BNg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Tcny2BNg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UAU5218J, 1, m, &cDelay_UAU5218J_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rYy6RcGR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UAU5218J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UAU5218J, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Djv8ptfc, 0, m, &cIf_Djv8ptfc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Tcny2BNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UAU5218J, 0, m, &cDelay_UAU5218J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rYy6RcGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UAU5218J, 0, m, &cDelay_UAU5218J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e5Drf546_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7NAlJCEw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bJXmhkUx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jPXyIb9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ekGjtTel_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cNYoJZvZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cNYoJZvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dYQbod8T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ekGjtTel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Djv8ptfc, 1, m, &cIf_Djv8ptfc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7NAlJCEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RkfA5eeQ, 1, m, &cIf_RkfA5eeQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bJXmhkUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RkfA5eeQ, 0, m, &cIf_RkfA5eeQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PvNyv2Us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KNpeySki, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wakPapsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KNpeySki, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_E3i1gpjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NBMmNVRv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wxvmEQrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ojnL1LzQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kmzAD2fT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7643alYY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7643alYY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ux2ecb2b, 1, m, &cDelay_Ux2ecb2b_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BSqeaUUC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Ux2ecb2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ux2ecb2b, m);
  cIf_onMessage(_c, &Context(_c)->cIf_E3i1gpjg, 0, m, &cIf_E3i1gpjg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7643alYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ux2ecb2b, 0, m, &cDelay_Ux2ecb2b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BSqeaUUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ux2ecb2b, 0, m, &cDelay_Ux2ecb2b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Cp2xJYKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jxckpmYG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6dA0McCP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RToojtSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xk1GayXr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EtU6hElz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EtU6hElz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kmzAD2fT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Xk1GayXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E3i1gpjg, 1, m, &cIf_E3i1gpjg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6dA0McCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wxvmEQrE, 0, m, &cIf_wxvmEQrE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jxckpmYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wxvmEQrE, 1, m, &cIf_wxvmEQrE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ojnL1LzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vbiacoxw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NBMmNVRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vbiacoxw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5f85Zpi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_V4ssqBzF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rUmjFHZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_180ONUOB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Q89zUeip_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kDxGvddi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kDxGvddi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VT2ypioo, 1, m, &cDelay_VT2ypioo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Oq8E0U5r_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_VT2ypioo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VT2ypioo, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5f85Zpi3, 0, m, &cIf_5f85Zpi3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kDxGvddi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VT2ypioo, 0, m, &cDelay_VT2ypioo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Oq8E0U5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VT2ypioo, 0, m, &cDelay_VT2ypioo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_10z8UCia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bophyn0J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3jGDTq9o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tQsCZ1lH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uTrK6Xl4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wDrv1Z2X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wDrv1Z2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Q89zUeip_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uTrK6Xl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5f85Zpi3, 1, m, &cIf_5f85Zpi3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3jGDTq9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rUmjFHZl, 0, m, &cIf_rUmjFHZl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bophyn0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rUmjFHZl, 1, m, &cIf_rUmjFHZl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_180ONUOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rV4RUViF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_V4ssqBzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rV4RUViF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TB4bxT69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_oQHMUdEG_sendMessage(_c, 0, m);
  cMsg_x2rOCoYT_sendMessage(_c, 0, m);
  cMsg_ajrDj1Px_sendMessage(_c, 0, m);
  cMsg_2StU16IY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nCluTwbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_oQHMUdEG_sendMessage(_c, 0, m);
  cMsg_6DN8dx4c_sendMessage(_c, 0, m);
  cMsg_VOVXD6Qd_sendMessage(_c, 0, m);
  cMsg_nG3rSWD7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cxefCH4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_ZzjVKSKB_sendMessage(_c, 0, m);
  cMsg_6DN8dx4c_sendMessage(_c, 0, m);
  cMsg_2StU16IY_sendMessage(_c, 0, m);
  cMsg_d1kkPtYV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pwjTIaNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_ZzjVKSKB_sendMessage(_c, 0, m);
  cMsg_fMiyvg17_sendMessage(_c, 0, m);
  cMsg_ajrDj1Px_sendMessage(_c, 0, m);
  cMsg_82Dc0jaI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zQPW1xXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_ZhQvXBjj_sendMessage(_c, 0, m);
  cMsg_nG3rSWD7_sendMessage(_c, 0, m);
  cMsg_cLl0YV9i_sendMessage(_c, 0, m);
  cMsg_ajrDj1Px_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_K7YJWmVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_ZhQvXBjj_sendMessage(_c, 0, m);
  cMsg_82Dc0jaI_sendMessage(_c, 0, m);
  cMsg_6DN8dx4c_sendMessage(_c, 0, m);
  cMsg_Xxz2QOFd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GvyGfI7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vGXp2k0Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O2eNyuQO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wntc1aDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vGXp2k0Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O2eNyuQO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hLRabygZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9sVYdegP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AsRUmdLa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Fk2eucxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9sVYdegP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AsRUmdLa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dDm91xJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HLtI7ZiH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_70PtUcxQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VqJPEpnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HLtI7ZiH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_70PtUcxQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oQHMUdEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_GvyGfI7x_sendMessage(_c, 0, m);
  cMsg_Fk2eucxT_sendMessage(_c, 0, m);
  cMsg_VqJPEpnz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZzjVKSKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_wntc1aDL_sendMessage(_c, 0, m);
  cMsg_hLRabygZ_sendMessage(_c, 0, m);
  cMsg_VqJPEpnz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZhQvXBjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_wntc1aDL_sendMessage(_c, 0, m);
  cMsg_Fk2eucxT_sendMessage(_c, 0, m);
  cMsg_dDm91xJN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tlHCnVyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vK3x5F6Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C8b73wNB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ezyUNabP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vK3x5F6Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C8b73wNB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_85izRQE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7jc4AJyy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VgTjUxma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cnxnFoKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7jc4AJyy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VgTjUxma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_f6PWfAjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i0RL1oq0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_biBmRyzI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nhF7KliT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i0RL1oq0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_biBmRyzI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6DN8dx4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_ezyUNabP_sendMessage(_c, 0, m);
  cMsg_cnxnFoKy_sendMessage(_c, 0, m);
  cMsg_nhF7KliT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_x2rOCoYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_ezyUNabP_sendMessage(_c, 0, m);
  cMsg_85izRQE9_sendMessage(_c, 0, m);
  cMsg_f6PWfAjA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fMiyvg17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_tlHCnVyw_sendMessage(_c, 0, m);
  cMsg_cnxnFoKy_sendMessage(_c, 0, m);
  cMsg_f6PWfAjA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_E8HnOWiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jPXyIb9Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_e5Drf546_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LGDLA8J8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jPXyIb9Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_e5Drf546_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iI7wicm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RToojtSv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Cp2xJYKh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_31Oi3yHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RToojtSv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Cp2xJYKh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_24zeBsyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tQsCZ1lH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_10z8UCia_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p1ltJ7g5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tQsCZ1lH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_10z8UCia_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_82Dc0jaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_E8HnOWiT_sendMessage(_c, 0, m);
  cMsg_31Oi3yHX_sendMessage(_c, 0, m);
  cMsg_p1ltJ7g5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nG3rSWD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_LGDLA8J8_sendMessage(_c, 0, m);
  cMsg_iI7wicm6_sendMessage(_c, 0, m);
  cMsg_p1ltJ7g5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2StU16IY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_LGDLA8J8_sendMessage(_c, 0, m);
  cMsg_31Oi3yHX_sendMessage(_c, 0, m);
  cMsg_24zeBsyH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dIRkY3vE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ipmn8F2L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_n4TGmJXI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hbR2T8VR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ipmn8F2L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_n4TGmJXI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b7pOHsyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XSnAzkfM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5hHhE2P8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5qjgo7lV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XSnAzkfM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5hHhE2P8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_15FNv5Z4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1UsQVEHj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YK5k8ZMx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fNslc3lg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1UsQVEHj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YK5k8ZMx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ajrDj1Px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_hbR2T8VR_sendMessage(_c, 0, m);
  cMsg_5qjgo7lV_sendMessage(_c, 0, m);
  cMsg_fNslc3lg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VOVXD6Qd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_hbR2T8VR_sendMessage(_c, 0, m);
  cMsg_b7pOHsyt_sendMessage(_c, 0, m);
  cMsg_15FNv5Z4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Xxz2QOFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_dIRkY3vE_sendMessage(_c, 0, m);
  cMsg_b7pOHsyt_sendMessage(_c, 0, m);
  cMsg_fNslc3lg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cLl0YV9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_tlHCnVyw_sendMessage(_c, 0, m);
  cMsg_85izRQE9_sendMessage(_c, 0, m);
  cMsg_nhF7KliT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_d1kkPtYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_dIRkY3vE_sendMessage(_c, 0, m);
  cMsg_5qjgo7lV_sendMessage(_c, 0, m);
  cMsg_15FNv5Z4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_avpRM5Vt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_43hl3bp4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tumdDcOr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9EZytB0y, 0, m, &cSlice_9EZytB0y_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YfXySWRT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9EZytB0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_t9Y2ddws_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_t9Y2ddws_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_IeU4aKDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t9Y2ddws_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_t9Y2ddws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AWjjOHCs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_q5njJST0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BevxgnMZ, 0, m, &cSlice_BevxgnMZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_z90kepTi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_BevxgnMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BwnWz6pl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BwnWz6pl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TC7GY2No_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BwnWz6pl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_BwnWz6pl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3JI383kK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_z90kepTi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Pw10QKrf, 0, m, &cSlice_Pw10QKrf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tumdDcOr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Pw10QKrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_T3G1rNTX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_T3G1rNTX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_YtJXFepk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_T3G1rNTX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_T3G1rNTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4LGlDM8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YfXySWRT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bnukTEZ1, 0, m, &cSlice_bnukTEZ1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3Vr0ttOV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bnukTEZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_D6QbKqNK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_D6QbKqNK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Yzx6fMDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_D6QbKqNK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_D6QbKqNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YR9XrXym_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3Vr0ttOV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xEXd3Xej, 0, m, &cSlice_xEXd3Xej_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bi8WMj8g_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_xEXd3Xej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PTRncdIT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PTRncdIT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_MzTReQOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PTRncdIT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_PTRncdIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BBhEccgB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kt34zxMN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eQmeAYif_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eQmeAYif_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RYydmjCB, 1, m, &cDelay_RYydmjCB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XlWIBHeg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RYydmjCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RYydmjCB, m);
  cMsg_BVg9qTeB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eQmeAYif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RYydmjCB, 0, m, &cDelay_RYydmjCB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XlWIBHeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RYydmjCB, 0, m, &cDelay_RYydmjCB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_sRIJ9n69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Vg1s1yo, HV_BINOP_SUBTRACT, 0, m, &cBinop_5Vg1s1yo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_vS3Ij8CC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CGcc5ocy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Oi4x9DGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CGcc5ocy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_kUbljVQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sRIJ9n69, 0, m, &cVar_sRIJ9n69_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_Wk53PUtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xo8mdQ44_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D1CX50qj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MsMkW7ag_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5Vg1s1yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5SrLYOFL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5SrLYOFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nkPEoD63_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nkPEoD63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_qHRxLGmZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sNmOOkzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R6EB1eRf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ppd9SKzr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R6EB1eRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vS3Ij8CC, 1, m, &cIf_vS3Ij8CC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ppd9SKzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a4nKLNIq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_GBk1hbkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Oi4x9DGK, 1, m, &cIf_Oi4x9DGK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a4nKLNIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_vS3Ij8CC, 0, m, &cIf_vS3Ij8CC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qHRxLGmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Oi4x9DGK, 0, m, &cIf_Oi4x9DGK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xo8mdQ44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_MsMkW7ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sRIJ9n69, 0, m, &cVar_sRIJ9n69_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D1CX50qj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Vg1s1yo, HV_BINOP_SUBTRACT, 1, m, &cBinop_5Vg1s1yo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CGcc5ocy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rDddlpag, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bi8WMj8g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ri0pOpE4, 0, m, &cSlice_Ri0pOpE4_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Ri0pOpE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pVvu5UWk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pVvu5UWk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ofd3WStB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pVvu5UWk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_pVvu5UWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qK823ny8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qfws2E2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_coiPZw5I, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xHj3urIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tM0NIeRp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_VDCzT33Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WLwxyyF5, 0, m, &cVar_WLwxyyF5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_43hl3bp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X3pJt634, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uDdImY07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eVvepTBa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_hGNrvunY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kt34zxMN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BVg9qTeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DQgYIF0Y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eVvepTBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DQgYIF0Y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cpqdwVNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_WTJOhlZS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WTJOhlZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xw6UFc4f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xw6UFc4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bPloqjb8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_Ks0bMys5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qoa0fXUb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_rNGgIymJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hacsmLqa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_lIDqKwSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A6hoUG4Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_qk0iGwb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kevbV2HS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_mJAlRwOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zNFD9ekq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_4W41IuiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JnfxzPfU_sendMessage);
  cMsg_mztHcUFI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_JnfxzPfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4W41IuiM, 1, m, &cVar_4W41IuiM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wbLzouNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rOpL5I65_sendMessage(_c, 0, m);
  cMsg_1jB7cN3n_sendMessage(_c, 0, m);
  cMsg_y1sweHSZ_sendMessage(_c, 0, m);
  cMsg_cJzGaTiB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_f2H5NLkP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BWs1tudI, 0, m, &cSlice_BWs1tudI_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_BWs1tudI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WwhP1q34_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WwhP1q34_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_VDrhDdzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WwhP1q34_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_WwhP1q34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hrKO8YpD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_J80qcm4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_quRabMbv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_quRabMbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_VYlVbZbP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VYlVbZbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_sZEr1XBc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sZEr1XBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kt9SuFXR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pj6Nn83T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kt9SuFXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lzZ3lig1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Pj6Nn83T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JSHBZhuq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lzZ3lig1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FiZn6PnY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JSHBZhuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ntcinWgQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ntcinWgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VRTHOmHV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FiZn6PnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kRk1M5Oq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_VRTHOmHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fnJj4atP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kRk1M5Oq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_olzyQLYv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fnJj4atP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HaC6D8AP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_RN1AOJk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0vddgkJ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_1Ak6Ct8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K3fRByUF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HebY0xcj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_arVVeJco_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Ee76ds9_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3OdkycjJ_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UaXV75El_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MRdX4FQP_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QRmF9Wvo_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_arVVeJco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gDFe101V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_2Ee76ds9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mWBf1Vw2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_3OdkycjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sZWnID4s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_UaXV75El_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rsSuzZWw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_MRdX4FQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wkzmWFRZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_QRmF9Wvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l6XKmtCh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_8PARhZfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gJoObRDT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CWLWCGot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OhybSJxB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Ues0hBeH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_iyVmKun2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_iyVmKun2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9K3LX7IB, 1, m, &cDelay_9K3LX7IB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PSjZ1fp6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9K3LX7IB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9K3LX7IB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8PARhZfg, 0, m, &cIf_8PARhZfg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iyVmKun2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9K3LX7IB, 0, m, &cDelay_9K3LX7IB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PSjZ1fp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9K3LX7IB, 0, m, &cDelay_9K3LX7IB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bS388qPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_efEgdoGS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8qOO1C7X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M7cePdcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l4QmpuGq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MlpfzORZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l4QmpuGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8PARhZfg, 1, m, &cIf_8PARhZfg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MlpfzORZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ues0hBeH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_efEgdoGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CWLWCGot, 1, m, &cIf_CWLWCGot_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8qOO1C7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CWLWCGot, 0, m, &cIf_CWLWCGot_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OhybSJxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S6IyEB8g, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gJoObRDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S6IyEB8g, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_FQXQqtO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mPAF3COJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RHESocK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_z4Y3PSzW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XxdIszEr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fNImNyyU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fNImNyyU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Bve9FkVh, 1, m, &cDelay_Bve9FkVh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9BUDqLse_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Bve9FkVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Bve9FkVh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_FQXQqtO7, 0, m, &cIf_FQXQqtO7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fNImNyyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bve9FkVh, 0, m, &cDelay_Bve9FkVh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9BUDqLse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bve9FkVh, 0, m, &cDelay_Bve9FkVh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EmuoPucy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KmT4TYrH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jwyJTTKj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3H7vV8N2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vwxrcTz4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d0iQNfKX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vwxrcTz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FQXQqtO7, 1, m, &cIf_FQXQqtO7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d0iQNfKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XxdIszEr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_KmT4TYrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RHESocK4, 1, m, &cIf_RHESocK4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jwyJTTKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RHESocK4, 0, m, &cIf_RHESocK4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z4Y3PSzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uloH3YLr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mPAF3COJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uloH3YLr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_f2k6rPbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_T6tErHEr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jRwDXfzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TocqFADS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uZLuPkz1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OzVrIVJ4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OzVrIVJ4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RtCaaW6r, 1, m, &cDelay_RtCaaW6r_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Smuuulnu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RtCaaW6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RtCaaW6r, m);
  cIf_onMessage(_c, &Context(_c)->cIf_f2k6rPbg, 0, m, &cIf_f2k6rPbg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OzVrIVJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RtCaaW6r, 0, m, &cDelay_RtCaaW6r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Smuuulnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RtCaaW6r, 0, m, &cDelay_RtCaaW6r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xJVyhb8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2sF8Dlmn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xcvAHVCD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pcL0c6LC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lKMZYx6k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_deyndoBU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_deyndoBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uZLuPkz1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lKMZYx6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f2k6rPbg, 1, m, &cIf_f2k6rPbg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2sF8Dlmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jRwDXfzD, 1, m, &cIf_jRwDXfzD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xcvAHVCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jRwDXfzD, 0, m, &cIf_jRwDXfzD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TocqFADS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T79EBREr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_T6tErHEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T79EBREr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_O9njpAlv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_51UmqB2K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_q1WLixiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_62YoUfcS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zeWLwIf2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1Fuk8BRb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1Fuk8BRb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_alNcPjuf, 1, m, &cDelay_alNcPjuf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jHz5Agvs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_alNcPjuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_alNcPjuf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_O9njpAlv, 0, m, &cIf_O9njpAlv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1Fuk8BRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_alNcPjuf, 0, m, &cDelay_alNcPjuf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jHz5Agvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_alNcPjuf, 0, m, &cDelay_alNcPjuf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WuRb73O8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AUS4VDIP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_td4K6Hmr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lx7QS7Nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ccPeW8La_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gqzaGkIU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gqzaGkIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zeWLwIf2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ccPeW8La_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O9njpAlv, 1, m, &cIf_O9njpAlv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_td4K6Hmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q1WLixiy, 0, m, &cIf_q1WLixiy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AUS4VDIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q1WLixiy, 1, m, &cIf_q1WLixiy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_62YoUfcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3tmWlXfz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_51UmqB2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3tmWlXfz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_zq3MsY6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_B4X5xIik_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bGqUJuMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fDJGxhIx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DPxTsMjb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZQLHlNK8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZQLHlNK8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NYTbRTrx, 1, m, &cDelay_NYTbRTrx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wBfn4GKZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_NYTbRTrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NYTbRTrx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zq3MsY6W, 0, m, &cIf_zq3MsY6W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZQLHlNK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NYTbRTrx, 0, m, &cDelay_NYTbRTrx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wBfn4GKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NYTbRTrx, 0, m, &cDelay_NYTbRTrx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1KULrAmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fuhCjMac_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zGIGM0kc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sRdjwjPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xRLuERXV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mlNfE0Xy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xRLuERXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zq3MsY6W, 1, m, &cIf_zq3MsY6W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mlNfE0Xy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DPxTsMjb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fuhCjMac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bGqUJuMn, 1, m, &cIf_bGqUJuMn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zGIGM0kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bGqUJuMn, 0, m, &cIf_bGqUJuMn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fDJGxhIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_csCVGhTD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_B4X5xIik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_csCVGhTD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8Ht0wuWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9KsY9LHI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_VP8d3Rvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_R8LIjhfs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IlNNTtT6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YOc1ITqT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YOc1ITqT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6rLsjQDP, 1, m, &cDelay_6rLsjQDP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QSi5Qu1g_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6rLsjQDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6rLsjQDP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8Ht0wuWw, 0, m, &cIf_8Ht0wuWw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YOc1ITqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6rLsjQDP, 0, m, &cDelay_6rLsjQDP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QSi5Qu1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6rLsjQDP, 0, m, &cDelay_6rLsjQDP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GFmta1Un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kowoZF33_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3EY6CXDL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jlEGfBB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WJwJM9bi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UMAKM6jq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WJwJM9bi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8Ht0wuWw, 1, m, &cIf_8Ht0wuWw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UMAKM6jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IlNNTtT6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kowoZF33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VP8d3Rvq, 1, m, &cIf_VP8d3Rvq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3EY6CXDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VP8d3Rvq, 0, m, &cIf_VP8d3Rvq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R8LIjhfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n6GdnktL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9KsY9LHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n6GdnktL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_UISHmHgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2j9luscM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CasJI4c5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2Mg3YTZW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EC8Kb2Ul_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_JMtayfMl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_JMtayfMl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_s5dOQDlj, 1, m, &cDelay_s5dOQDlj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pYZkdgdn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_s5dOQDlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_s5dOQDlj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UISHmHgS, 0, m, &cIf_UISHmHgS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JMtayfMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_s5dOQDlj, 0, m, &cDelay_s5dOQDlj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pYZkdgdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_s5dOQDlj, 0, m, &cDelay_s5dOQDlj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZW5ENtWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1BHrvqyt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DxHg0lcH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LVnu4RzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MhBzAKE7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_agBwtHIF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_agBwtHIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EC8Kb2Ul_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MhBzAKE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UISHmHgS, 1, m, &cIf_UISHmHgS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1BHrvqyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CasJI4c5, 1, m, &cIf_CasJI4c5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DxHg0lcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CasJI4c5, 0, m, &cIf_CasJI4c5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2Mg3YTZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KYkcATVf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2j9luscM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KYkcATVf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_HcFKwAUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bIHO0zut_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_h3GmSm5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4cslTCtE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e0tQL3FU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Wi4Zcp7F_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Wi4Zcp7F_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4hZwyo70, 1, m, &cDelay_4hZwyo70_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7Ri7MoUD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4hZwyo70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4hZwyo70, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HcFKwAUe, 0, m, &cIf_HcFKwAUe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wi4Zcp7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4hZwyo70, 0, m, &cDelay_4hZwyo70_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7Ri7MoUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4hZwyo70, 0, m, &cDelay_4hZwyo70_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QgiZUZ8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yPs49Sjr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9VglduCl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1y91eHNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0m97mauM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BrECC6e6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BrECC6e6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_e0tQL3FU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0m97mauM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HcFKwAUe, 1, m, &cIf_HcFKwAUe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9VglduCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h3GmSm5U, 0, m, &cIf_h3GmSm5U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yPs49Sjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h3GmSm5U, 1, m, &cIf_h3GmSm5U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4cslTCtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wuvpmkn3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bIHO0zut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wuvpmkn3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ais36E1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QrDnKi0U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KwVBhTdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ATs41Anc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XcJtTWNi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BX9v7gH0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BX9v7gH0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_p3yg9CUR, 1, m, &cDelay_p3yg9CUR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hqa6Dl1p_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_p3yg9CUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p3yg9CUR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ais36E1z, 0, m, &cIf_Ais36E1z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BX9v7gH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_p3yg9CUR, 0, m, &cDelay_p3yg9CUR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hqa6Dl1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p3yg9CUR, 0, m, &cDelay_p3yg9CUR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wOi7tlDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZmFx25nC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EUMfDAgH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yFYEfgQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bYBzSfVk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kMpMXxtB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kMpMXxtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XcJtTWNi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_bYBzSfVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ais36E1z, 1, m, &cIf_Ais36E1z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EUMfDAgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KwVBhTdM, 0, m, &cIf_KwVBhTdM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZmFx25nC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KwVBhTdM, 1, m, &cIf_KwVBhTdM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ATs41Anc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kfodzCu2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QrDnKi0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kfodzCu2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_wsyOQihT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VCxKmRH3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hYoWfZvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rngLI9KT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HLS1ILC3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LMAh41zZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LMAh41zZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_srSARrj8, 1, m, &cDelay_srSARrj8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5m9CpUVV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_srSARrj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_srSARrj8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wsyOQihT, 0, m, &cIf_wsyOQihT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LMAh41zZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_srSARrj8, 0, m, &cDelay_srSARrj8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5m9CpUVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_srSARrj8, 0, m, &cDelay_srSARrj8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i0ANOOiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JJdYYSzt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zWdXyDfk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Qz4YXGy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P1xqtdF4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iugMiheG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iugMiheG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HLS1ILC3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_P1xqtdF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wsyOQihT, 1, m, &cIf_wsyOQihT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zWdXyDfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hYoWfZvq, 0, m, &cIf_hYoWfZvq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JJdYYSzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hYoWfZvq, 1, m, &cIf_hYoWfZvq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rngLI9KT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LUR29rXc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VCxKmRH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LUR29rXc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lFPJrNN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4M0gn995_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zkzfz5XE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9VYzBxEE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WFTDqwg2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ED8kZJEp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ED8kZJEp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hue7kVS0, 1, m, &cDelay_hue7kVS0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3c70p5Xe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hue7kVS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hue7kVS0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lFPJrNN8, 0, m, &cIf_lFPJrNN8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ED8kZJEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hue7kVS0, 0, m, &cDelay_hue7kVS0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3c70p5Xe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hue7kVS0, 0, m, &cDelay_hue7kVS0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RgOjgM1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g2T8jzBt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YrHjoN4M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6j0FFlAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FFOn6hk0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ovhZ3XJz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ovhZ3XJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WFTDqwg2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FFOn6hk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lFPJrNN8, 1, m, &cIf_lFPJrNN8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YrHjoN4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zkzfz5XE, 0, m, &cIf_zkzfz5XE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_g2T8jzBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zkzfz5XE, 1, m, &cIf_zkzfz5XE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9VYzBxEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qXjn4T0b, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4M0gn995_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qXjn4T0b, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7EJ1Jcb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8PfcPIsG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_luV6DaNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ahLAxqym_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_35PG8hmx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LLelI9W1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LLelI9W1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uvrSLIIy, 1, m, &cDelay_uvrSLIIy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7fQJbfaK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uvrSLIIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uvrSLIIy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7EJ1Jcb5, 0, m, &cIf_7EJ1Jcb5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LLelI9W1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uvrSLIIy, 0, m, &cDelay_uvrSLIIy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7fQJbfaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uvrSLIIy, 0, m, &cDelay_uvrSLIIy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YmNqMKqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pg78KUgn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PkU6DeyM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IMnxj4qd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r91FHoV5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xz60IflI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xz60IflI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_35PG8hmx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_r91FHoV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7EJ1Jcb5, 1, m, &cIf_7EJ1Jcb5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PkU6DeyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_luV6DaNB, 0, m, &cIf_luV6DaNB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pg78KUgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_luV6DaNB, 1, m, &cIf_luV6DaNB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ahLAxqym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vlyJjXFD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8PfcPIsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vlyJjXFD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gDFe101V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_gc5mHHOW_sendMessage(_c, 0, m);
  cMsg_UwGjjIjc_sendMessage(_c, 0, m);
  cMsg_W2Jop2DM_sendMessage(_c, 0, m);
  cMsg_4J0zrGYa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mWBf1Vw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_gc5mHHOW_sendMessage(_c, 0, m);
  cMsg_sfxLZvkI_sendMessage(_c, 0, m);
  cMsg_M3mSQ2nv_sendMessage(_c, 0, m);
  cMsg_90xqwIla_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sZWnID4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_99lqSpru_sendMessage(_c, 0, m);
  cMsg_sfxLZvkI_sendMessage(_c, 0, m);
  cMsg_4J0zrGYa_sendMessage(_c, 0, m);
  cMsg_SY0agr9n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rsSuzZWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_99lqSpru_sendMessage(_c, 0, m);
  cMsg_zfVyJAgV_sendMessage(_c, 0, m);
  cMsg_W2Jop2DM_sendMessage(_c, 0, m);
  cMsg_qinMmAYM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wkzmWFRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_H74fjXfh_sendMessage(_c, 0, m);
  cMsg_90xqwIla_sendMessage(_c, 0, m);
  cMsg_EgerKoyO_sendMessage(_c, 0, m);
  cMsg_W2Jop2DM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_l6XKmtCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_H74fjXfh_sendMessage(_c, 0, m);
  cMsg_qinMmAYM_sendMessage(_c, 0, m);
  cMsg_sfxLZvkI_sendMessage(_c, 0, m);
  cMsg_gPcwmprd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_X3ApuTVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_M7cePdcu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bS388qPc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XnXP0YxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_M7cePdcu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bS388qPc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gbXHqJEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3H7vV8N2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EmuoPucy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C7cnM83H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3H7vV8N2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EmuoPucy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mCkBrzSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pcL0c6LC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xJVyhb8o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DoN1TdBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pcL0c6LC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xJVyhb8o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gc5mHHOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_X3ApuTVS_sendMessage(_c, 0, m);
  cMsg_C7cnM83H_sendMessage(_c, 0, m);
  cMsg_DoN1TdBw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_99lqSpru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_XnXP0YxP_sendMessage(_c, 0, m);
  cMsg_gbXHqJEZ_sendMessage(_c, 0, m);
  cMsg_DoN1TdBw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_H74fjXfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_XnXP0YxP_sendMessage(_c, 0, m);
  cMsg_C7cnM83H_sendMessage(_c, 0, m);
  cMsg_mCkBrzSs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tRPLd0Xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lx7QS7Nr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WuRb73O8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WYARQhNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lx7QS7Nr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WuRb73O8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E0XBhpyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sRdjwjPU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1KULrAmg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OVmPPjAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sRdjwjPU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1KULrAmg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ji5of2hq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jlEGfBB5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GFmta1Un_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mpHVvfIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jlEGfBB5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GFmta1Un_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sfxLZvkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_WYARQhNj_sendMessage(_c, 0, m);
  cMsg_OVmPPjAt_sendMessage(_c, 0, m);
  cMsg_mpHVvfIN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UwGjjIjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_WYARQhNj_sendMessage(_c, 0, m);
  cMsg_E0XBhpyF_sendMessage(_c, 0, m);
  cMsg_ji5of2hq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zfVyJAgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_tRPLd0Xl_sendMessage(_c, 0, m);
  cMsg_OVmPPjAt_sendMessage(_c, 0, m);
  cMsg_ji5of2hq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9YM7f61Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Qz4YXGy3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_i0ANOOiV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ntttwH37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Qz4YXGy3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_i0ANOOiV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jgwyUvLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6j0FFlAd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RgOjgM1f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w3cHoAhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6j0FFlAd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RgOjgM1f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uYCFmaAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IMnxj4qd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YmNqMKqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_G7CviwIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IMnxj4qd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YmNqMKqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qinMmAYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_9YM7f61Z_sendMessage(_c, 0, m);
  cMsg_w3cHoAhY_sendMessage(_c, 0, m);
  cMsg_G7CviwIR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_90xqwIla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_ntttwH37_sendMessage(_c, 0, m);
  cMsg_jgwyUvLu_sendMessage(_c, 0, m);
  cMsg_G7CviwIR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4J0zrGYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_ntttwH37_sendMessage(_c, 0, m);
  cMsg_w3cHoAhY_sendMessage(_c, 0, m);
  cMsg_uYCFmaAP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mV0dAChx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LVnu4RzR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZW5ENtWZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_v7JY3ilc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LVnu4RzR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZW5ENtWZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_knuSZswa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1y91eHNw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QgiZUZ8X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jYd8iym9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1y91eHNw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QgiZUZ8X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AY3Xy812_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yFYEfgQX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wOi7tlDT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JyY5zshh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yFYEfgQX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wOi7tlDT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W2Jop2DM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_v7JY3ilc_sendMessage(_c, 0, m);
  cMsg_jYd8iym9_sendMessage(_c, 0, m);
  cMsg_JyY5zshh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_M3mSQ2nv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_v7JY3ilc_sendMessage(_c, 0, m);
  cMsg_knuSZswa_sendMessage(_c, 0, m);
  cMsg_AY3Xy812_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gPcwmprd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_mV0dAChx_sendMessage(_c, 0, m);
  cMsg_knuSZswa_sendMessage(_c, 0, m);
  cMsg_JyY5zshh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EgerKoyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_tRPLd0Xl_sendMessage(_c, 0, m);
  cMsg_E0XBhpyF_sendMessage(_c, 0, m);
  cMsg_mpHVvfIN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SY0agr9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_mV0dAChx_sendMessage(_c, 0, m);
  cMsg_jYd8iym9_sendMessage(_c, 0, m);
  cMsg_AY3Xy812_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_adlfWpm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UiExcOyR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zV3iVYbJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3VGD6U4J, 0, m, &cSlice_3VGD6U4J_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zjvPbDy5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_3VGD6U4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oJODcShC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oJODcShC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_52QPa1GD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oJODcShC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_oJODcShC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZqW4VYu8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OomEJobD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_x8lvXa0f, 0, m, &cSlice_x8lvXa0f_sendMessage);
      break;
    }
    default: {
      cSwitchcase_63VrUZof_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_x8lvXa0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_apo5POqp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_apo5POqp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_sUhhHzfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_apo5POqp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_apo5POqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WQFva1jt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_63VrUZof_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FNqgRRii, 0, m, &cSlice_FNqgRRii_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zV3iVYbJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_FNqgRRii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Y2clLBoD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Y2clLBoD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3UJBlSrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Y2clLBoD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Y2clLBoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mLvQZyXz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zjvPbDy5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0BO4c30i, 0, m, &cSlice_0BO4c30i_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kJyP0v2T_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0BO4c30i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tTMTOiqQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tTMTOiqQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_XCh9bzr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tTMTOiqQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_tTMTOiqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_puzMgJQs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kJyP0v2T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AS1kZf2r, 0, m, &cSlice_AS1kZf2r_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZYb3dxRZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_AS1kZf2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jISzHVEh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jISzHVEh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_XXVo7NES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jISzHVEh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jISzHVEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5xupRvvA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mxtuVLFH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3O29Ts6H_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3O29Ts6H_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KqPWIewa, 1, m, &cDelay_KqPWIewa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BoRkoGnO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KqPWIewa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KqPWIewa, m);
  cMsg_nopEib2M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3O29Ts6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KqPWIewa, 0, m, &cDelay_KqPWIewa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BoRkoGnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KqPWIewa, 0, m, &cDelay_KqPWIewa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_nN3FqDLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j4U9ywzT, HV_BINOP_SUBTRACT, 0, m, &cBinop_j4U9ywzT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_iTug8sI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ywOqie54_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lQ7Vq929_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ywOqie54_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_a1NYBl4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nN3FqDLq, 0, m, &cVar_nN3FqDLq_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_ZTQubMs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZqzD4gQU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7ZtHtGm2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dt8C2GrE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j4U9ywzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6P83y9ix_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6P83y9ix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mC0B8B7z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mC0B8B7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_NJVHOtyS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YSGqDXO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bdiPYcxh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i4OvjqCN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i4OvjqCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rM17RijX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_bdiPYcxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iTug8sI6, 1, m, &cIf_iTug8sI6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fKVEI54M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lQ7Vq929, 1, m, &cIf_lQ7Vq929_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rM17RijX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_iTug8sI6, 0, m, &cIf_iTug8sI6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NJVHOtyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lQ7Vq929, 0, m, &cIf_lQ7Vq929_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7ZtHtGm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j4U9ywzT, HV_BINOP_SUBTRACT, 1, m, &cBinop_j4U9ywzT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZqzD4gQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_Dt8C2GrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nN3FqDLq, 0, m, &cVar_nN3FqDLq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ywOqie54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vu8sEma4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZYb3dxRZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gEsQZv7z, 0, m, &cSlice_gEsQZv7z_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gEsQZv7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FYFpu7zr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FYFpu7zr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Vd1zShIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FYFpu7zr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FYFpu7zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qAtnrP1j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0vddgkJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r3JdKsTu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_K3fRByUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6vX9VjVc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_YDgtCnHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1Ak6Ct8m, 0, m, &cVar_1Ak6Ct8m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UiExcOyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IVoesz6O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_tl6LxPBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mxtuVLFH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_u7zTPwcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YnPq1mAg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nopEib2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mz6QipU0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YnPq1mAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mz6QipU0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pm07Cw0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_5ZblVnuy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5ZblVnuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qWYdEI6J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qWYdEI6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9J6zZmHf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_XI0JeX7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZwJ593eA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_u8YlXVYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AvVfmLzX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Rx4XOfXe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TcZHIwwh_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3c1L8jB9_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SMimKjYa_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DginfEco_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4rzUdL9Z_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l9BT2aaH_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_TcZHIwwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ieiY8mUn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_3c1L8jB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PUqnEcBg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_SMimKjYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tQqCUUBq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_DginfEco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nLFGWvbe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_4rzUdL9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5LMMbSpX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_l9BT2aaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uBpb9oRI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_OUFQeyVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_d97FWTLt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lMHcLhbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0QHI5QRF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3lt6k8Ha_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QA5kR8OI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QA5kR8OI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_C8Y1eer5, 1, m, &cDelay_C8Y1eer5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7tiHXdgD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_C8Y1eer5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C8Y1eer5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OUFQeyVA, 0, m, &cIf_OUFQeyVA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QA5kR8OI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_C8Y1eer5, 0, m, &cDelay_C8Y1eer5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7tiHXdgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C8Y1eer5, 0, m, &cDelay_C8Y1eer5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_14gOQu3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vej63jLC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gjZiUwFc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CMGXra33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_86EmMMvA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TgJ6f2OY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TgJ6f2OY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3lt6k8Ha_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_86EmMMvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OUFQeyVA, 1, m, &cIf_OUFQeyVA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gjZiUwFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lMHcLhbk, 0, m, &cIf_lMHcLhbk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Vej63jLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lMHcLhbk, 1, m, &cIf_lMHcLhbk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0QHI5QRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1yyM5g9J, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_d97FWTLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1yyM5g9J, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Dy7jnDoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0pTeXzHp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dP1XfxYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zBmg2mMe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_m89sybN3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_D93q6HGN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_D93q6HGN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ctbkvi02, 1, m, &cDelay_Ctbkvi02_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fH2Rulpg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Ctbkvi02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ctbkvi02, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Dy7jnDoe, 0, m, &cIf_Dy7jnDoe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_D93q6HGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ctbkvi02, 0, m, &cDelay_Ctbkvi02_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fH2Rulpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ctbkvi02, 0, m, &cDelay_Ctbkvi02_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vs0VEQhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M0NIlhQt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sCBDdsRh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yPRdXN3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vDlX4IUi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rx5tjM5u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vDlX4IUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Dy7jnDoe, 1, m, &cIf_Dy7jnDoe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Rx5tjM5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_m89sybN3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sCBDdsRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dP1XfxYy, 0, m, &cIf_dP1XfxYy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M0NIlhQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dP1XfxYy, 1, m, &cIf_dP1XfxYy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zBmg2mMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bO9lR8Ek, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0pTeXzHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bO9lR8Ek, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_84Rlw4bt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sKvmNQMp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_TX9bo1Qf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ilv5gV65_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Pxh9kWHa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Pv8XvWpd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Pv8XvWpd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_un9WwyFC, 1, m, &cDelay_un9WwyFC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dVOrwIob_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_un9WwyFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_un9WwyFC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_84Rlw4bt, 0, m, &cIf_84Rlw4bt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Pv8XvWpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_un9WwyFC, 0, m, &cDelay_un9WwyFC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dVOrwIob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_un9WwyFC, 0, m, &cDelay_un9WwyFC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lGhWG8DZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XBVp8UK7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YGJDUqfz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ykx5h82x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BxBKtyaU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k0JOT1Hg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BxBKtyaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_84Rlw4bt, 1, m, &cIf_84Rlw4bt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k0JOT1Hg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Pxh9kWHa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YGJDUqfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TX9bo1Qf, 0, m, &cIf_TX9bo1Qf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XBVp8UK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TX9bo1Qf, 1, m, &cIf_TX9bo1Qf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ilv5gV65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CsGan9fy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sKvmNQMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CsGan9fy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_EQswa34K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ShYfIdIX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5oGhZbVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EFJ5y7IZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LoBz9biI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_x9WD8oAl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_x9WD8oAl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Jl7gv0B1, 1, m, &cDelay_Jl7gv0B1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2MIakMLC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Jl7gv0B1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Jl7gv0B1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EQswa34K, 0, m, &cIf_EQswa34K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x9WD8oAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Jl7gv0B1, 0, m, &cDelay_Jl7gv0B1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2MIakMLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Jl7gv0B1, 0, m, &cDelay_Jl7gv0B1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9DagQYx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DVUkxGhK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kJMA4Q0O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G40L6qID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KOXj1ZFu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pl1j7ee6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Pl1j7ee6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LoBz9biI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_KOXj1ZFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EQswa34K, 1, m, &cIf_EQswa34K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kJMA4Q0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5oGhZbVf, 0, m, &cIf_5oGhZbVf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DVUkxGhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5oGhZbVf, 1, m, &cIf_5oGhZbVf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EFJ5y7IZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GHnAIG3z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ShYfIdIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GHnAIG3z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_boahbzXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VKW7VQeM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DrbzBEOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HieQV24V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3nRuyTRS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OmD3WizZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OmD3WizZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_eIA3jfjV, 1, m, &cDelay_eIA3jfjV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0vJtdSjp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_eIA3jfjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eIA3jfjV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_boahbzXI, 0, m, &cIf_boahbzXI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OmD3WizZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eIA3jfjV, 0, m, &cDelay_eIA3jfjV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0vJtdSjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eIA3jfjV, 0, m, &cDelay_eIA3jfjV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uvN22jt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nSJbjLq1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ffStsdri_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wBEURIAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O1fbbHN0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Sk5OptlC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Sk5OptlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3nRuyTRS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_O1fbbHN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_boahbzXI, 1, m, &cIf_boahbzXI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ffStsdri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DrbzBEOv, 0, m, &cIf_DrbzBEOv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nSJbjLq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DrbzBEOv, 1, m, &cIf_DrbzBEOv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HieQV24V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QaueMrzd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VKW7VQeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QaueMrzd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_TNg7FyOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kmVJgFe1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oWKbDK1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MjzIZkKo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eNcSCmME_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_afX9lwcd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_afX9lwcd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_f7xbR6NN, 1, m, &cDelay_f7xbR6NN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iKH1THeQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_f7xbR6NN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_f7xbR6NN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_TNg7FyOA, 0, m, &cIf_TNg7FyOA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_afX9lwcd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_f7xbR6NN, 0, m, &cDelay_f7xbR6NN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iKH1THeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_f7xbR6NN, 0, m, &cDelay_f7xbR6NN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Pdwe9oxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SkdrsvxP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GcndokZD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_trUIYfHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tynuzd9E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e4RTC1AB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tynuzd9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TNg7FyOA, 1, m, &cIf_TNg7FyOA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e4RTC1AB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eNcSCmME_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GcndokZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oWKbDK1m, 0, m, &cIf_oWKbDK1m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SkdrsvxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oWKbDK1m, 1, m, &cIf_oWKbDK1m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MjzIZkKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vniP6wyM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kmVJgFe1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vniP6wyM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BbeF0xwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dIopvwkA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_h3bcADmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uGoLVyJu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zNXyM39I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tRMOU11S_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tRMOU11S_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yyzkE2rs, 1, m, &cDelay_yyzkE2rs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X4CdAEpy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yyzkE2rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yyzkE2rs, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BbeF0xwV, 0, m, &cIf_BbeF0xwV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tRMOU11S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yyzkE2rs, 0, m, &cDelay_yyzkE2rs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X4CdAEpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yyzkE2rs, 0, m, &cDelay_yyzkE2rs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Uph0BMyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HMiq4cTj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tGUPEYVd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Rm0BJ3QG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ex3ysdT1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zcL1Mw23_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ex3ysdT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BbeF0xwV, 1, m, &cIf_BbeF0xwV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zcL1Mw23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zNXyM39I_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HMiq4cTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h3bcADmk, 1, m, &cIf_h3bcADmk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tGUPEYVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h3bcADmk, 0, m, &cIf_h3bcADmk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uGoLVyJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QEFSzlxX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dIopvwkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QEFSzlxX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ldowuEux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rfoTpDCY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zu9HItwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eL5TBNdu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yeucwZb8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eIm2IZJV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eIm2IZJV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oQrx20Aa, 1, m, &cDelay_oQrx20Aa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uC7eFnZP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oQrx20Aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oQrx20Aa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ldowuEux, 0, m, &cIf_ldowuEux_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eIm2IZJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oQrx20Aa, 0, m, &cDelay_oQrx20Aa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uC7eFnZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oQrx20Aa, 0, m, &cDelay_oQrx20Aa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JfNtX9NU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yOuKr36Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4dsvEG5B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0Tj8ilYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VK9MF4EP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DayQOo55_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VK9MF4EP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ldowuEux, 1, m, &cIf_ldowuEux_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DayQOo55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yeucwZb8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yOuKr36Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zu9HItwH, 1, m, &cIf_zu9HItwH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4dsvEG5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zu9HItwH, 0, m, &cIf_zu9HItwH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eL5TBNdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dCidLkjd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rfoTpDCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dCidLkjd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8kNFJpgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UXzvtRqO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_a5hCCRRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QFYGCwJt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_99s1AIdF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0xEIdVdE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0xEIdVdE_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7CxrSv7y, 1, m, &cDelay_7CxrSv7y_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bR7jD8TB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7CxrSv7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7CxrSv7y, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8kNFJpgh, 0, m, &cIf_8kNFJpgh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0xEIdVdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7CxrSv7y, 0, m, &cDelay_7CxrSv7y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bR7jD8TB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7CxrSv7y, 0, m, &cDelay_7CxrSv7y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lmxq7NkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_74d7ie1Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mDIo9O4O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B3li7sae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_exuQ4ME8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5T61n8Ds_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5T61n8Ds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_99s1AIdF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_exuQ4ME8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8kNFJpgh, 1, m, &cIf_8kNFJpgh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_74d7ie1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a5hCCRRg, 1, m, &cIf_a5hCCRRg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mDIo9O4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a5hCCRRg, 0, m, &cIf_a5hCCRRg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QFYGCwJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6elAW81c, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UXzvtRqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6elAW81c, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_cvPYxhxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_T847Uni0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_pgTymucB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_U1foOFdF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qhup88ER_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TOt9zp2X_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TOt9zp2X_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_3L9OAYmN, 1, m, &cDelay_3L9OAYmN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z7kW5YaM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_3L9OAYmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3L9OAYmN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cvPYxhxU, 0, m, &cIf_cvPYxhxU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TOt9zp2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3L9OAYmN, 0, m, &cDelay_3L9OAYmN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z7kW5YaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3L9OAYmN, 0, m, &cDelay_3L9OAYmN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QdGtLdZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SG7iN5u0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2PrjU3Uo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fDd9Lzld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kZCFGfyf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3g4wekjJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3g4wekjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qhup88ER_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kZCFGfyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cvPYxhxU, 1, m, &cIf_cvPYxhxU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2PrjU3Uo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pgTymucB, 0, m, &cIf_pgTymucB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SG7iN5u0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pgTymucB, 1, m, &cIf_pgTymucB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U1foOFdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_juhFIt18, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_T847Uni0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_juhFIt18, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_K7LolLND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zqOzk8BC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hfjaHmPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_N4kmEbmg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZJGKDr14_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nHopdgXd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nHopdgXd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IRbqJv4n, 1, m, &cDelay_IRbqJv4n_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eWDT7RqT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IRbqJv4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IRbqJv4n, m);
  cIf_onMessage(_c, &Context(_c)->cIf_K7LolLND, 0, m, &cIf_K7LolLND_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nHopdgXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IRbqJv4n, 0, m, &cDelay_IRbqJv4n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eWDT7RqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IRbqJv4n, 0, m, &cDelay_IRbqJv4n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L4iN8RBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MmpftXL0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_enLKqKyy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BOikW00r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DPcz9327_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mpgNXdlK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DPcz9327_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K7LolLND, 1, m, &cIf_K7LolLND_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mpgNXdlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZJGKDr14_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MmpftXL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hfjaHmPT, 1, m, &cIf_hfjaHmPT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_enLKqKyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hfjaHmPT, 0, m, &cIf_hfjaHmPT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N4kmEbmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iIDBQ4r0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zqOzk8BC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iIDBQ4r0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_l1zJCirT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gNw7ha02_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UQ9KrUDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_C4x2VqkX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gCVxHXSs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CGBBYTOJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CGBBYTOJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dY2ImBl3, 1, m, &cDelay_dY2ImBl3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K7fXox21_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_dY2ImBl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dY2ImBl3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_l1zJCirT, 0, m, &cIf_l1zJCirT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CGBBYTOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dY2ImBl3, 0, m, &cDelay_dY2ImBl3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K7fXox21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dY2ImBl3, 0, m, &cDelay_dY2ImBl3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vIYwoPdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4lN8kdn1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WsjZOyXd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6xTwNiWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Mz3Yqd8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E7c5jriG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2Mz3Yqd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l1zJCirT, 1, m, &cIf_l1zJCirT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E7c5jriG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gCVxHXSs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4lN8kdn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UQ9KrUDI, 1, m, &cIf_UQ9KrUDI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WsjZOyXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UQ9KrUDI, 0, m, &cIf_UQ9KrUDI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C4x2VqkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HRRiEk8F, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gNw7ha02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HRRiEk8F, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ieiY8mUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_hc4NHAUS_sendMessage(_c, 0, m);
  cMsg_UezUF3Cr_sendMessage(_c, 0, m);
  cMsg_evrvCmyl_sendMessage(_c, 0, m);
  cMsg_1K1gI0YI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PUqnEcBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_hc4NHAUS_sendMessage(_c, 0, m);
  cMsg_PSaGDUv2_sendMessage(_c, 0, m);
  cMsg_GI0SPpv8_sendMessage(_c, 0, m);
  cMsg_Q9AErrtf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tQqCUUBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_7ffxFRwO_sendMessage(_c, 0, m);
  cMsg_PSaGDUv2_sendMessage(_c, 0, m);
  cMsg_1K1gI0YI_sendMessage(_c, 0, m);
  cMsg_EM3K3VoT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nLFGWvbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_7ffxFRwO_sendMessage(_c, 0, m);
  cMsg_PBwfhbHX_sendMessage(_c, 0, m);
  cMsg_evrvCmyl_sendMessage(_c, 0, m);
  cMsg_cyzLCz6v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5LMMbSpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_0uzDpcUv_sendMessage(_c, 0, m);
  cMsg_Q9AErrtf_sendMessage(_c, 0, m);
  cMsg_23Aj0FrB_sendMessage(_c, 0, m);
  cMsg_evrvCmyl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uBpb9oRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_0uzDpcUv_sendMessage(_c, 0, m);
  cMsg_cyzLCz6v_sendMessage(_c, 0, m);
  cMsg_PSaGDUv2_sendMessage(_c, 0, m);
  cMsg_mKUAcOz9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KcpbZaon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CMGXra33_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_14gOQu3o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZpdzG4Ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CMGXra33_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_14gOQu3o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9MMC9NPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yPRdXN3q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vs0VEQhn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Yy23md53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yPRdXN3q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vs0VEQhn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TFic8A9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ykx5h82x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lGhWG8DZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zDJUVS0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ykx5h82x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lGhWG8DZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hc4NHAUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_KcpbZaon_sendMessage(_c, 0, m);
  cMsg_Yy23md53_sendMessage(_c, 0, m);
  cMsg_zDJUVS0X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7ffxFRwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_ZpdzG4Ah_sendMessage(_c, 0, m);
  cMsg_9MMC9NPO_sendMessage(_c, 0, m);
  cMsg_zDJUVS0X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0uzDpcUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_ZpdzG4Ah_sendMessage(_c, 0, m);
  cMsg_Yy23md53_sendMessage(_c, 0, m);
  cMsg_TFic8A9s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pvwS3LKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G40L6qID_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9DagQYx8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BQK0YRZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G40L6qID_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9DagQYx8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XTt8U2fx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wBEURIAw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uvN22jt5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8htFYO5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wBEURIAw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uvN22jt5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9HzG5nvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_trUIYfHg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Pdwe9oxn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XRIAImvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_trUIYfHg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Pdwe9oxn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PSaGDUv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_BQK0YRZy_sendMessage(_c, 0, m);
  cMsg_8htFYO5M_sendMessage(_c, 0, m);
  cMsg_XRIAImvz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UezUF3Cr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_BQK0YRZy_sendMessage(_c, 0, m);
  cMsg_XTt8U2fx_sendMessage(_c, 0, m);
  cMsg_9HzG5nvX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PBwfhbHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_pvwS3LKx_sendMessage(_c, 0, m);
  cMsg_8htFYO5M_sendMessage(_c, 0, m);
  cMsg_9HzG5nvX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EfV90IV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fDd9Lzld_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QdGtLdZz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LzJeRmrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fDd9Lzld_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QdGtLdZz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nWt0VTK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BOikW00r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_L4iN8RBd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zjZaAN3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BOikW00r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_L4iN8RBd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HAIIQ7HW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6xTwNiWV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vIYwoPdp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DlK8fuLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6xTwNiWV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vIYwoPdp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cyzLCz6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_EfV90IV0_sendMessage(_c, 0, m);
  cMsg_zjZaAN3S_sendMessage(_c, 0, m);
  cMsg_DlK8fuLR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Q9AErrtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_LzJeRmrk_sendMessage(_c, 0, m);
  cMsg_nWt0VTK3_sendMessage(_c, 0, m);
  cMsg_DlK8fuLR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1K1gI0YI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_LzJeRmrk_sendMessage(_c, 0, m);
  cMsg_zjZaAN3S_sendMessage(_c, 0, m);
  cMsg_HAIIQ7HW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CWz3fudp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Rm0BJ3QG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Uph0BMyy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Gh4e3Svc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Rm0BJ3QG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Uph0BMyy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y37jCHRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0Tj8ilYI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JfNtX9NU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_swIlsAb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0Tj8ilYI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JfNtX9NU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iL1EmTDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B3li7sae_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lmxq7NkJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hiMU8HCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B3li7sae_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lmxq7NkJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_evrvCmyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_Gh4e3Svc_sendMessage(_c, 0, m);
  cMsg_swIlsAb6_sendMessage(_c, 0, m);
  cMsg_hiMU8HCc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GI0SPpv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_Gh4e3Svc_sendMessage(_c, 0, m);
  cMsg_Y37jCHRR_sendMessage(_c, 0, m);
  cMsg_iL1EmTDo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mKUAcOz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_CWz3fudp_sendMessage(_c, 0, m);
  cMsg_Y37jCHRR_sendMessage(_c, 0, m);
  cMsg_hiMU8HCc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_23Aj0FrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_pvwS3LKx_sendMessage(_c, 0, m);
  cMsg_XTt8U2fx_sendMessage(_c, 0, m);
  cMsg_XRIAImvz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EM3K3VoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_CWz3fudp_sendMessage(_c, 0, m);
  cMsg_swIlsAb6_sendMessage(_c, 0, m);
  cMsg_iL1EmTDo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_gfQuqo7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_02087ElD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EicutXeS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sz41cj3r, 0, m, &cSlice_sz41cj3r_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IARxbTfa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_sz41cj3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UUWXiqOn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UUWXiqOn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_P17kuMNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UUWXiqOn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UUWXiqOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vfpE7BsO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SFtVhWVf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZWfD9NtT, 0, m, &cSlice_ZWfD9NtT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Z3eI4qXS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ZWfD9NtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ONFQmGog_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ONFQmGog_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_sfA1s3Sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ONFQmGog_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ONFQmGog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ujAmU9tg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Z3eI4qXS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rGJJAaxR, 0, m, &cSlice_rGJJAaxR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EicutXeS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_rGJJAaxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OeoLGU5P_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OeoLGU5P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_43GfZYBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OeoLGU5P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_OeoLGU5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0KVyg2MB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IARxbTfa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xZbXq0Kx, 0, m, &cSlice_xZbXq0Kx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_h4n8ivN1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_xZbXq0Kx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eTQrC87h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eTQrC87h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_czjYz9fX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eTQrC87h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_eTQrC87h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rpGLCyqN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_h4n8ivN1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4WIqwxo2, 0, m, &cSlice_4WIqwxo2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Kmfmc98D_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_4WIqwxo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UzWnoXH0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UzWnoXH0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_WoC2ol27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UzWnoXH0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UzWnoXH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pRWwYELw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ISDcV44c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fUlHcky1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fUlHcky1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0zdiP8gp, 1, m, &cDelay_0zdiP8gp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KIBQQLVz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0zdiP8gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0zdiP8gp, m);
  cMsg_ruwYrSOu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fUlHcky1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0zdiP8gp, 0, m, &cDelay_0zdiP8gp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KIBQQLVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0zdiP8gp, 0, m, &cDelay_0zdiP8gp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_VTAdhxfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uXoS3dDO, HV_BINOP_SUBTRACT, 0, m, &cBinop_uXoS3dDO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_iOyEEMsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dA9otlDL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Mjn3VTJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dA9otlDL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_QFxVoMhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VTAdhxfX, 0, m, &cVar_VTAdhxfX_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_4VlCUEcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BUVQ3Tgl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1nSIGx5L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gACUOaFS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uXoS3dDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3GGBjdQJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3GGBjdQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QV0wE0Hb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QV0wE0Hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_uA6IovKf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rqEkkGQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ESPGGCKm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FKK8BTnr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FKK8BTnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zBgKQP6H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ESPGGCKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iOyEEMsI, 1, m, &cIf_iOyEEMsI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MugM3jKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Mjn3VTJO, 1, m, &cIf_Mjn3VTJO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zBgKQP6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_iOyEEMsI, 0, m, &cIf_iOyEEMsI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uA6IovKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Mjn3VTJO, 0, m, &cIf_Mjn3VTJO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1nSIGx5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uXoS3dDO, HV_BINOP_SUBTRACT, 1, m, &cBinop_uXoS3dDO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BUVQ3Tgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_gACUOaFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VTAdhxfX, 0, m, &cVar_VTAdhxfX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dA9otlDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cB5PE5uM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Kmfmc98D_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9dT6tRce, 0, m, &cSlice_9dT6tRce_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9dT6tRce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XCF78tup_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XCF78tup_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TsITJvRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XCF78tup_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_XCF78tup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sPIXNCq0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZwJ593eA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kTfrq7xh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AvVfmLzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5bC37u66, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_kbxHz7KB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u8YlXVYC, 0, m, &cVar_u8YlXVYC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_02087ElD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7wMP3wCF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sNlJfnVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ISDcV44c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WUIcad1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dll2Ii8x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ruwYrSOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rrrcbDoi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dll2Ii8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rrrcbDoi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_T5qKUeXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_GHQcbrW5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GHQcbrW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z7FOj410_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Z7FOj410_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GvzxD2jc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_Jip6Ri9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ilew3RL1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_i83ItpF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NTIsembr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_x2wRLsCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8A2vEf8B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_an4p3w5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_U8Y8VqPk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H8naOuME_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_AHmCCI8G_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YSGlSTFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_U8Y8VqPk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H8naOuME_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_AHmCCI8G_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_UZKfEWqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TWFYKzea, 0, m, &cVar_TWFYKzea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_exXijmko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_U8Y8VqPk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H8naOuME_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_AHmCCI8G_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0i1kkAOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_U8Y8VqPk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H8naOuME_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_AHmCCI8G_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hccWQ6KX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_U8Y8VqPk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H8naOuME_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_AHmCCI8G_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FELzqVMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_rEgLR6MH, 0, m, &cVar_rEgLR6MH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x8DBMpcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_2iMaYoBZ, 0, m, &cVar_2iMaYoBZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Mwv2yz7x, 0, m, &cVar_Mwv2yz7x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KpKkfzlI, 0, m, &cVar_KpKkfzlI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vqfB7FyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_UZKfEWqM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zPCN1skt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1QwWeKE8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_08zKuaBy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_li5tdiPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1QwWeKE8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_08zKuaBy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oE7wmHgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1QwWeKE8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_08zKuaBy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QjGcbAVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1QwWeKE8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_08zKuaBy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xDloProb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1QwWeKE8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_08zKuaBy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qC7VPtdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_J1Cskvl0, 0, m, &cVar_J1Cskvl0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_c4FqzjPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_1PbEQr7j, 0, m, &cVar_1PbEQr7j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LedYrwCK, 0, m, &cVar_LedYrwCK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0GjL3vM4, 0, m, &cVar_0GjL3vM4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KdzjJyKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_U8Y8VqPk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H8naOuME_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_AHmCCI8G_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WGXGm6jl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UfrTMLbu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6FlnY3NO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q5njJST0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xXUHhZTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UfrTMLbu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6FlnY3NO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q5njJST0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_AZRsKoVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QfrneSS5, 0, m, &cVar_QfrneSS5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xEYsB0bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UfrTMLbu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6FlnY3NO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q5njJST0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cqYfjzN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UfrTMLbu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6FlnY3NO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q5njJST0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MVgmRfrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UfrTMLbu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6FlnY3NO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q5njJST0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Xc5NZcNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_9q9SOcbV, 0, m, &cVar_9q9SOcbV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pC3MLICa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_xramEk4y, 0, m, &cVar_xramEk4y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_alVox0ps, 0, m, &cVar_alVox0ps_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YsZqaxoL, 0, m, &cVar_YsZqaxoL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5L1JorEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_AZRsKoVB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_06negG0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UfrTMLbu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6FlnY3NO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q5njJST0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qoa0fXUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2H5NLkP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OomEJobD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SFtVhWVf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kevbV2HS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2H5NLkP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OomEJobD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SFtVhWVf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_Zeb743TH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rNGgIymJ, 0, m, &cVar_rNGgIymJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_A6hoUG4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2H5NLkP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OomEJobD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SFtVhWVf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zNFD9ekq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2H5NLkP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OomEJobD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SFtVhWVf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mztHcUFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2H5NLkP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OomEJobD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SFtVhWVf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rOpL5I65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_qk0iGwb7, 0, m, &cVar_qk0iGwb7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1jB7cN3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_lIDqKwSJ, 0, m, &cVar_lIDqKwSJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mJAlRwOA, 0, m, &cVar_mJAlRwOA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4W41IuiM, 0, m, &cVar_4W41IuiM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y1sweHSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Zeb743TH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hacsmLqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2H5NLkP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OomEJobD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SFtVhWVf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_T5DyXBVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Jip6Ri9K, 0, m, &cVar_Jip6Ri9K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ilew3RL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_U8Y8VqPk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H8naOuME_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_AHmCCI8G_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WyWeCiVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_i83ItpF4, 0, m, &cVar_i83ItpF4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NTIsembr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UfrTMLbu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6FlnY3NO_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q5njJST0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cJzGaTiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_x2wRLsCL, 0, m, &cVar_x2wRLsCL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8A2vEf8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_f2H5NLkP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_OomEJobD_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_SFtVhWVf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_oJWXHGlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dxsdirKO_sendMessage(_c, 0, m);
  cMsg_lXpMtPVx_sendMessage(_c, 0, m);
  cMsg_Vob4DQDY_sendMessage(_c, 0, m);
  cMsg_NaCl7QLX_sendMessage(_c, 0, m);
  cMsg_gtQ3v2Hj_sendMessage(_c, 0, m);
  cMsg_tfQ0JX5k_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nzfvQfl5, 0, m, &cVar_nzfvQfl5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_orzAmyRG, 0, m, &cVar_orzAmyRG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GRerQSDA, 0, m, &cVar_GRerQSDA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YYUfom53, 0, m, &cVar_YYUfom53_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xyqG6Z71, 0, m, &cVar_xyqG6Z71_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DhuSmcrY, 0, m, &cVar_DhuSmcrY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_of5s3swg, 0, m, &cVar_of5s3swg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_igDE3udd, 0, m, &cVar_igDE3udd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c4bLdeEJ, 0, m, &cVar_c4bLdeEJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JrkBlI8a, 0, m, &cVar_JrkBlI8a_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BEjQ8BTy, 0, m, &cVar_BEjQ8BTy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gu1mKmbG, 0, m, &cVar_gu1mKmbG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1Zgt3ank, 0, m, &cVar_1Zgt3ank_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9nVITjRA, 0, m, &cVar_9nVITjRA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3PgGF4P4, 0, m, &cVar_3PgGF4P4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dp6hvvgW, 0, m, &cVar_dp6hvvgW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hxxEBsCd, 0, m, &cVar_hxxEBsCd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WWQlMVOE, 0, m, &cVar_WWQlMVOE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_T4tOSQKF, 0, m, &cVar_T4tOSQKF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zEdgtR1v, 0, m, &cVar_zEdgtR1v_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v7Xs3ApL, 0, m, &cVar_v7Xs3ApL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PN6qdr3Z, 0, m, &cVar_PN6qdr3Z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_n7RFc5X8, 0, m, &cVar_n7RFc5X8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NuZMECkq, 0, m, &cVar_NuZMECkq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_85r93S0R, 0, m, &cVar_85r93S0R_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c3gLPIC6, 0, m, &cVar_c3gLPIC6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Br5OWdTp, 0, m, &cVar_Br5OWdTp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jIbOsbuG, 0, m, &cVar_jIbOsbuG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JFGvcXOD, 0, m, &cVar_JFGvcXOD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j0J1EHva, 0, m, &cVar_j0J1EHva_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VjQ2qqPZ, 0, m, &cVar_VjQ2qqPZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0l2dwnpE, 0, m, &cVar_0l2dwnpE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2HpZ4ah4, 0, m, &cVar_2HpZ4ah4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3L3pXb7K, 0, m, &cVar_3L3pXb7K_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nHBDsWuT, 0, m, &cVar_nHBDsWuT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Fu0RGTOt, 0, m, &cVar_Fu0RGTOt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zzD7s9V3, 0, m, &cVar_zzD7s9V3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LeHQTddB, 0, m, &cVar_LeHQTddB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1ajPrGv5, 0, m, &cVar_1ajPrGv5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eRgFbCt3, 0, m, &cVar_eRgFbCt3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IeU4aKDO, 0, m, &cVar_IeU4aKDO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TC7GY2No, 0, m, &cVar_TC7GY2No_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YtJXFepk, 0, m, &cVar_YtJXFepk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Yzx6fMDl, 0, m, &cVar_Yzx6fMDl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MzTReQOz, 0, m, &cVar_MzTReQOz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ofd3WStB, 0, m, &cVar_ofd3WStB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_52QPa1GD, 0, m, &cVar_52QPa1GD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sUhhHzfa, 0, m, &cVar_sUhhHzfa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3UJBlSrN, 0, m, &cVar_3UJBlSrN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XCh9bzr0, 0, m, &cVar_XCh9bzr0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XXVo7NES, 0, m, &cVar_XXVo7NES_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Vd1zShIP, 0, m, &cVar_Vd1zShIP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P17kuMNp, 0, m, &cVar_P17kuMNp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sfA1s3Sw, 0, m, &cVar_sfA1s3Sw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_43GfZYBd, 0, m, &cVar_43GfZYBd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_czjYz9fX, 0, m, &cVar_czjYz9fX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WoC2ol27, 0, m, &cVar_WoC2ol27_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TsITJvRp, 0, m, &cVar_TsITJvRp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E0sSumlV, 0, m, &cVar_E0sSumlV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qy2T9dSm, 0, m, &cVar_qy2T9dSm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VDrhDdzp, 0, m, &cVar_VDrhDdzp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9kxEd14H_sendMessage);
  cMsg_c4FqzjPD_sendMessage(_c, 0, m);
  cMsg_qC7VPtdh_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ovnVcyBB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wbLzouNf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vtAygWAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1PbEQr7j, 0, m, &cVar_1PbEQr7j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4dGV1Bmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LedYrwCK, 0, m, &cVar_LedYrwCK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_f58QkQk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0GjL3vM4, 0, m, &cVar_0GjL3vM4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_f7MlT223_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_orzAmyRG, 0, m, &cVar_orzAmyRG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sRmoI3PF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tlklmzaX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TRFIbxQc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Sx5qgBgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H5TYXpbU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SK2TcAJY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qp5FacyR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LRTP4uAm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_s7hbKDLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rSfWjGIb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TH372THX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WgCIgo8C_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yXY1yaMx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YO2vHiOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LXhPzFZS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hIBNH3hF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cOCoWvqp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NsHlfAdD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qGOPsxwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VCgINkwx, HV_BINOP_MULTIPLY, 0, m, &cBinop_VCgINkwx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fsVnnMh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GWHEl0Bu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Zui9T056_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_37MeNhmb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_aZeWVx62_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RQQiJUaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_641uqvkr_sendMessage);
  cMsg_K1ZitC0E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_eXIyxPZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dfo1IAeF, HV_BINOP_MULTIPLY, 0, m, &cBinop_dfo1IAeF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eP7unyu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_OWYQxIP4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PdSTiEnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vQpNkFrr, HV_BINOP_MULTIPLY, 1, m, &cBinop_vQpNkFrr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0Z1ZUpcO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QmyVP3Ib_sendMessage);
  cMsg_nIRYiqfg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_kAqvampd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aMtpD6M3, HV_BINOP_MULTIPLY, 0, m, &cBinop_aMtpD6M3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pWFq4PdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J6MPqLUk_sendMessage(_c, 0, m);
  cMsg_w80iMS58_sendMessage(_c, 0, m);
  cMsg_fZrTViwW_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_gkX12FKj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_tc3wVE1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9umTfKd1_sendMessage);
  cMsg_qnrQr6Tu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_ls0Ioo6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xyqG6Z71, 0, m, &cVar_xyqG6Z71_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cwDMaQ3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hlp7YDAt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1ilqNmZO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_EIPaZai5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ChK9Hg9d_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vgHwkbdU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2pwaxHEx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_30rrNMJ6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pLdYZGuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AdDx4ySO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FhpOeiby_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KSEwbAJk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4oLARuHI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ycOpbzhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XbzYUxHG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DKjlaBmu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WKgHz5Jb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8iIwy8Ak_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2nCD967D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UOG7LwG3, HV_BINOP_MULTIPLY, 0, m, &cBinop_UOG7LwG3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KoWGF65p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CIt32T2X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_16rOofGV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9N4I8W76_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_1wg18UMD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gLwTBLFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_U6c13rXd_sendMessage);
  cMsg_XvnYmDzh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_V4tTKxWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C4umZw7r, HV_BINOP_MULTIPLY, 0, m, &cBinop_C4umZw7r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SDY01T5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_HZn69tOT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qVspi1CC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Il6bsO6E, HV_BINOP_MULTIPLY, 1, m, &cBinop_Il6bsO6E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gPiOI4y3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CcXwdmHI_sendMessage);
  cMsg_6t8qfY1P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_YSvClWhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vt9wthlC, HV_BINOP_MULTIPLY, 0, m, &cBinop_Vt9wthlC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uFPlEcg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tvk77PDQ_sendMessage(_c, 0, m);
  cMsg_a6MHIr4x_sendMessage(_c, 0, m);
  cMsg_muTrZ0zF_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_2IG0J1c9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Z3rrgvdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UKoR4VQa_sendMessage);
  cMsg_NbWz5pQD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_15sngfiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_J1Cskvl0, 0, m, &cVar_J1Cskvl0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0Cc6vpCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wKbD1Z71, 0, m, &cVar_wKbD1Z71_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7Qr5j9bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rEgLR6MH, 0, m, &cVar_rEgLR6MH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_m6kB4VNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2iMaYoBZ, 0, m, &cVar_2iMaYoBZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_d11NdOMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mwv2yz7x, 0, m, &cVar_Mwv2yz7x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_M90bJM04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KpKkfzlI, 0, m, &cVar_KpKkfzlI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vwLNOqpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_UZKfEWqM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_c87b9xKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_AAj9Q0f6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hCNxj7fa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tpz2Ayt9, 0, m, &cVar_tpz2Ayt9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Jyb17J7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cOWXTprG, 0, m, &cVar_cOWXTprG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yXHzWMBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_foDwT9lz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GdX12s4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pNucKtWh_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2PkA8gJu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sJNnKpHG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jwg0BVYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xhOFQ2c2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rcJ1cM67_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_MKufJJhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IzYBs4Sx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_LCi0PAB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8r1jjJs6, 0, m, &cVar_8r1jjJs6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jbU572Kj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PQ0JWc7m, 0, m, &cVar_PQ0JWc7m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GTEnmwau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_PxPEamr3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8nUMSjxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lRhpMoze_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KAL02zyu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2ljW0l0E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DXno7MHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_s3cOO0X3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pefNx7bX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NHhlrOw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DapvS51a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_NWRTSUmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hU6TO4pk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fGbmJubB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kjfh58CW, 0, m, &cVar_kjfh58CW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rKWJFMgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HX9UGaL7, 0, m, &cVar_HX9UGaL7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pPixn0UN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_aoHXfIMD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zz7hYlhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0o0egYYI_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UmDXorZJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7Php8fxF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_m0DEBlAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Gft26hOC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vGMKTXcH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ttZ4dY9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dz7JvEnA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_AWjjOHCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0HPs7n0s, 0, m, &cVar_0HPs7n0s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YR9XrXym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_avpRM5Vt, 0, m, &cVar_avpRM5Vt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4LGlDM8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_VDCzT33Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3JI383kK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_d2itPwjM_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uDdImY07_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hGNrvunY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_BBhEccgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sNmOOkzU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GBk1hbkK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qK823ny8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cpqdwVNY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_BrC4OvhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C9Z2lDRE, 0, m, &cVar_C9Z2lDRE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pauCVrU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9q9SOcbV, 0, m, &cVar_9q9SOcbV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OmALedDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xramEk4y, 0, m, &cVar_xramEk4y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_D5hNU51G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_alVox0ps, 0, m, &cVar_alVox0ps_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DxDbfSLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YsZqaxoL, 0, m, &cVar_YsZqaxoL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_f9uYtK8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_AZRsKoVB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hrKO8YpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_J80qcm4k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZqW4VYu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RN1AOJk8, 0, m, &cVar_RN1AOJk8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_puzMgJQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_adlfWpm1, 0, m, &cVar_adlfWpm1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_mLvQZyXz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_YDgtCnHv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WQFva1jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HebY0xcj_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u7zTPwcp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tl6LxPBY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5xupRvvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YSGqDXO4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fKVEI54M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qAtnrP1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pm07Cw0l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_vfpE7BsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XI0JeX7y, 0, m, &cVar_XI0JeX7y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rpGLCyqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gfQuqo7q, 0, m, &cVar_gfQuqo7q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0KVyg2MB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_kbxHz7KB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ujAmU9tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Rx4XOfXe_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WUIcad1Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sNlJfnVK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pRWwYELw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rqEkkGQC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MugM3jKV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sPIXNCq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T5qKUeXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_vqDWI6aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ks0bMys5, 0, m, &cVar_Ks0bMys5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CQ7ufHbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qk0iGwb7, 0, m, &cVar_qk0iGwb7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_LaMcOniv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lIDqKwSJ, 0, m, &cVar_lIDqKwSJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WHR74Pih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mJAlRwOA, 0, m, &cVar_mJAlRwOA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RaXFs8t5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4W41IuiM, 0, m, &cVar_4W41IuiM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dv9OfEue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Zeb743TH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zXdjYFC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jip6Ri9K, 0, m, &cVar_Jip6Ri9K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_MV3sLiHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i83ItpF4, 0, m, &cVar_i83ItpF4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_47ui3TrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x2wRLsCL, 0, m, &cVar_x2wRLsCL_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_mIs1bR8N, VOf(Bf0));
    __hv_line_f(&sLine_1aqcl6Rj, VOf(Bf1));
    __hv_line_f(&sLine_r4iL8Oa0, VOf(Bf2));
    __hv_line_f(&sLine_U2WfoVfU, VOf(Bf3));
    __hv_line_f(&sLine_B7rvE1jF, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_YpSkWJ3K, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_FlmIGQ1n, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_hCaAZUX0, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_xw6YiCE5, VOf(Bf1));
    __hv_line_f(&sLine_acifBcx4, VOf(Bf0));
    __hv_line_f(&sLine_uJg4kzbC, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_vcwj8wKq, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Z8hZYdls, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_Ad44Ybgc, VOf(Bf5));
    __hv_line_f(&sLine_iQo1KLlG, VOf(Bf1));
    __hv_line_f(&sLine_ioW7baIw, VOf(Bf2));
    __hv_line_f(&sLine_IeftKuW4, VOf(Bf4));
    __hv_line_f(&sLine_1YsUL5wp, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_AFw1S6Ej, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_PEmmWLuV, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_3LpPWyug, VOf(Bf6));
    __hv_line_f(&sLine_qpdrRC15, VOf(Bf2));
    __hv_line_f(&sLine_kEuNRKdZ, VOf(Bf1));
    __hv_line_f(&sLine_fq9kDkW9, VOf(Bf5));
    __hv_line_f(&sLine_77yCnGr2, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_pcyL0VlG, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_4rRFUI0Q, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_V7sZJ2v9, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_fDU0mjDL, VOf(Bf2));
    __hv_line_f(&sLine_FQEogp4h, VOf(Bf6));
    __hv_line_f(&sLine_L0EyKR68, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_HkozabEG, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_2KaTQhi1, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_CqZMAYCX, VOf(Bf8));
    __hv_line_f(&sLine_pR6RTMuY, VOf(Bf2));
    __hv_line_f(&sLine_mxgQW420, VOf(Bf1));
    __hv_line_f(&sLine_O0JThNCj, VOf(Bf7));
    __hv_line_f(&sLine_ii0fLJNg, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_YERjQNzR, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_s8OH6a0H, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_Nf2r6lEi, VIf(Bf0));
    __hv_varwrite_f(&sVarf_CHKRUlq3, VIf(Bf6));
    __hv_varwrite_f(&sVarf_M8gkB6Bl, VIf(Bf4));
    __hv_varwrite_f(&sVarf_QecjrQDg, VIf(Bf7));
    __hv_varread_f(&sVarf_LtQs6aUU, VOf(Bf7));
    __hv_varread_f(&sVarf_7zzFDQlP, VOf(Bf4));
    __hv_varread_f(&sVarf_dHpzMTnO, VOf(Bf6));
    __hv_varread_f(&sVarf_BEogxK3e, VOf(Bf0));
    __hv_varread_f(&sVarf_Yv8iwrUB, VOf(Bf9));
    __hv_varread_f(&sVarf_AKkRrT9z, VOf(Bf1));
    __hv_line_f(&sLine_7HEyDSYL, VOf(Bf2));
    __hv_line_f(&sLine_kMPMBM6C, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_dHpzMTnO, VIf(Bf7));
    __hv_varwrite_f(&sVarf_Yv8iwrUB, VIf(Bf4));
    __hv_varread_f(&sVarf_H5CHMZN9, VOf(Bf2));
    __hv_varread_f(&sVarf_nX66Efhx, VOf(Bf9));
    __hv_varread_f(&sVarf_ATqffRbS, VOf(Bf1));
    __hv_varread_f(&sVarf_vRHct2UK, VOf(Bf6));
    __hv_varread_f(&sVarf_eearNQGP, VOf(Bf10));
    __hv_varread_f(&sVarf_Zyrg8TJi, VOf(Bf11));
    __hv_varread_f(&sVarf_oFgdbCNS, VOf(Bf12));
    __hv_varwrite_f(&sVarf_5p80XTxQ, VIf(Bf7));
    __hv_varread_f(&sVarf_1MkUiChc, VOf(Bf13));
    __hv_line_f(&sLine_LqOW5cbx, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_EDhr0Lwx, VOf(Bf15));
    __hv_line_f(&sLine_DJhFh3d0, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_PZWOtdHY, VOf(Bf14));
    __hv_line_f(&sLine_QkvYRPOo, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_vRHct2UK, VIf(Bf17));
    __hv_varread_f(&sVarf_5p80XTxQ, VOf(Bf17));
    __hv_line_f(&sLine_Sit8fAf1, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_JuLAwOOH, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_P0OaMtXP, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_eearNQGP, VIf(Bf16));
    __hv_line_f(&sLine_vg2Zp1yK, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_b62RQYxO, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_3Nrcd90m, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_Zyrg8TJi, VIf(Bf16));
    __hv_line_f(&sLine_F9CZ4nPG, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_q5aXWgio, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_qOcd6Ljv, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_oFgdbCNS, VIf(Bf16));
    __hv_varwrite_f(&sVarf_1MkUiChc, VIf(Bf2));
    __hv_varwrite_f(&sVarf_EDhr0Lwx, VIf(Bf9));
    __hv_varwrite_f(&sVarf_PZWOtdHY, VIf(Bf1));
    sEnv_process(this, &sEnv_BCUizeyW, VIf(Bf6), &sEnv_BCUizeyW_sendMessage);
    sEnv_process(this, &sEnv_KM6l8BCd, VIf(Bf7), &sEnv_KM6l8BCd_sendMessage);
    __hv_line_f(&sLine_0CWc1D0p, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_LrBXUQk6, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_HlyeOxQy, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_R2qDvbAJ, VOf(Bf6));
    __hv_line_f(&sLine_mbYyBrS7, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_H5CHMZN9, VIf(Bf9));
    __hv_varwrite_f(&sVarf_R2qDvbAJ, VIf(Bf10));
    __hv_varwrite_f(&sVarf_LN7pHLBI, VIf(Bf11));
    __hv_varwrite_f(&sVarf_NhR6rgxM, VIf(Bf12));
    __hv_varread_f(&sVarf_NhR6rgxM, VOf(Bf12));
    __hv_line_f(&sLine_uW0vG9pL, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_ATqffRbS, VIf(Bf10));
    __hv_varread_f(&sVarf_LN7pHLBI, VOf(Bf10));
    __hv_line_f(&sLine_gGQzqAlO, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_nX66Efhx, VIf(Bf10));
    __hv_varwrite_f(&sVarf_BEogxK3e, VIf(Bf7));
    __hv_varread_f(&sVarf_OThyx2wt, VOf(Bf7));
    __hv_varread_f(&sVarf_EZOpL5tY, VOf(Bf10));
    __hv_varread_f(&sVarf_32U0LF0b, VOf(Bf9));
    __hv_varread_f(&sVarf_0rEgGZW5, VOf(Bf11));
    __hv_varread_f(&sVarf_B4InUmKX, VOf(Bf6));
    __hv_varread_f(&sVarf_oUMHNhSx, VOf(Bf12));
    __hv_varread_f(&sVarf_eVkSPqQy, VOf(Bf1));
    __hv_varwrite_f(&sVarf_DR2Kv0yw, VIf(Bf4));
    __hv_varread_f(&sVarf_v6S5ZnlV, VOf(Bf2));
    __hv_line_f(&sLine_o0q5LLrD, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_LSqe8dW4, VOf(Bf17));
    __hv_line_f(&sLine_gKRjP5rj, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_18NRkB6R, VOf(Bf16));
    __hv_line_f(&sLine_qAa16wI6, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_0rEgGZW5, VIf(Bf15));
    __hv_varread_f(&sVarf_DR2Kv0yw, VOf(Bf15));
    __hv_line_f(&sLine_F1NRnlab, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_AtddN7ak, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_adKn952P, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_B4InUmKX, VIf(Bf13));
    __hv_line_f(&sLine_QE4US8el, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_XfjpVt35, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_TH16F7y8, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_oUMHNhSx, VIf(Bf13));
    __hv_line_f(&sLine_s9zea3B0, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_gUkDy3T9, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_mmONQ0k0, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_eVkSPqQy, VIf(Bf13));
    __hv_varwrite_f(&sVarf_v6S5ZnlV, VIf(Bf7));
    __hv_varwrite_f(&sVarf_LSqe8dW4, VIf(Bf10));
    __hv_varwrite_f(&sVarf_18NRkB6R, VIf(Bf9));
    sEnv_process(this, &sEnv_ZbWcTrEe, VIf(Bf11), &sEnv_ZbWcTrEe_sendMessage);
    sEnv_process(this, &sEnv_jRZfyZe7, VIf(Bf4), &sEnv_jRZfyZe7_sendMessage);
    __hv_line_f(&sLine_j9iVez3r, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_dngmJLbk, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_MxR9ZKIf, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Ikv8AkO2, VOf(Bf11));
    __hv_line_f(&sLine_F86lFQ5w, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_OThyx2wt, VIf(Bf10));
    __hv_varwrite_f(&sVarf_Ikv8AkO2, VIf(Bf6));
    __hv_varwrite_f(&sVarf_MpBBLwy0, VIf(Bf12));
    __hv_varwrite_f(&sVarf_tB7Cwcz0, VIf(Bf1));
    __hv_varread_f(&sVarf_tB7Cwcz0, VOf(Bf1));
    __hv_line_f(&sLine_B1R7OPFy, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_32U0LF0b, VIf(Bf6));
    __hv_varread_f(&sVarf_MpBBLwy0, VOf(Bf6));
    __hv_line_f(&sLine_xSrlWqJI, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_EZOpL5tY, VIf(Bf6));
    __hv_varwrite_f(&sVarf_AKkRrT9z, VIf(Bf4));
    __hv_varwrite_f(&sVarf_nB28qran, VIf(Bf0));
    __hv_varread_f(&sVarf_Nf2r6lEi, VOf(Bf0));
    __hv_varread_f(&sVarf_CHKRUlq3, VOf(Bf4));
    __hv_varread_f(&sVarf_CJxtPuJv, VOf(Bf6));
    __hv_varread_f(&sVarf_fp4KBYrl, VOf(Bf10));
    __hv_varread_f(&sVarf_zYwEtN7f, VOf(Bf12));
    __hv_varread_f(&sVarf_4qYhRKJu, VOf(Bf11));
    __hv_line_f(&sLine_9Dk1OErN, VOf(Bf1));
    __hv_line_f(&sLine_ElI9PlYs, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_CJxtPuJv, VIf(Bf0));
    __hv_varwrite_f(&sVarf_zYwEtN7f, VIf(Bf4));
    __hv_varread_f(&sVarf_ERmPhFNj, VOf(Bf1));
    __hv_varread_f(&sVarf_XlK9vW7e, VOf(Bf12));
    __hv_varread_f(&sVarf_RwKEqzPj, VOf(Bf11));
    __hv_varread_f(&sVarf_eTaAMX9s, VOf(Bf6));
    __hv_varread_f(&sVarf_nWlBCSg6, VOf(Bf7));
    __hv_varread_f(&sVarf_4ntEynzN, VOf(Bf13));
    __hv_varread_f(&sVarf_mXCbseIo, VOf(Bf15));
    __hv_varwrite_f(&sVarf_qZUXz2YZ, VIf(Bf0));
    __hv_varread_f(&sVarf_p4F0BAYH, VOf(Bf2));
    __hv_line_f(&sLine_7kcbiean, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_5IOdNNRu, VOf(Bf18));
    __hv_line_f(&sLine_1y9MnWiR, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_Q9CQPMxC, VOf(Bf17));
    __hv_line_f(&sLine_vq9Uo03o, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_eTaAMX9s, VIf(Bf14));
    __hv_varread_f(&sVarf_qZUXz2YZ, VOf(Bf14));
    __hv_line_f(&sLine_YoVWbcln, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_fAmvIqX1, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_XV3hsCd4, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_nWlBCSg6, VIf(Bf16));
    __hv_line_f(&sLine_Gby8D26P, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_DS98NZZM, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_rulvoW8b, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_4ntEynzN, VIf(Bf16));
    __hv_line_f(&sLine_US0RuV7m, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_LNUiYcAv, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_KTQi2dUc, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_mXCbseIo, VIf(Bf16));
    __hv_varwrite_f(&sVarf_p4F0BAYH, VIf(Bf1));
    __hv_varwrite_f(&sVarf_5IOdNNRu, VIf(Bf12));
    __hv_varwrite_f(&sVarf_Q9CQPMxC, VIf(Bf11));
    sEnv_process(this, &sEnv_unUtm1qA, VIf(Bf6), &sEnv_unUtm1qA_sendMessage);
    sEnv_process(this, &sEnv_dsffpoPy, VIf(Bf0), &sEnv_dsffpoPy_sendMessage);
    __hv_line_f(&sLine_neW54wkG, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_8rJgERe9, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_TvIfc1jM, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_c6R3xGu7, VOf(Bf6));
    __hv_line_f(&sLine_h3YyEIwv, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_ERmPhFNj, VIf(Bf12));
    __hv_varwrite_f(&sVarf_c6R3xGu7, VIf(Bf7));
    __hv_varwrite_f(&sVarf_QPjZbYpS, VIf(Bf13));
    __hv_varwrite_f(&sVarf_gotQyIzU, VIf(Bf15));
    __hv_varread_f(&sVarf_gotQyIzU, VOf(Bf15));
    __hv_line_f(&sLine_zifyF84m, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_RwKEqzPj, VIf(Bf7));
    __hv_varread_f(&sVarf_QPjZbYpS, VOf(Bf7));
    __hv_line_f(&sLine_rFnOWmyY, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_XlK9vW7e, VIf(Bf7));
    __hv_varwrite_f(&sVarf_fp4KBYrl, VIf(Bf0));
    __hv_varread_f(&sVarf_gpAdmsSq, VOf(Bf0));
    __hv_varread_f(&sVarf_fVCODvfX, VOf(Bf7));
    __hv_varread_f(&sVarf_2mJHspjJ, VOf(Bf12));
    __hv_varread_f(&sVarf_rhbTpn59, VOf(Bf13));
    __hv_varread_f(&sVarf_Ot2rT9kl, VOf(Bf6));
    __hv_varread_f(&sVarf_p9kqwrwD, VOf(Bf15));
    __hv_varread_f(&sVarf_WzFCRfe7, VOf(Bf11));
    __hv_varwrite_f(&sVarf_TNdJCnQt, VIf(Bf4));
    __hv_varread_f(&sVarf_TfEC67vl, VOf(Bf1));
    __hv_line_f(&sLine_KNpeySki, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_AjqCR0lt, VOf(Bf14));
    __hv_line_f(&sLine_Vbiacoxw, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_HhvHY0BH, VOf(Bf16));
    __hv_line_f(&sLine_rV4RUViF, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_rhbTpn59, VIf(Bf18));
    __hv_varread_f(&sVarf_TNdJCnQt, VOf(Bf18));
    __hv_line_f(&sLine_d7JFQIFx, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_ZHFNeKcX, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_oEzxKcks, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_Ot2rT9kl, VIf(Bf2));
    __hv_line_f(&sLine_YHYI01h1, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_KjHubgBS, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_tosSCqTX, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_p9kqwrwD, VIf(Bf2));
    __hv_line_f(&sLine_tQwhKKEA, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_hCRNK5YP, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_fxAcAYg5, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_WzFCRfe7, VIf(Bf2));
    __hv_varwrite_f(&sVarf_TfEC67vl, VIf(Bf0));
    __hv_varwrite_f(&sVarf_AjqCR0lt, VIf(Bf7));
    __hv_varwrite_f(&sVarf_HhvHY0BH, VIf(Bf12));
    sEnv_process(this, &sEnv_kUbljVQe, VIf(Bf13), &sEnv_kUbljVQe_sendMessage);
    sEnv_process(this, &sEnv_Wk53PUtk, VIf(Bf4), &sEnv_Wk53PUtk_sendMessage);
    __hv_line_f(&sLine_rDddlpag, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_DQgYIF0Y, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_bPloqjb8, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_8bYUxfBB, VOf(Bf13));
    __hv_line_f(&sLine_tM0NIeRp, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_gpAdmsSq, VIf(Bf7));
    __hv_varwrite_f(&sVarf_8bYUxfBB, VIf(Bf6));
    __hv_varwrite_f(&sVarf_hzPbZWb5, VIf(Bf15));
    __hv_varwrite_f(&sVarf_qYUz2bxN, VIf(Bf11));
    __hv_varread_f(&sVarf_qYUz2bxN, VOf(Bf11));
    __hv_line_f(&sLine_X3pJt634, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_2mJHspjJ, VIf(Bf6));
    __hv_varread_f(&sVarf_hzPbZWb5, VOf(Bf6));
    __hv_line_f(&sLine_coiPZw5I, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_fVCODvfX, VIf(Bf6));
    __hv_varwrite_f(&sVarf_4qYhRKJu, VIf(Bf4));
    __hv_varwrite_f(&sVarf_UY3fjGpk, VIf(Bf10));
    __hv_varread_f(&sVarf_M8gkB6Bl, VOf(Bf10));
    __hv_varread_f(&sVarf_QecjrQDg, VOf(Bf4));
    __hv_varread_f(&sVarf_81CoeDXV, VOf(Bf6));
    __hv_varread_f(&sVarf_sAIBfR45, VOf(Bf7));
    __hv_varread_f(&sVarf_w6a3ASQ3, VOf(Bf15));
    __hv_varread_f(&sVarf_SxIn0Huo, VOf(Bf13));
    __hv_line_f(&sLine_HaC6D8AP, VOf(Bf11));
    __hv_line_f(&sLine_olzyQLYv, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_81CoeDXV, VIf(Bf10));
    __hv_varwrite_f(&sVarf_w6a3ASQ3, VIf(Bf4));
    __hv_varread_f(&sVarf_bhk2YBwq, VOf(Bf11));
    __hv_varread_f(&sVarf_qVU2QHz3, VOf(Bf15));
    __hv_varread_f(&sVarf_NgrFMjfK, VOf(Bf13));
    __hv_varread_f(&sVarf_lwnG2ZmE, VOf(Bf6));
    __hv_varread_f(&sVarf_Ijq6Votl, VOf(Bf0));
    __hv_varread_f(&sVarf_HnPtuyGZ, VOf(Bf2));
    __hv_varread_f(&sVarf_xnp1cOat, VOf(Bf18));
    __hv_varwrite_f(&sVarf_92FWFDH7, VIf(Bf10));
    __hv_varread_f(&sVarf_PCj0ooER, VOf(Bf1));
    __hv_line_f(&sLine_LUR29rXc, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_HrBYeENf, VOf(Bf19));
    __hv_line_f(&sLine_qXjn4T0b, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_8kZAHZze, VOf(Bf14));
    __hv_line_f(&sLine_vlyJjXFD, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_lwnG2ZmE, VIf(Bf17));
    __hv_varread_f(&sVarf_92FWFDH7, VOf(Bf17));
    __hv_line_f(&sLine_S6IyEB8g, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_3tmWlXfz, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_KYkcATVf, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_Ijq6Votl, VIf(Bf16));
    __hv_line_f(&sLine_uloH3YLr, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_csCVGhTD, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_wuvpmkn3, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_HnPtuyGZ, VIf(Bf16));
    __hv_line_f(&sLine_T79EBREr, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_n6GdnktL, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_kfodzCu2, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_xnp1cOat, VIf(Bf16));
    __hv_varwrite_f(&sVarf_PCj0ooER, VIf(Bf11));
    __hv_varwrite_f(&sVarf_HrBYeENf, VIf(Bf15));
    __hv_varwrite_f(&sVarf_8kZAHZze, VIf(Bf13));
    sEnv_process(this, &sEnv_a1NYBl4D, VIf(Bf6), &sEnv_a1NYBl4D_sendMessage);
    sEnv_process(this, &sEnv_ZTQubMs0, VIf(Bf10), &sEnv_ZTQubMs0_sendMessage);
    __hv_line_f(&sLine_Vu8sEma4, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_mz6QipU0, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_9J6zZmHf, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_4FqNZHaC, VOf(Bf6));
    __hv_line_f(&sLine_6vX9VjVc, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_bhk2YBwq, VIf(Bf15));
    __hv_varwrite_f(&sVarf_4FqNZHaC, VIf(Bf0));
    __hv_varwrite_f(&sVarf_1c25nviz, VIf(Bf2));
    __hv_varwrite_f(&sVarf_iO4RJbmN, VIf(Bf18));
    __hv_varread_f(&sVarf_iO4RJbmN, VOf(Bf18));
    __hv_line_f(&sLine_IVoesz6O, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_NgrFMjfK, VIf(Bf0));
    __hv_varread_f(&sVarf_1c25nviz, VOf(Bf0));
    __hv_line_f(&sLine_r3JdKsTu, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_qVU2QHz3, VIf(Bf0));
    __hv_varwrite_f(&sVarf_sAIBfR45, VIf(Bf10));
    __hv_varread_f(&sVarf_D76jqmQe, VOf(Bf10));
    __hv_varread_f(&sVarf_RJKl7wYt, VOf(Bf0));
    __hv_varread_f(&sVarf_7mJFZV7y, VOf(Bf15));
    __hv_varread_f(&sVarf_iMjwYf8N, VOf(Bf2));
    __hv_varread_f(&sVarf_jbDc2HCY, VOf(Bf6));
    __hv_varread_f(&sVarf_BXcmlUfz, VOf(Bf18));
    __hv_varread_f(&sVarf_UGEfQjFp, VOf(Bf13));
    __hv_varwrite_f(&sVarf_Jb5dyiII, VIf(Bf4));
    __hv_varread_f(&sVarf_BR6oV6w8, VOf(Bf11));
    __hv_line_f(&sLine_juhFIt18, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_ckrcODWw, VOf(Bf17));
    __hv_line_f(&sLine_iIDBQ4r0, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_YXY1mb8o, VOf(Bf16));
    __hv_line_f(&sLine_HRRiEk8F, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_iMjwYf8N, VIf(Bf19));
    __hv_varread_f(&sVarf_Jb5dyiII, VOf(Bf19));
    __hv_line_f(&sLine_1yyM5g9J, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_GHnAIG3z, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_QEFSzlxX, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_jbDc2HCY, VIf(Bf1));
    __hv_line_f(&sLine_bO9lR8Ek, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_QaueMrzd, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_dCidLkjd, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_BXcmlUfz, VIf(Bf1));
    __hv_line_f(&sLine_CsGan9fy, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_vniP6wyM, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_6elAW81c, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_UGEfQjFp, VIf(Bf1));
    __hv_varwrite_f(&sVarf_BR6oV6w8, VIf(Bf10));
    __hv_varwrite_f(&sVarf_ckrcODWw, VIf(Bf0));
    __hv_varwrite_f(&sVarf_YXY1mb8o, VIf(Bf15));
    sEnv_process(this, &sEnv_QFxVoMhr, VIf(Bf2), &sEnv_QFxVoMhr_sendMessage);
    sEnv_process(this, &sEnv_4VlCUEcL, VIf(Bf4), &sEnv_4VlCUEcL_sendMessage);
    __hv_line_f(&sLine_cB5PE5uM, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_rrrcbDoi, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_GvzxD2jc, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_D6JHMBiy, VOf(Bf2));
    __hv_line_f(&sLine_5bC37u66, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_D76jqmQe, VIf(Bf0));
    __hv_varwrite_f(&sVarf_D6JHMBiy, VIf(Bf6));
    __hv_varwrite_f(&sVarf_lETMH4cI, VIf(Bf18));
    __hv_varwrite_f(&sVarf_1PZJkIHA, VIf(Bf13));
    __hv_varread_f(&sVarf_1PZJkIHA, VOf(Bf13));
    __hv_line_f(&sLine_7wMP3wCF, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_7mJFZV7y, VIf(Bf6));
    __hv_varread_f(&sVarf_lETMH4cI, VOf(Bf6));
    __hv_line_f(&sLine_kTfrq7xh, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_RJKl7wYt, VIf(Bf6));
    __hv_varwrite_f(&sVarf_SxIn0Huo, VIf(Bf4));
    __hv_varwrite_f(&sVarf_pPmQH1iD, VIf(Bf7));
    __hv_varwrite_f(&sVarf_glUiwL60, VIf(Bf8));
    __hv_varwrite_f(&sVarf_si5ABmfj, VIf(Bf9));
    __hv_varwrite_f(&sVarf_Os5dzgeG, VIf(Bf12));
    __hv_varwrite_f(&sVarf_LtQs6aUU, VIf(Bf3));
    __hv_varwrite_f(&sVarf_7zzFDQlP, VIf(Bf5));
    __hv_varread_f(&sVarf_glUiwL60, VOf(Bf5));
    __hv_varread_f(&sVarf_si5ABmfj, VOf(Bf3));
    __hv_varread_f(&sVarf_Os5dzgeG, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_nB28qran, VOf(Bf12));
    __hv_varread_f(&sVarf_UY3fjGpk, VOf(Bf5));
    __hv_varread_f(&sVarf_pPmQH1iD, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
